# coding: utf-8

# flake8: noqa

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "19.0.2"

from typing import TYPE_CHECKING

# non-runtime imports for type hints

if TYPE_CHECKING:
    from openapi_client.api.accounts_api import AccountsApi
    from openapi_client.api.campaigns_api import CampaignsApi
    from openapi_client.api.catalogs_api import CatalogsApi
    from openapi_client.api.coupons_api import CouponsApi
    from openapi_client.api.data_privacy_api import DataPrivacyApi
    from openapi_client.api.events_api import EventsApi
    from openapi_client.api.flows_api import FlowsApi
    from openapi_client.api.forms_api import FormsApi
    from openapi_client.api.images_api import ImagesApi
    from openapi_client.api.lists_api import ListsApi
    from openapi_client.api.metrics_api import MetricsApi
    from openapi_client.api.profiles_api import ProfilesApi
    from openapi_client.api.reporting_api import ReportingApi
    from openapi_client.api.reviews_api import ReviewsApi
    from openapi_client.api.segments_api import SegmentsApi
    from openapi_client.api.tags_api import TagsApi
    from openapi_client.api.templates_api import TemplatesApi
    from openapi_client.api.tracking_settings_api import TrackingSettingsApi
    from openapi_client.api.web_feeds_api import WebFeedsApi
    from openapi_client.api.webhooks_api import WebhooksApi
    
    # import ApiClient
    from openapi_client.api_response import ApiResponse
    from openapi_client.api_client import ApiClient
    from openapi_client.configuration import Configuration
    from openapi_client.exceptions import OpenApiException
    from openapi_client.exceptions import ApiTypeError
    from openapi_client.exceptions import ApiValueError
    from openapi_client.exceptions import ApiKeyError
    from openapi_client.exceptions import ApiAttributeError
    from openapi_client.exceptions import ApiException
    from openapi_client.models.api_job_error_payload import APIJobErrorPayload
    from openapi_client.models.account_enum import AccountEnum
    from openapi_client.models.account_response_object_resource import AccountResponseObjectResource
    from openapi_client.models.account_response_object_resource_attributes import AccountResponseObjectResourceAttributes
    from openapi_client.models.attribution_enum import AttributionEnum
    from openapi_client.models.audiences import Audiences
    from openapi_client.models.audiences_update import AudiencesUpdate
    from openapi_client.models.back_in_stock_subscription_enum import BackInStockSubscriptionEnum
    from openapi_client.models.base_event_create_query_bulk_entry_resource_object import BaseEventCreateQueryBulkEntryResourceObject
    from openapi_client.models.base_event_create_query_bulk_entry_resource_object_attributes import BaseEventCreateQueryBulkEntryResourceObjectAttributes
    from openapi_client.models.bulk_profile_suppressions_create_job_response_object_resource import BulkProfileSuppressionsCreateJobResponseObjectResource
    from openapi_client.models.bulk_profile_suppressions_create_job_response_object_resource_attributes import BulkProfileSuppressionsCreateJobResponseObjectResourceAttributes
    from openapi_client.models.bulk_profile_suppressions_remove_job_response_object_resource import BulkProfileSuppressionsRemoveJobResponseObjectResource
    from openapi_client.models.campaign_clone_query import CampaignCloneQuery
    from openapi_client.models.campaign_clone_query_resource_object import CampaignCloneQueryResourceObject
    from openapi_client.models.campaign_clone_query_resource_object_attributes import CampaignCloneQueryResourceObjectAttributes
    from openapi_client.models.campaign_create_query import CampaignCreateQuery
    from openapi_client.models.campaign_create_query_resource_object import CampaignCreateQueryResourceObject
    from openapi_client.models.campaign_create_query_resource_object_attributes import CampaignCreateQueryResourceObjectAttributes
    from openapi_client.models.campaign_create_query_resource_object_attributes_campaign_messages import CampaignCreateQueryResourceObjectAttributesCampaignMessages
    from openapi_client.models.campaign_enum import CampaignEnum
    from openapi_client.models.campaign_message_assign_template_query import CampaignMessageAssignTemplateQuery
    from openapi_client.models.campaign_message_assign_template_query_resource_object import CampaignMessageAssignTemplateQueryResourceObject
    from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships import CampaignMessageAssignTemplateQueryResourceObjectRelationships
    from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships_template import CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplate
    from openapi_client.models.campaign_message_assign_template_query_resource_object_relationships_template_data import CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplateData
    from openapi_client.models.campaign_message_create_query_resource_object import CampaignMessageCreateQueryResourceObject
    from openapi_client.models.campaign_message_create_query_resource_object_attributes import CampaignMessageCreateQueryResourceObjectAttributes
    from openapi_client.models.campaign_message_create_query_resource_object_relationships import CampaignMessageCreateQueryResourceObjectRelationships
    from openapi_client.models.campaign_message_create_query_resource_object_relationships_image import CampaignMessageCreateQueryResourceObjectRelationshipsImage
    from openapi_client.models.campaign_message_create_query_resource_object_relationships_image_data import CampaignMessageCreateQueryResourceObjectRelationshipsImageData
    from openapi_client.models.campaign_message_enum import CampaignMessageEnum
    from openapi_client.models.campaign_message_image_update_query import CampaignMessageImageUpdateQuery
    from openapi_client.models.campaign_message_image_update_query_data import CampaignMessageImageUpdateQueryData
    from openapi_client.models.campaign_message_partial_update_query import CampaignMessagePartialUpdateQuery
    from openapi_client.models.campaign_message_partial_update_query_resource_object import CampaignMessagePartialUpdateQueryResourceObject
    from openapi_client.models.campaign_message_partial_update_query_resource_object_attributes import CampaignMessagePartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.campaign_message_response_object_resource import CampaignMessageResponseObjectResource
    from openapi_client.models.campaign_message_response_object_resource_attributes import CampaignMessageResponseObjectResourceAttributes
    from openapi_client.models.campaign_partial_update_query import CampaignPartialUpdateQuery
    from openapi_client.models.campaign_partial_update_query_resource_object import CampaignPartialUpdateQueryResourceObject
    from openapi_client.models.campaign_partial_update_query_resource_object_attributes import CampaignPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.campaign_recipient_estimation_enum import CampaignRecipientEstimationEnum
    from openapi_client.models.campaign_recipient_estimation_job_create_query import CampaignRecipientEstimationJobCreateQuery
    from openapi_client.models.campaign_recipient_estimation_job_create_query_resource_object import CampaignRecipientEstimationJobCreateQueryResourceObject
    from openapi_client.models.campaign_recipient_estimation_job_enum import CampaignRecipientEstimationJobEnum
    from openapi_client.models.campaign_recipient_estimation_job_response_object_resource import CampaignRecipientEstimationJobResponseObjectResource
    from openapi_client.models.campaign_recipient_estimation_job_response_object_resource_attributes import CampaignRecipientEstimationJobResponseObjectResourceAttributes
    from openapi_client.models.campaign_recipient_estimation_response_object_resource import CampaignRecipientEstimationResponseObjectResource
    from openapi_client.models.campaign_recipient_estimation_response_object_resource_attributes import CampaignRecipientEstimationResponseObjectResourceAttributes
    from openapi_client.models.campaign_response_object_resource import CampaignResponseObjectResource
    from openapi_client.models.campaign_response_object_resource_attributes import CampaignResponseObjectResourceAttributes
    from openapi_client.models.campaign_send_job_create_query import CampaignSendJobCreateQuery
    from openapi_client.models.campaign_send_job_create_query_resource_object import CampaignSendJobCreateQueryResourceObject
    from openapi_client.models.campaign_send_job_enum import CampaignSendJobEnum
    from openapi_client.models.campaign_send_job_partial_update_query import CampaignSendJobPartialUpdateQuery
    from openapi_client.models.campaign_send_job_partial_update_query_resource_object import CampaignSendJobPartialUpdateQueryResourceObject
    from openapi_client.models.campaign_send_job_partial_update_query_resource_object_attributes import CampaignSendJobPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.campaign_send_job_response_object_resource import CampaignSendJobResponseObjectResource
    from openapi_client.models.campaign_send_job_response_object_resource_attributes import CampaignSendJobResponseObjectResourceAttributes
    from openapi_client.models.campaign_values_report_enum import CampaignValuesReportEnum
    from openapi_client.models.campaign_values_request_dto import CampaignValuesRequestDTO
    from openapi_client.models.campaign_values_request_dto_resource_object import CampaignValuesRequestDTOResourceObject
    from openapi_client.models.campaign_values_request_dto_resource_object_attributes import CampaignValuesRequestDTOResourceObjectAttributes
    from openapi_client.models.catalog_category_bulk_create_job_enum import CatalogCategoryBulkCreateJobEnum
    from openapi_client.models.catalog_category_bulk_delete_job_enum import CatalogCategoryBulkDeleteJobEnum
    from openapi_client.models.catalog_category_bulk_update_job_enum import CatalogCategoryBulkUpdateJobEnum
    from openapi_client.models.catalog_category_create_job_create_query import CatalogCategoryCreateJobCreateQuery
    from openapi_client.models.catalog_category_create_job_create_query_resource_object import CatalogCategoryCreateJobCreateQueryResourceObject
    from openapi_client.models.catalog_category_create_job_create_query_resource_object_attributes import CatalogCategoryCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_category_create_job_create_query_resource_object_attributes_categories import CatalogCategoryCreateJobCreateQueryResourceObjectAttributesCategories
    from openapi_client.models.catalog_category_create_job_response_object_resource import CatalogCategoryCreateJobResponseObjectResource
    from openapi_client.models.catalog_category_create_query import CatalogCategoryCreateQuery
    from openapi_client.models.catalog_category_create_query_resource_object import CatalogCategoryCreateQueryResourceObject
    from openapi_client.models.catalog_category_create_query_resource_object_attributes import CatalogCategoryCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_category_create_query_resource_object_relationships import CatalogCategoryCreateQueryResourceObjectRelationships
    from openapi_client.models.catalog_category_create_query_resource_object_relationships_items import CatalogCategoryCreateQueryResourceObjectRelationshipsItems
    from openapi_client.models.catalog_category_delete_job_create_query import CatalogCategoryDeleteJobCreateQuery
    from openapi_client.models.catalog_category_delete_job_create_query_resource_object import CatalogCategoryDeleteJobCreateQueryResourceObject
    from openapi_client.models.catalog_category_delete_job_create_query_resource_object_attributes import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_category_delete_job_create_query_resource_object_attributes_categories import CatalogCategoryDeleteJobCreateQueryResourceObjectAttributesCategories
    from openapi_client.models.catalog_category_delete_job_response_object_resource import CatalogCategoryDeleteJobResponseObjectResource
    from openapi_client.models.catalog_category_delete_query_resource_object import CatalogCategoryDeleteQueryResourceObject
    from openapi_client.models.catalog_category_enum import CatalogCategoryEnum
    from openapi_client.models.catalog_category_item_op import CatalogCategoryItemOp
    from openapi_client.models.catalog_category_item_op_data_inner import CatalogCategoryItemOpDataInner
    from openapi_client.models.catalog_category_response_object_resource import CatalogCategoryResponseObjectResource
    from openapi_client.models.catalog_category_response_object_resource_attributes import CatalogCategoryResponseObjectResourceAttributes
    from openapi_client.models.catalog_category_update_job_create_query import CatalogCategoryUpdateJobCreateQuery
    from openapi_client.models.catalog_category_update_job_create_query_resource_object import CatalogCategoryUpdateJobCreateQueryResourceObject
    from openapi_client.models.catalog_category_update_job_create_query_resource_object_attributes import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_category_update_job_create_query_resource_object_attributes_categories import CatalogCategoryUpdateJobCreateQueryResourceObjectAttributesCategories
    from openapi_client.models.catalog_category_update_job_response_object_resource import CatalogCategoryUpdateJobResponseObjectResource
    from openapi_client.models.catalog_category_update_query import CatalogCategoryUpdateQuery
    from openapi_client.models.catalog_category_update_query_resource_object import CatalogCategoryUpdateQueryResourceObject
    from openapi_client.models.catalog_category_update_query_resource_object_attributes import CatalogCategoryUpdateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_bulk_create_job_enum import CatalogItemBulkCreateJobEnum
    from openapi_client.models.catalog_item_bulk_delete_job_enum import CatalogItemBulkDeleteJobEnum
    from openapi_client.models.catalog_item_bulk_update_job_enum import CatalogItemBulkUpdateJobEnum
    from openapi_client.models.catalog_item_category_op import CatalogItemCategoryOp
    from openapi_client.models.catalog_item_create_job_create_query import CatalogItemCreateJobCreateQuery
    from openapi_client.models.catalog_item_create_job_create_query_resource_object import CatalogItemCreateJobCreateQueryResourceObject
    from openapi_client.models.catalog_item_create_job_create_query_resource_object_attributes import CatalogItemCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_create_job_create_query_resource_object_attributes_items import CatalogItemCreateJobCreateQueryResourceObjectAttributesItems
    from openapi_client.models.catalog_item_create_job_response_object_resource import CatalogItemCreateJobResponseObjectResource
    from openapi_client.models.catalog_item_create_query import CatalogItemCreateQuery
    from openapi_client.models.catalog_item_create_query_resource_object import CatalogItemCreateQueryResourceObject
    from openapi_client.models.catalog_item_create_query_resource_object_attributes import CatalogItemCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_create_query_resource_object_relationships import CatalogItemCreateQueryResourceObjectRelationships
    from openapi_client.models.catalog_item_create_query_resource_object_relationships_categories import CatalogItemCreateQueryResourceObjectRelationshipsCategories
    from openapi_client.models.catalog_item_create_query_resource_object_relationships_categories_data_inner import CatalogItemCreateQueryResourceObjectRelationshipsCategoriesDataInner
    from openapi_client.models.catalog_item_delete_job_create_query import CatalogItemDeleteJobCreateQuery
    from openapi_client.models.catalog_item_delete_job_create_query_resource_object import CatalogItemDeleteJobCreateQueryResourceObject
    from openapi_client.models.catalog_item_delete_job_create_query_resource_object_attributes import CatalogItemDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_delete_job_create_query_resource_object_attributes_items import CatalogItemDeleteJobCreateQueryResourceObjectAttributesItems
    from openapi_client.models.catalog_item_delete_job_response_object_resource import CatalogItemDeleteJobResponseObjectResource
    from openapi_client.models.catalog_item_delete_query_resource_object import CatalogItemDeleteQueryResourceObject
    from openapi_client.models.catalog_item_enum import CatalogItemEnum
    from openapi_client.models.catalog_item_response_object_resource import CatalogItemResponseObjectResource
    from openapi_client.models.catalog_item_response_object_resource_attributes import CatalogItemResponseObjectResourceAttributes
    from openapi_client.models.catalog_item_update_job_create_query import CatalogItemUpdateJobCreateQuery
    from openapi_client.models.catalog_item_update_job_create_query_resource_object import CatalogItemUpdateJobCreateQueryResourceObject
    from openapi_client.models.catalog_item_update_job_create_query_resource_object_attributes import CatalogItemUpdateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_item_update_job_create_query_resource_object_attributes_items import CatalogItemUpdateJobCreateQueryResourceObjectAttributesItems
    from openapi_client.models.catalog_item_update_job_response_object_resource import CatalogItemUpdateJobResponseObjectResource
    from openapi_client.models.catalog_item_update_query import CatalogItemUpdateQuery
    from openapi_client.models.catalog_item_update_query_resource_object import CatalogItemUpdateQueryResourceObject
    from openapi_client.models.catalog_item_update_query_resource_object_attributes import CatalogItemUpdateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_bulk_create_job_enum import CatalogVariantBulkCreateJobEnum
    from openapi_client.models.catalog_variant_bulk_delete_job_enum import CatalogVariantBulkDeleteJobEnum
    from openapi_client.models.catalog_variant_bulk_update_job_enum import CatalogVariantBulkUpdateJobEnum
    from openapi_client.models.catalog_variant_create_job_create_query import CatalogVariantCreateJobCreateQuery
    from openapi_client.models.catalog_variant_create_job_create_query_resource_object import CatalogVariantCreateJobCreateQueryResourceObject
    from openapi_client.models.catalog_variant_create_job_create_query_resource_object_attributes import CatalogVariantCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_create_job_create_query_resource_object_attributes_variants import CatalogVariantCreateJobCreateQueryResourceObjectAttributesVariants
    from openapi_client.models.catalog_variant_create_job_response_object_resource import CatalogVariantCreateJobResponseObjectResource
    from openapi_client.models.catalog_variant_create_query import CatalogVariantCreateQuery
    from openapi_client.models.catalog_variant_create_query_resource_object import CatalogVariantCreateQueryResourceObject
    from openapi_client.models.catalog_variant_create_query_resource_object_attributes import CatalogVariantCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_create_query_resource_object_relationships import CatalogVariantCreateQueryResourceObjectRelationships
    from openapi_client.models.catalog_variant_create_query_resource_object_relationships_item import CatalogVariantCreateQueryResourceObjectRelationshipsItem
    from openapi_client.models.catalog_variant_create_query_resource_object_relationships_item_data import CatalogVariantCreateQueryResourceObjectRelationshipsItemData
    from openapi_client.models.catalog_variant_delete_job_create_query import CatalogVariantDeleteJobCreateQuery
    from openapi_client.models.catalog_variant_delete_job_create_query_resource_object import CatalogVariantDeleteJobCreateQueryResourceObject
    from openapi_client.models.catalog_variant_delete_job_create_query_resource_object_attributes import CatalogVariantDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_delete_job_create_query_resource_object_attributes_variants import CatalogVariantDeleteJobCreateQueryResourceObjectAttributesVariants
    from openapi_client.models.catalog_variant_delete_job_response_object_resource import CatalogVariantDeleteJobResponseObjectResource
    from openapi_client.models.catalog_variant_delete_query_resource_object import CatalogVariantDeleteQueryResourceObject
    from openapi_client.models.catalog_variant_enum import CatalogVariantEnum
    from openapi_client.models.catalog_variant_response_object_resource import CatalogVariantResponseObjectResource
    from openapi_client.models.catalog_variant_response_object_resource_attributes import CatalogVariantResponseObjectResourceAttributes
    from openapi_client.models.catalog_variant_update_job_create_query import CatalogVariantUpdateJobCreateQuery
    from openapi_client.models.catalog_variant_update_job_create_query_resource_object import CatalogVariantUpdateJobCreateQueryResourceObject
    from openapi_client.models.catalog_variant_update_job_create_query_resource_object_attributes import CatalogVariantUpdateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.catalog_variant_update_job_create_query_resource_object_attributes_variants import CatalogVariantUpdateJobCreateQueryResourceObjectAttributesVariants
    from openapi_client.models.catalog_variant_update_job_response_object_resource import CatalogVariantUpdateJobResponseObjectResource
    from openapi_client.models.catalog_variant_update_query import CatalogVariantUpdateQuery
    from openapi_client.models.catalog_variant_update_query_resource_object import CatalogVariantUpdateQueryResourceObject
    from openapi_client.models.catalog_variant_update_query_resource_object_attributes import CatalogVariantUpdateQueryResourceObjectAttributes
    from openapi_client.models.collection_links import CollectionLinks
    from openapi_client.models.condition_group import ConditionGroup
    from openapi_client.models.contact_information import ContactInformation
    from openapi_client.models.coupon_code_bulk_create_job_enum import CouponCodeBulkCreateJobEnum
    from openapi_client.models.coupon_code_create_job_create_query import CouponCodeCreateJobCreateQuery
    from openapi_client.models.coupon_code_create_job_create_query_resource_object import CouponCodeCreateJobCreateQueryResourceObject
    from openapi_client.models.coupon_code_create_job_create_query_resource_object_attributes import CouponCodeCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.coupon_code_create_job_create_query_resource_object_attributes_coupon_codes import CouponCodeCreateJobCreateQueryResourceObjectAttributesCouponCodes
    from openapi_client.models.coupon_code_create_job_response_object_resource import CouponCodeCreateJobResponseObjectResource
    from openapi_client.models.coupon_code_create_job_response_object_resource_attributes import CouponCodeCreateJobResponseObjectResourceAttributes
    from openapi_client.models.coupon_code_create_query import CouponCodeCreateQuery
    from openapi_client.models.coupon_code_create_query_resource_object import CouponCodeCreateQueryResourceObject
    from openapi_client.models.coupon_code_create_query_resource_object_attributes import CouponCodeCreateQueryResourceObjectAttributes
    from openapi_client.models.coupon_code_create_query_resource_object_relationships import CouponCodeCreateQueryResourceObjectRelationships
    from openapi_client.models.coupon_code_create_query_resource_object_relationships_coupon import CouponCodeCreateQueryResourceObjectRelationshipsCoupon
    from openapi_client.models.coupon_code_enum import CouponCodeEnum
    from openapi_client.models.coupon_code_response_object_resource import CouponCodeResponseObjectResource
    from openapi_client.models.coupon_code_response_object_resource_attributes import CouponCodeResponseObjectResourceAttributes
    from openapi_client.models.coupon_code_update_query import CouponCodeUpdateQuery
    from openapi_client.models.coupon_code_update_query_resource_object import CouponCodeUpdateQueryResourceObject
    from openapi_client.models.coupon_code_update_query_resource_object_attributes import CouponCodeUpdateQueryResourceObjectAttributes
    from openapi_client.models.coupon_create_query import CouponCreateQuery
    from openapi_client.models.coupon_create_query_resource_object import CouponCreateQueryResourceObject
    from openapi_client.models.coupon_enum import CouponEnum
    from openapi_client.models.coupon_response_object_resource import CouponResponseObjectResource
    from openapi_client.models.coupon_response_object_resource_attributes import CouponResponseObjectResourceAttributes
    from openapi_client.models.coupon_update_query import CouponUpdateQuery
    from openapi_client.models.coupon_update_query_resource_object import CouponUpdateQueryResourceObject
    from openapi_client.models.coupon_update_query_resource_object_attributes import CouponUpdateQueryResourceObjectAttributes
    from openapi_client.models.custom_metric_condition import CustomMetricCondition
    from openapi_client.models.custom_metric_create_query import CustomMetricCreateQuery
    from openapi_client.models.custom_metric_create_query_resource_object import CustomMetricCreateQueryResourceObject
    from openapi_client.models.custom_metric_create_query_resource_object_attributes import CustomMetricCreateQueryResourceObjectAttributes
    from openapi_client.models.custom_metric_definition import CustomMetricDefinition
    from openapi_client.models.custom_metric_enum import CustomMetricEnum
    from openapi_client.models.custom_metric_group import CustomMetricGroup
    from openapi_client.models.custom_metric_partial_update_query import CustomMetricPartialUpdateQuery
    from openapi_client.models.custom_metric_partial_update_query_resource_object import CustomMetricPartialUpdateQueryResourceObject
    from openapi_client.models.custom_metric_partial_update_query_resource_object_attributes import CustomMetricPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.custom_metric_response_object_resource import CustomMetricResponseObjectResource
    from openapi_client.models.custom_metric_response_object_resource_attributes import CustomMetricResponseObjectResourceAttributes
    from openapi_client.models.custom_tracking_param_dto import CustomTrackingParamDTO
    from openapi_client.models.data_privacy_create_deletion_job_query import DataPrivacyCreateDeletionJobQuery
    from openapi_client.models.data_privacy_create_deletion_job_query_resource_object import DataPrivacyCreateDeletionJobQueryResourceObject
    from openapi_client.models.data_privacy_create_deletion_job_query_resource_object_attributes import DataPrivacyCreateDeletionJobQueryResourceObjectAttributes
    from openapi_client.models.data_privacy_create_deletion_job_query_resource_object_attributes_profile import DataPrivacyCreateDeletionJobQueryResourceObjectAttributesProfile
    from openapi_client.models.data_privacy_deletion_job_enum import DataPrivacyDeletionJobEnum
    from openapi_client.models.data_privacy_profile_query_resource_object import DataPrivacyProfileQueryResourceObject
    from openapi_client.models.data_privacy_profile_query_resource_object_attributes import DataPrivacyProfileQueryResourceObjectAttributes
    from openapi_client.models.delete_tag_group_response import DeleteTagGroupResponse
    from openapi_client.models.device_metadata import DeviceMetadata
    from openapi_client.models.email_channel import EmailChannel
    from openapi_client.models.email_marketing import EmailMarketing
    from openapi_client.models.email_marketing_list_suppression import EmailMarketingListSuppression
    from openapi_client.models.email_marketing_suppression import EmailMarketingSuppression
    from openapi_client.models.email_subscription_parameters import EmailSubscriptionParameters
    from openapi_client.models.email_unsubscription_parameters import EmailUnsubscriptionParameters
    from openapi_client.models.error_source import ErrorSource
    from openapi_client.models.event_bulk_create_enum import EventBulkCreateEnum
    from openapi_client.models.event_bulk_create_job_enum import EventBulkCreateJobEnum
    from openapi_client.models.event_create_query_v2 import EventCreateQueryV2
    from openapi_client.models.event_create_query_v2_resource_object import EventCreateQueryV2ResourceObject
    from openapi_client.models.event_create_query_v2_resource_object_attributes import EventCreateQueryV2ResourceObjectAttributes
    from openapi_client.models.event_create_query_v2_resource_object_attributes_metric import EventCreateQueryV2ResourceObjectAttributesMetric
    from openapi_client.models.event_create_query_v2_resource_object_attributes_profile import EventCreateQueryV2ResourceObjectAttributesProfile
    from openapi_client.models.event_enum import EventEnum
    from openapi_client.models.event_profile_create_query_resource_object import EventProfileCreateQueryResourceObject
    from openapi_client.models.event_profile_create_query_resource_object_attributes import EventProfileCreateQueryResourceObjectAttributes
    from openapi_client.models.event_response_object_resource import EventResponseObjectResource
    from openapi_client.models.event_response_object_resource_attributes import EventResponseObjectResourceAttributes
    from openapi_client.models.events_bulk_create_job import EventsBulkCreateJob
    from openapi_client.models.events_bulk_create_job_resource_object import EventsBulkCreateJobResourceObject
    from openapi_client.models.events_bulk_create_job_resource_object_attributes import EventsBulkCreateJobResourceObjectAttributes
    from openapi_client.models.events_bulk_create_job_resource_object_attributes_events_bulk_create import EventsBulkCreateJobResourceObjectAttributesEventsBulkCreate
    from openapi_client.models.events_bulk_create_query_resource_object import EventsBulkCreateQueryResourceObject
    from openapi_client.models.events_bulk_create_query_resource_object_attributes import EventsBulkCreateQueryResourceObjectAttributes
    from openapi_client.models.events_bulk_create_query_resource_object_attributes_events import EventsBulkCreateQueryResourceObjectAttributesEvents
    from openapi_client.models.events_bulk_create_query_resource_object_attributes_profile import EventsBulkCreateQueryResourceObjectAttributesProfile
    from openapi_client.models.flow_action_enum import FlowActionEnum
    from openapi_client.models.flow_action_response_object_resource import FlowActionResponseObjectResource
    from openapi_client.models.flow_action_response_object_resource_attributes import FlowActionResponseObjectResourceAttributes
    from openapi_client.models.flow_create_query import FlowCreateQuery
    from openapi_client.models.flow_create_query_resource_object import FlowCreateQueryResourceObject
    from openapi_client.models.flow_create_query_resource_object_attributes import FlowCreateQueryResourceObjectAttributes
    from openapi_client.models.flow_definition import FlowDefinition
    from openapi_client.models.flow_definition_profile_filter import FlowDefinitionProfileFilter
    from openapi_client.models.flow_definition_profile_filter_condition_groups_inner import FlowDefinitionProfileFilterConditionGroupsInner
    from openapi_client.models.flow_enum import FlowEnum
    from openapi_client.models.flow_message_enum import FlowMessageEnum
    from openapi_client.models.flow_message_response_object_resource import FlowMessageResponseObjectResource
    from openapi_client.models.flow_message_response_object_resource_attributes import FlowMessageResponseObjectResourceAttributes
    from openapi_client.models.flow_response_object_resource import FlowResponseObjectResource
    from openapi_client.models.flow_response_object_resource_attributes import FlowResponseObjectResourceAttributes
    from openapi_client.models.flow_series_report_enum import FlowSeriesReportEnum
    from openapi_client.models.flow_series_request_dto import FlowSeriesRequestDTO
    from openapi_client.models.flow_series_request_dto_resource_object import FlowSeriesRequestDTOResourceObject
    from openapi_client.models.flow_series_request_dto_resource_object_attributes import FlowSeriesRequestDTOResourceObjectAttributes
    from openapi_client.models.flow_update_query import FlowUpdateQuery
    from openapi_client.models.flow_update_query_resource_object import FlowUpdateQueryResourceObject
    from openapi_client.models.flow_update_query_resource_object_attributes import FlowUpdateQueryResourceObjectAttributes
    from openapi_client.models.flow_v2_response_object_resource_attributes import FlowV2ResponseObjectResourceAttributes
    from openapi_client.models.flow_v2_response_object_resource_extended import FlowV2ResponseObjectResourceExtended
    from openapi_client.models.flow_v2_response_object_resource_extended_attributes import FlowV2ResponseObjectResourceExtendedAttributes
    from openapi_client.models.flow_values_report_enum import FlowValuesReportEnum
    from openapi_client.models.flow_values_request_dto import FlowValuesRequestDTO
    from openapi_client.models.flow_values_request_dto_resource_object import FlowValuesRequestDTOResourceObject
    from openapi_client.models.flow_values_request_dto_resource_object_attributes import FlowValuesRequestDTOResourceObjectAttributes
    from openapi_client.models.form_enum import FormEnum
    from openapi_client.models.form_response_object_resource import FormResponseObjectResource
    from openapi_client.models.form_response_object_resource_attributes import FormResponseObjectResourceAttributes
    from openapi_client.models.form_series_report_enum import FormSeriesReportEnum
    from openapi_client.models.form_series_request_dto import FormSeriesRequestDTO
    from openapi_client.models.form_series_request_dto_resource_object import FormSeriesRequestDTOResourceObject
    from openapi_client.models.form_series_request_dto_resource_object_attributes import FormSeriesRequestDTOResourceObjectAttributes
    from openapi_client.models.form_values_report_enum import FormValuesReportEnum
    from openapi_client.models.form_values_request_dto import FormValuesRequestDTO
    from openapi_client.models.form_values_request_dto_resource_object import FormValuesRequestDTOResourceObject
    from openapi_client.models.form_values_request_dto_resource_object_attributes import FormValuesRequestDTOResourceObjectAttributes
    from openapi_client.models.form_version_ab_test import FormVersionABTest
    from openapi_client.models.form_version_enum import FormVersionEnum
    from openapi_client.models.form_version_response_object_resource import FormVersionResponseObjectResource
    from openapi_client.models.form_version_response_object_resource_attributes import FormVersionResponseObjectResourceAttributes
    from openapi_client.models.get_account_response import GetAccountResponse
    from openapi_client.models.get_account_response_collection import GetAccountResponseCollection
    from openapi_client.models.get_accounts4_xx_response import GetAccounts4XXResponse
    from openapi_client.models.get_accounts4_xx_response_errors_inner import GetAccounts4XXResponseErrorsInner
    from openapi_client.models.get_accounts4_xx_response_errors_inner_source import GetAccounts4XXResponseErrorsInnerSource
    from openapi_client.models.get_bulk_profile_suppressions_create_job_response import GetBulkProfileSuppressionsCreateJobResponse
    from openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection import GetBulkProfileSuppressionsCreateJobResponseCollection
    from openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection_data_inner import GetBulkProfileSuppressionsCreateJobResponseCollectionDataInner
    from openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection_data_inner_all_of_relationships import GetBulkProfileSuppressionsCreateJobResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_bulk_profile_suppressions_remove_job_response import GetBulkProfileSuppressionsRemoveJobResponse
    from openapi_client.models.get_bulk_profile_suppressions_remove_job_response_collection import GetBulkProfileSuppressionsRemoveJobResponseCollection
    from openapi_client.models.get_bulk_profile_suppressions_remove_job_response_collection_data_inner import GetBulkProfileSuppressionsRemoveJobResponseCollectionDataInner
    from openapi_client.models.get_campaign_message_campaign_relationship_response import GetCampaignMessageCampaignRelationshipResponse
    from openapi_client.models.get_campaign_message_campaign_relationship_response_data import GetCampaignMessageCampaignRelationshipResponseData
    from openapi_client.models.get_campaign_message_image_relationship_response import GetCampaignMessageImageRelationshipResponse
    from openapi_client.models.get_campaign_message_image_relationship_response_data import GetCampaignMessageImageRelationshipResponseData
    from openapi_client.models.get_campaign_message_response_collection_compound_document import GetCampaignMessageResponseCollectionCompoundDocument
    from openapi_client.models.get_campaign_message_response_compound_document import GetCampaignMessageResponseCompoundDocument
    from openapi_client.models.get_campaign_message_response_compound_document_data import GetCampaignMessageResponseCompoundDocumentData
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_campaign import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsCampaign
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_campaign_data import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsCampaignData
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_image import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsImage
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_image_data import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsImageData
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_template import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsTemplate
    from openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_template_data import GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsTemplateData
    from openapi_client.models.get_campaign_message_template_relationship_response import GetCampaignMessageTemplateRelationshipResponse
    from openapi_client.models.get_campaign_messages_relationships_response_collection import GetCampaignMessagesRelationshipsResponseCollection
    from openapi_client.models.get_campaign_messages_relationships_response_collection_data_inner import GetCampaignMessagesRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_campaign_recipient_estimation_job_response import GetCampaignRecipientEstimationJobResponse
    from openapi_client.models.get_campaign_recipient_estimation_response import GetCampaignRecipientEstimationResponse
    from openapi_client.models.get_campaign_response import GetCampaignResponse
    from openapi_client.models.get_campaign_response_collection_compound_document import GetCampaignResponseCollectionCompoundDocument
    from openapi_client.models.get_campaign_response_collection_compound_document_data_inner import GetCampaignResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships_campaign_messages import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCampaignMessages
    from openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships_campaign_messages_data_inner import GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCampaignMessagesDataInner
    from openapi_client.models.get_campaign_response_compound_document import GetCampaignResponseCompoundDocument
    from openapi_client.models.get_campaign_response_data import GetCampaignResponseData
    from openapi_client.models.get_campaign_response_data_all_of_relationships import GetCampaignResponseDataAllOfRelationships
    from openapi_client.models.get_campaign_send_job_response import GetCampaignSendJobResponse
    from openapi_client.models.get_campaign_tags_relationships_response_collection import GetCampaignTagsRelationshipsResponseCollection
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document import GetCatalogCategoryCreateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships_categories import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategories
    from openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships_categories_data_inner import GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategoriesDataInner
    from openapi_client.models.get_catalog_category_create_job_response_compound_document import GetCatalogCategoryCreateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_category_delete_job_response import GetCatalogCategoryDeleteJobResponse
    from openapi_client.models.get_catalog_category_delete_job_response_collection import GetCatalogCategoryDeleteJobResponseCollection
    from openapi_client.models.get_catalog_category_delete_job_response_collection_data_inner import GetCatalogCategoryDeleteJobResponseCollectionDataInner
    from openapi_client.models.get_catalog_category_delete_job_response_collection_data_inner_all_of_relationships import GetCatalogCategoryDeleteJobResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_category_items_relationships_response_collection import GetCatalogCategoryItemsRelationshipsResponseCollection
    from openapi_client.models.get_catalog_category_items_relationships_response_collection_data_inner import GetCatalogCategoryItemsRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_catalog_category_response import GetCatalogCategoryResponse
    from openapi_client.models.get_catalog_category_response_collection import GetCatalogCategoryResponseCollection
    from openapi_client.models.get_catalog_category_response_collection_data_inner import GetCatalogCategoryResponseCollectionDataInner
    from openapi_client.models.get_catalog_category_response_collection_data_inner_all_of_relationships import GetCatalogCategoryResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships_categories import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategories
    from openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships_categories_data_inner import GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategoriesDataInner
    from openapi_client.models.get_catalog_category_update_job_response_compound_document import GetCatalogCategoryUpdateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_item_categories_relationships_response_collection import GetCatalogItemCategoriesRelationshipsResponseCollection
    from openapi_client.models.get_catalog_item_categories_relationships_response_collection_data_inner import GetCatalogItemCategoriesRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document import GetCatalogItemCreateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships_items import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItems
    from openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships_items_data_inner import GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItemsDataInner
    from openapi_client.models.get_catalog_item_create_job_response_compound_document import GetCatalogItemCreateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_item_delete_job_response import GetCatalogItemDeleteJobResponse
    from openapi_client.models.get_catalog_item_delete_job_response_collection import GetCatalogItemDeleteJobResponseCollection
    from openapi_client.models.get_catalog_item_delete_job_response_collection_data_inner import GetCatalogItemDeleteJobResponseCollectionDataInner
    from openapi_client.models.get_catalog_item_response_collection_compound_document import GetCatalogItemResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner import GetCatalogItemResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
    from openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
    from openapi_client.models.get_catalog_item_response_compound_document import GetCatalogItemResponseCompoundDocument
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document import GetCatalogItemUpdateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships_items import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItems
    from openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships_items_data_inner import GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItemsDataInner
    from openapi_client.models.get_catalog_item_update_job_response_compound_document import GetCatalogItemUpdateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_item_variants_relationships_response_collection import GetCatalogItemVariantsRelationshipsResponseCollection
    from openapi_client.models.get_catalog_item_variants_relationships_response_collection_data_inner import GetCatalogItemVariantsRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document import GetCatalogVariantCreateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
    from openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
    from openapi_client.models.get_catalog_variant_create_job_response_compound_document import GetCatalogVariantCreateJobResponseCompoundDocument
    from openapi_client.models.get_catalog_variant_delete_job_response import GetCatalogVariantDeleteJobResponse
    from openapi_client.models.get_catalog_variant_delete_job_response_collection import GetCatalogVariantDeleteJobResponseCollection
    from openapi_client.models.get_catalog_variant_delete_job_response_collection_data_inner import GetCatalogVariantDeleteJobResponseCollectionDataInner
    from openapi_client.models.get_catalog_variant_delete_job_response_collection_data_inner_all_of_relationships import GetCatalogVariantDeleteJobResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_variant_response import GetCatalogVariantResponse
    from openapi_client.models.get_catalog_variant_response_collection import GetCatalogVariantResponseCollection
    from openapi_client.models.get_catalog_variant_response_collection_data_inner import GetCatalogVariantResponseCollectionDataInner
    from openapi_client.models.get_catalog_variant_response_collection_data_inner_all_of_relationships import GetCatalogVariantResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document import GetCatalogVariantUpdateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships_variants import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants
    from openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner import GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner
    from openapi_client.models.get_catalog_variant_update_job_response_compound_document import GetCatalogVariantUpdateJobResponseCompoundDocument
    from openapi_client.models.get_coupon_code_coupon_relationship_response import GetCouponCodeCouponRelationshipResponse
    from openapi_client.models.get_coupon_code_coupon_relationship_response_data import GetCouponCodeCouponRelationshipResponseData
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document import GetCouponCodeCreateJobResponseCollectionCompoundDocument
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships_coupon_codes import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponCodes
    from openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships_coupon_codes_data_inner import GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponCodesDataInner
    from openapi_client.models.get_coupon_code_create_job_response_compound_document import GetCouponCodeCreateJobResponseCompoundDocument
    from openapi_client.models.get_coupon_code_response_collection import GetCouponCodeResponseCollection
    from openapi_client.models.get_coupon_code_response_collection_compound_document import GetCouponCodeResponseCollectionCompoundDocument
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner import GetCouponCodeResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_coupon import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCoupon
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_coupon_data import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponData
    from openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_profile import GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile
    from openapi_client.models.get_coupon_code_response_collection_data_inner import GetCouponCodeResponseCollectionDataInner
    from openapi_client.models.get_coupon_code_response_collection_data_inner_all_of_relationships import GetCouponCodeResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_coupon_code_response_compound_document import GetCouponCodeResponseCompoundDocument
    from openapi_client.models.get_coupon_codes_relationships_response_collection import GetCouponCodesRelationshipsResponseCollection
    from openapi_client.models.get_coupon_codes_relationships_response_collection_data_inner import GetCouponCodesRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_coupon_response import GetCouponResponse
    from openapi_client.models.get_coupon_response_collection import GetCouponResponseCollection
    from openapi_client.models.get_custom_metric_metrics_relationships_response_collection import GetCustomMetricMetricsRelationshipsResponseCollection
    from openapi_client.models.get_custom_metric_response_collection_compound_document import GetCustomMetricResponseCollectionCompoundDocument
    from openapi_client.models.get_custom_metric_response_collection_compound_document_data_inner import GetCustomMetricResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_custom_metric_response_collection_compound_document_data_inner_all_of_relationships import GetCustomMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_custom_metric_response_collection_compound_document_data_inner_all_of_relationships_metrics import GetCustomMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetrics
    from openapi_client.models.get_custom_metric_response_collection_compound_document_data_inner_all_of_relationships_metrics_data_inner import GetCustomMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetricsDataInner
    from openapi_client.models.get_custom_metric_response_compound_document import GetCustomMetricResponseCompoundDocument
    from openapi_client.models.get_event_metric_relationship_response import GetEventMetricRelationshipResponse
    from openapi_client.models.get_event_profile_relationship_response import GetEventProfileRelationshipResponse
    from openapi_client.models.get_event_profile_relationship_response_data import GetEventProfileRelationshipResponseData
    from openapi_client.models.get_event_response_collection_compound_document import GetEventResponseCollectionCompoundDocument
    from openapi_client.models.get_event_response_collection_compound_document_data_inner import GetEventResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_attributions import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsAttributions
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_attributions_data_inner import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsAttributionsDataInner
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_metric import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetric
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_metric_data import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetricData
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_profile import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile
    from openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_profile_data import GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfileData
    from openapi_client.models.get_event_response_compound_document import GetEventResponseCompoundDocument
    from openapi_client.models.get_flow_action_flow_message_relationship_response_collection import GetFlowActionFlowMessageRelationshipResponseCollection
    from openapi_client.models.get_flow_action_flow_relationship_response import GetFlowActionFlowRelationshipResponse
    from openapi_client.models.get_flow_action_response import GetFlowActionResponse
    from openapi_client.models.get_flow_action_response_collection import GetFlowActionResponseCollection
    from openapi_client.models.get_flow_action_response_collection_data_inner import GetFlowActionResponseCollectionDataInner
    from openapi_client.models.get_flow_action_response_collection_data_inner_all_of_relationships import GetFlowActionResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_flow_action_response_compound_document import GetFlowActionResponseCompoundDocument
    from openapi_client.models.get_flow_action_response_compound_document_data import GetFlowActionResponseCompoundDocumentData
    from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships import GetFlowActionResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlow
    from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow_messages import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlowMessages
    from openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow_messages_data_inner import GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlowMessagesDataInner
    from openapi_client.models.get_flow_flow_action_relationship_list_response_collection import GetFlowFlowActionRelationshipListResponseCollection
    from openapi_client.models.get_flow_message_action_relationship_response import GetFlowMessageActionRelationshipResponse
    from openapi_client.models.get_flow_message_response_collection import GetFlowMessageResponseCollection
    from openapi_client.models.get_flow_message_response_collection_data_inner import GetFlowMessageResponseCollectionDataInner
    from openapi_client.models.get_flow_message_response_collection_data_inner_all_of_relationships import GetFlowMessageResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_flow_message_response_compound_document import GetFlowMessageResponseCompoundDocument
    from openapi_client.models.get_flow_message_response_compound_document_data import GetFlowMessageResponseCompoundDocumentData
    from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships import GetFlowMessageResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_flow_action import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsFlowAction
    from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_template import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsTemplate
    from openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_template_data import GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsTemplateData
    from openapi_client.models.get_flow_message_template_relationship_response import GetFlowMessageTemplateRelationshipResponse
    from openapi_client.models.get_flow_message_template_relationship_response_data import GetFlowMessageTemplateRelationshipResponseData
    from openapi_client.models.get_flow_response import GetFlowResponse
    from openapi_client.models.get_flow_response_collection import GetFlowResponseCollection
    from openapi_client.models.get_flow_response_collection_compound_document import GetFlowResponseCollectionCompoundDocument
    from openapi_client.models.get_flow_response_collection_compound_document_data_inner import GetFlowResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships_flow_actions import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowActions
    from openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships_flow_actions_data_inner import GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowActionsDataInner
    from openapi_client.models.get_flow_response_collection_data_inner import GetFlowResponseCollectionDataInner
    from openapi_client.models.get_flow_response_collection_data_inner_all_of_relationships import GetFlowResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_flow_tags_relationships_response_collection import GetFlowTagsRelationshipsResponseCollection
    from openapi_client.models.get_flow_v2_response_compound_document import GetFlowV2ResponseCompoundDocument
    from openapi_client.models.get_flow_v2_response_compound_document_data import GetFlowV2ResponseCompoundDocumentData
    from openapi_client.models.get_form_response import GetFormResponse
    from openapi_client.models.get_form_response_collection_compound_document import GetFormResponseCollectionCompoundDocument
    from openapi_client.models.get_form_response_collection_compound_document_data_inner import GetFormResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_form_response_collection_compound_document_data_inner_all_of_relationships import GetFormResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_form_response_compound_document import GetFormResponseCompoundDocument
    from openapi_client.models.get_form_response_compound_document_data import GetFormResponseCompoundDocumentData
    from openapi_client.models.get_form_response_compound_document_data_all_of_relationships import GetFormResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_form_response_compound_document_data_all_of_relationships_form_versions import GetFormResponseCompoundDocumentDataAllOfRelationshipsFormVersions
    from openapi_client.models.get_form_response_compound_document_data_all_of_relationships_form_versions_data_inner import GetFormResponseCompoundDocumentDataAllOfRelationshipsFormVersionsDataInner
    from openapi_client.models.get_form_version_form_relationship_response import GetFormVersionFormRelationshipResponse
    from openapi_client.models.get_form_version_form_relationship_response_data import GetFormVersionFormRelationshipResponseData
    from openapi_client.models.get_form_version_response import GetFormVersionResponse
    from openapi_client.models.get_form_version_response_collection import GetFormVersionResponseCollection
    from openapi_client.models.get_form_versions_relationships_response_collection import GetFormVersionsRelationshipsResponseCollection
    from openapi_client.models.get_form_versions_relationships_response_collection_data_inner import GetFormVersionsRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_image_response import GetImageResponse
    from openapi_client.models.get_image_response_collection import GetImageResponseCollection
    from openapi_client.models.get_import_error_response_collection import GetImportErrorResponseCollection
    from openapi_client.models.get_list_flow_triggers_relationships_response_collection import GetListFlowTriggersRelationshipsResponseCollection
    from openapi_client.models.get_list_list_response_collection_compound_document import GetListListResponseCollectionCompoundDocument
    from openapi_client.models.get_list_list_response_collection_compound_document_data_inner import GetListListResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships_tags import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTags
    from openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships_tags_data_inner import GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagsDataInner
    from openapi_client.models.get_list_member_response_collection import GetListMemberResponseCollection
    from openapi_client.models.get_list_member_response_collection_data_inner import GetListMemberResponseCollectionDataInner
    from openapi_client.models.get_list_profiles_relationships_response_collection import GetListProfilesRelationshipsResponseCollection
    from openapi_client.models.get_list_response_collection import GetListResponseCollection
    from openapi_client.models.get_list_response_collection_data_inner import GetListResponseCollectionDataInner
    from openapi_client.models.get_list_response_collection_data_inner_all_of_relationships import GetListResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_list_retrieve_response_compound_document import GetListRetrieveResponseCompoundDocument
    from openapi_client.models.get_list_retrieve_response_compound_document_data import GetListRetrieveResponseCompoundDocumentData
    from openapi_client.models.get_list_tags_relationships_response_collection import GetListTagsRelationshipsResponseCollection
    from openapi_client.models.get_list_tags_relationships_response_collection_data_inner import GetListTagsRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_metric_flow_triggers_relationships_response_collection import GetMetricFlowTriggersRelationshipsResponseCollection
    from openapi_client.models.get_metric_properties_relationships_response_collection import GetMetricPropertiesRelationshipsResponseCollection
    from openapi_client.models.get_metric_properties_relationships_response_collection_data_inner import GetMetricPropertiesRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_metric_property_metric_relationship_response import GetMetricPropertyMetricRelationshipResponse
    from openapi_client.models.get_metric_property_response_collection import GetMetricPropertyResponseCollection
    from openapi_client.models.get_metric_property_response_collection_data_inner import GetMetricPropertyResponseCollectionDataInner
    from openapi_client.models.get_metric_property_response_collection_data_inner_all_of_relationships import GetMetricPropertyResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_metric_property_response_compound_document import GetMetricPropertyResponseCompoundDocument
    from openapi_client.models.get_metric_property_response_compound_document_data import GetMetricPropertyResponseCompoundDocumentData
    from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships_metric import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationshipsMetric
    from openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships_metric_data import GetMetricPropertyResponseCompoundDocumentDataAllOfRelationshipsMetricData
    from openapi_client.models.get_metric_response import GetMetricResponse
    from openapi_client.models.get_metric_response_collection import GetMetricResponseCollection
    from openapi_client.models.get_metric_response_collection_compound_document import GetMetricResponseCollectionCompoundDocument
    from openapi_client.models.get_metric_response_collection_compound_document_data_inner import GetMetricResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships import GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships_flow_triggers import GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowTriggers
    from openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships_flow_triggers_data_inner import GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowTriggersDataInner
    from openapi_client.models.get_metric_response_compound_document import GetMetricResponseCompoundDocument
    from openapi_client.models.get_metric_response_data import GetMetricResponseData
    from openapi_client.models.get_metric_response_data_all_of_relationships import GetMetricResponseDataAllOfRelationships
    from openapi_client.models.get_profile_bulk_import_job_lists_relationships_response_collection import GetProfileBulkImportJobListsRelationshipsResponseCollection
    from openapi_client.models.get_profile_bulk_import_job_profiles_relationships_response_collection import GetProfileBulkImportJobProfilesRelationshipsResponseCollection
    from openapi_client.models.get_profile_import_job_response_collection_compound_document import GetProfileImportJobResponseCollectionCompoundDocument
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner import GetProfileImportJobResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_import_errors import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsImportErrors
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_lists import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsLists
    from openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_lists_data_inner import GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsListsDataInner
    from openapi_client.models.get_profile_import_job_response_compound_document import GetProfileImportJobResponseCompoundDocument
    from openapi_client.models.get_profile_lists_relationships_response_collection import GetProfileListsRelationshipsResponseCollection
    from openapi_client.models.get_profile_lists_relationships_response_collection_data_inner import GetProfileListsRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_profile_push_tokens_relationships_response_collection import GetProfilePushTokensRelationshipsResponseCollection
    from openapi_client.models.get_profile_push_tokens_relationships_response_collection_data_inner import GetProfilePushTokensRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_profile_response import GetProfileResponse
    from openapi_client.models.get_profile_response_collection import GetProfileResponseCollection
    from openapi_client.models.get_profile_response_collection_compound_document import GetProfileResponseCollectionCompoundDocument
    from openapi_client.models.get_profile_response_collection_compound_document_data_inner import GetProfileResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_profile_response_collection_compound_document_data_inner_all_of_relationships import GetProfileResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_profile_response_collection_compound_document_data_inner_all_of_relationships_push_tokens import GetProfileResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsPushTokens
    from openapi_client.models.get_profile_response_collection_compound_document_data_inner_all_of_relationships_push_tokens_data_inner import GetProfileResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsPushTokensDataInner
    from openapi_client.models.get_profile_response_compound_document import GetProfileResponseCompoundDocument
    from openapi_client.models.get_profile_response_compound_document_data import GetProfileResponseCompoundDocumentData
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships import GetProfileResponseCompoundDocumentDataAllOfRelationships
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_lists import GetProfileResponseCompoundDocumentDataAllOfRelationshipsLists
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_lists_data_inner import GetProfileResponseCompoundDocumentDataAllOfRelationshipsListsDataInner
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_segments import GetProfileResponseCompoundDocumentDataAllOfRelationshipsSegments
    from openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_segments_data_inner import GetProfileResponseCompoundDocumentDataAllOfRelationshipsSegmentsDataInner
    from openapi_client.models.get_profile_response_data import GetProfileResponseData
    from openapi_client.models.get_profile_response_data_all_of_relationships import GetProfileResponseDataAllOfRelationships
    from openapi_client.models.get_profile_segments_relationships_response_collection import GetProfileSegmentsRelationshipsResponseCollection
    from openapi_client.models.get_push_token_profile_relationship_response import GetPushTokenProfileRelationshipResponse
    from openapi_client.models.get_push_token_response_collection import GetPushTokenResponseCollection
    from openapi_client.models.get_push_token_response_collection_compound_document import GetPushTokenResponseCollectionCompoundDocument
    from openapi_client.models.get_push_token_response_collection_compound_document_data_inner import GetPushTokenResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_push_token_response_collection_compound_document_data_inner_all_of_relationships import GetPushTokenResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_push_token_response_collection_compound_document_data_inner_all_of_relationships_profile import GetPushTokenResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile
    from openapi_client.models.get_push_token_response_collection_compound_document_data_inner_all_of_relationships_profile_data import GetPushTokenResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfileData
    from openapi_client.models.get_push_token_response_collection_data_inner import GetPushTokenResponseCollectionDataInner
    from openapi_client.models.get_push_token_response_collection_data_inner_all_of_relationships import GetPushTokenResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_push_token_response_compound_document import GetPushTokenResponseCompoundDocument
    from openapi_client.models.get_review_response_dto_collection_compound_document import GetReviewResponseDTOCollectionCompoundDocument
    from openapi_client.models.get_review_response_dto_collection_compound_document_data_inner import GetReviewResponseDTOCollectionCompoundDocumentDataInner
    from openapi_client.models.get_review_response_dto_collection_compound_document_data_inner_all_of_relationships import GetReviewResponseDTOCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_review_response_dto_collection_compound_document_data_inner_all_of_relationships_events import GetReviewResponseDTOCollectionCompoundDocumentDataInnerAllOfRelationshipsEvents
    from openapi_client.models.get_review_response_dto_collection_compound_document_data_inner_all_of_relationships_events_data_inner import GetReviewResponseDTOCollectionCompoundDocumentDataInnerAllOfRelationshipsEventsDataInner
    from openapi_client.models.get_review_response_dto_compound_document import GetReviewResponseDTOCompoundDocument
    from openapi_client.models.get_segment_flow_triggers_relationships_response_collection import GetSegmentFlowTriggersRelationshipsResponseCollection
    from openapi_client.models.get_segment_list_response_collection_compound_document import GetSegmentListResponseCollectionCompoundDocument
    from openapi_client.models.get_segment_list_response_collection_compound_document_data_inner import GetSegmentListResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_segment_member_response_collection import GetSegmentMemberResponseCollection
    from openapi_client.models.get_segment_member_response_collection_data_inner import GetSegmentMemberResponseCollectionDataInner
    from openapi_client.models.get_segment_profiles_relationships_response_collection import GetSegmentProfilesRelationshipsResponseCollection
    from openapi_client.models.get_segment_response_collection import GetSegmentResponseCollection
    from openapi_client.models.get_segment_response_collection_data_inner import GetSegmentResponseCollectionDataInner
    from openapi_client.models.get_segment_retrieve_response_compound_document import GetSegmentRetrieveResponseCompoundDocument
    from openapi_client.models.get_segment_retrieve_response_compound_document_data import GetSegmentRetrieveResponseCompoundDocumentData
    from openapi_client.models.get_segment_tags_relationships_response_collection import GetSegmentTagsRelationshipsResponseCollection
    from openapi_client.models.get_tag_campaign_relationships_response_collection import GetTagCampaignRelationshipsResponseCollection
    from openapi_client.models.get_tag_campaign_relationships_response_collection_data_inner import GetTagCampaignRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_tag_flow_relationships_response_collection import GetTagFlowRelationshipsResponseCollection
    from openapi_client.models.get_tag_flow_relationships_response_collection_data_inner import GetTagFlowRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_tag_group_relationship_response import GetTagGroupRelationshipResponse
    from openapi_client.models.get_tag_group_relationship_response_data import GetTagGroupRelationshipResponseData
    from openapi_client.models.get_tag_group_response import GetTagGroupResponse
    from openapi_client.models.get_tag_group_response_collection import GetTagGroupResponseCollection
    from openapi_client.models.get_tag_group_response_collection_data_inner import GetTagGroupResponseCollectionDataInner
    from openapi_client.models.get_tag_group_response_collection_data_inner_all_of_relationships import GetTagGroupResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_tag_group_tags_relationships_response_collection import GetTagGroupTagsRelationshipsResponseCollection
    from openapi_client.models.get_tag_list_relationships_response_collection import GetTagListRelationshipsResponseCollection
    from openapi_client.models.get_tag_list_relationships_response_collection_data_inner import GetTagListRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_tag_response_collection import GetTagResponseCollection
    from openapi_client.models.get_tag_response_collection_compound_document import GetTagResponseCollectionCompoundDocument
    from openapi_client.models.get_tag_response_collection_compound_document_data_inner import GetTagResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships_tag_group import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagGroup
    from openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships_tag_group_data import GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagGroupData
    from openapi_client.models.get_tag_response_collection_data_inner import GetTagResponseCollectionDataInner
    from openapi_client.models.get_tag_response_collection_data_inner_all_of_relationships import GetTagResponseCollectionDataInnerAllOfRelationships
    from openapi_client.models.get_tag_response_compound_document import GetTagResponseCompoundDocument
    from openapi_client.models.get_tag_segment_relationships_response_collection import GetTagSegmentRelationshipsResponseCollection
    from openapi_client.models.get_tag_segment_relationships_response_collection_data_inner import GetTagSegmentRelationshipsResponseCollectionDataInner
    from openapi_client.models.get_template_response import GetTemplateResponse
    from openapi_client.models.get_template_response_collection import GetTemplateResponseCollection
    from openapi_client.models.get_tracking_setting_response import GetTrackingSettingResponse
    from openapi_client.models.get_tracking_setting_response_collection import GetTrackingSettingResponseCollection
    from openapi_client.models.get_universal_content_response import GetUniversalContentResponse
    from openapi_client.models.get_universal_content_response_collection import GetUniversalContentResponseCollection
    from openapi_client.models.get_web_feed_response import GetWebFeedResponse
    from openapi_client.models.get_web_feed_response_collection import GetWebFeedResponseCollection
    from openapi_client.models.get_webhook_response_collection_compound_document import GetWebhookResponseCollectionCompoundDocument
    from openapi_client.models.get_webhook_response_collection_compound_document_data_inner import GetWebhookResponseCollectionCompoundDocumentDataInner
    from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationships
    from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships_webhook_topics import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsWebhookTopics
    from openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships_webhook_topics_data_inner import GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsWebhookTopicsDataInner
    from openapi_client.models.get_webhook_response_compound_document import GetWebhookResponseCompoundDocument
    from openapi_client.models.get_webhook_topic_response import GetWebhookTopicResponse
    from openapi_client.models.get_webhook_topic_response_collection import GetWebhookTopicResponseCollection
    from openapi_client.models.image_create_query import ImageCreateQuery
    from openapi_client.models.image_create_query_resource_object import ImageCreateQueryResourceObject
    from openapi_client.models.image_create_query_resource_object_attributes import ImageCreateQueryResourceObjectAttributes
    from openapi_client.models.image_enum import ImageEnum
    from openapi_client.models.image_partial_update_query import ImagePartialUpdateQuery
    from openapi_client.models.image_partial_update_query_resource_object import ImagePartialUpdateQueryResourceObject
    from openapi_client.models.image_partial_update_query_resource_object_attributes import ImagePartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.image_response_object_resource import ImageResponseObjectResource
    from openapi_client.models.image_response_object_resource_attributes import ImageResponseObjectResourceAttributes
    from openapi_client.models.import_error_enum import ImportErrorEnum
    from openapi_client.models.import_error_response_object_resource import ImportErrorResponseObjectResource
    from openapi_client.models.import_error_response_object_resource_attributes import ImportErrorResponseObjectResourceAttributes
    from openapi_client.models.list_create_query import ListCreateQuery
    from openapi_client.models.list_create_query_resource_object import ListCreateQueryResourceObject
    from openapi_client.models.list_create_query_resource_object_attributes import ListCreateQueryResourceObjectAttributes
    from openapi_client.models.list_enum import ListEnum
    from openapi_client.models.list_list_response_object_resource import ListListResponseObjectResource
    from openapi_client.models.list_list_response_object_resource_attributes import ListListResponseObjectResourceAttributes
    from openapi_client.models.list_member_response_object_resource_attributes import ListMemberResponseObjectResourceAttributes
    from openapi_client.models.list_member_response_object_resource_extended import ListMemberResponseObjectResourceExtended
    from openapi_client.models.list_member_response_object_resource_extended_attributes import ListMemberResponseObjectResourceExtendedAttributes
    from openapi_client.models.list_members_add_query import ListMembersAddQuery
    from openapi_client.models.list_members_delete_query import ListMembersDeleteQuery
    from openapi_client.models.list_partial_update_query import ListPartialUpdateQuery
    from openapi_client.models.list_partial_update_query_resource_object import ListPartialUpdateQueryResourceObject
    from openapi_client.models.list_response_object_resource import ListResponseObjectResource
    from openapi_client.models.list_retrieve_response_object_resource_attributes import ListRetrieveResponseObjectResourceAttributes
    from openapi_client.models.list_retrieve_response_object_resource_extended import ListRetrieveResponseObjectResourceExtended
    from openapi_client.models.list_retrieve_response_object_resource_extended_attributes import ListRetrieveResponseObjectResourceExtendedAttributes
    from openapi_client.models.metric_aggregate_enum import MetricAggregateEnum
    from openapi_client.models.metric_aggregate_query import MetricAggregateQuery
    from openapi_client.models.metric_aggregate_query_resource_object import MetricAggregateQueryResourceObject
    from openapi_client.models.metric_aggregate_query_resource_object_attributes import MetricAggregateQueryResourceObjectAttributes
    from openapi_client.models.metric_aggregate_row_dto import MetricAggregateRowDTO
    from openapi_client.models.metric_create_query_resource_object import MetricCreateQueryResourceObject
    from openapi_client.models.metric_create_query_resource_object_attributes import MetricCreateQueryResourceObjectAttributes
    from openapi_client.models.metric_enum import MetricEnum
    from openapi_client.models.metric_property_enum import MetricPropertyEnum
    from openapi_client.models.metric_property_response_object_resource_attributes import MetricPropertyResponseObjectResourceAttributes
    from openapi_client.models.metric_property_response_object_resource_extended import MetricPropertyResponseObjectResourceExtended
    from openapi_client.models.metric_property_response_object_resource_extended_attributes import MetricPropertyResponseObjectResourceExtendedAttributes
    from openapi_client.models.metric_response_object_resource import MetricResponseObjectResource
    from openapi_client.models.metric_response_object_resource_attributes import MetricResponseObjectResourceAttributes
    from openapi_client.models.object_links import ObjectLinks
    from openapi_client.models.only_related_links import OnlyRelatedLinks
    from openapi_client.models.onsite_profile_create_query_resource_object import OnsiteProfileCreateQueryResourceObject
    from openapi_client.models.onsite_profile_create_query_resource_object_attributes import OnsiteProfileCreateQueryResourceObjectAttributes
    from openapi_client.models.onsite_profile_meta import OnsiteProfileMeta
    from openapi_client.models.patch_campaign_message_response import PatchCampaignMessageResponse
    from openapi_client.models.patch_campaign_message_response_data import PatchCampaignMessageResponseData
    from openapi_client.models.patch_campaign_response import PatchCampaignResponse
    from openapi_client.models.patch_catalog_category_response import PatchCatalogCategoryResponse
    from openapi_client.models.patch_catalog_item_response import PatchCatalogItemResponse
    from openapi_client.models.patch_catalog_variant_response import PatchCatalogVariantResponse
    from openapi_client.models.patch_coupon_code_response import PatchCouponCodeResponse
    from openapi_client.models.patch_coupon_response import PatchCouponResponse
    from openapi_client.models.patch_custom_metric_response import PatchCustomMetricResponse
    from openapi_client.models.patch_flow_response import PatchFlowResponse
    from openapi_client.models.patch_flow_response_data import PatchFlowResponseData
    from openapi_client.models.patch_image_response import PatchImageResponse
    from openapi_client.models.patch_list_partial_update_response import PatchListPartialUpdateResponse
    from openapi_client.models.patch_profile_response import PatchProfileResponse
    from openapi_client.models.patch_review_response_dto import PatchReviewResponseDTO
    from openapi_client.models.patch_review_response_dto_data import PatchReviewResponseDTOData
    from openapi_client.models.patch_review_response_dto_data_attributes import PatchReviewResponseDTODataAttributes
    from openapi_client.models.patch_review_response_dto_data_relationships import PatchReviewResponseDTODataRelationships
    from openapi_client.models.patch_review_response_dto_data_relationships_item import PatchReviewResponseDTODataRelationshipsItem
    from openapi_client.models.patch_review_response_dto_data_relationships_item_data import PatchReviewResponseDTODataRelationshipsItemData
    from openapi_client.models.patch_segment_partial_update_response import PatchSegmentPartialUpdateResponse
    from openapi_client.models.patch_tag_group_response import PatchTagGroupResponse
    from openapi_client.models.patch_template_response import PatchTemplateResponse
    from openapi_client.models.patch_tracking_setting_response import PatchTrackingSettingResponse
    from openapi_client.models.patch_tracking_setting_response_data import PatchTrackingSettingResponseData
    from openapi_client.models.patch_universal_content_response import PatchUniversalContentResponse
    from openapi_client.models.patch_web_feed_response import PatchWebFeedResponse
    from openapi_client.models.patch_webhook_response import PatchWebhookResponse
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response import PostBulkProfileSuppressionsCreateJobResponse
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data import PostBulkProfileSuppressionsCreateJobResponseData
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_attributes import PostBulkProfileSuppressionsCreateJobResponseDataAttributes
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships import PostBulkProfileSuppressionsCreateJobResponseDataRelationships
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_lists import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsLists
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_lists_data_inner import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsListsDataInner
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_segments import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsSegments
    from openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_segments_data_inner import PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsSegmentsDataInner
    from openapi_client.models.post_bulk_profile_suppressions_remove_job_response import PostBulkProfileSuppressionsRemoveJobResponse
    from openapi_client.models.post_bulk_profile_suppressions_remove_job_response_data import PostBulkProfileSuppressionsRemoveJobResponseData
    from openapi_client.models.post_campaign_message_response import PostCampaignMessageResponse
    from openapi_client.models.post_campaign_message_response_data import PostCampaignMessageResponseData
    from openapi_client.models.post_campaign_message_response_data_attributes import PostCampaignMessageResponseDataAttributes
    from openapi_client.models.post_campaign_message_response_data_relationships import PostCampaignMessageResponseDataRelationships
    from openapi_client.models.post_campaign_recipient_estimation_job_response import PostCampaignRecipientEstimationJobResponse
    from openapi_client.models.post_campaign_recipient_estimation_job_response_data import PostCampaignRecipientEstimationJobResponseData
    from openapi_client.models.post_campaign_recipient_estimation_job_response_data_attributes import PostCampaignRecipientEstimationJobResponseDataAttributes
    from openapi_client.models.post_campaign_response import PostCampaignResponse
    from openapi_client.models.post_campaign_response_data import PostCampaignResponseData
    from openapi_client.models.post_campaign_response_data_attributes import PostCampaignResponseDataAttributes
    from openapi_client.models.post_campaign_send_job_response import PostCampaignSendJobResponse
    from openapi_client.models.post_campaign_send_job_response_data import PostCampaignSendJobResponseData
    from openapi_client.models.post_campaign_send_job_response_data_attributes import PostCampaignSendJobResponseDataAttributes
    from openapi_client.models.post_campaign_values_response_dto import PostCampaignValuesResponseDTO
    from openapi_client.models.post_campaign_values_response_dto_data import PostCampaignValuesResponseDTOData
    from openapi_client.models.post_campaign_values_response_dto_data_attributes import PostCampaignValuesResponseDTODataAttributes
    from openapi_client.models.post_campaign_values_response_dto_data_relationships import PostCampaignValuesResponseDTODataRelationships
    from openapi_client.models.post_catalog_category_create_job_response import PostCatalogCategoryCreateJobResponse
    from openapi_client.models.post_catalog_category_create_job_response_data import PostCatalogCategoryCreateJobResponseData
    from openapi_client.models.post_catalog_category_delete_job_response import PostCatalogCategoryDeleteJobResponse
    from openapi_client.models.post_catalog_category_delete_job_response_data import PostCatalogCategoryDeleteJobResponseData
    from openapi_client.models.post_catalog_category_delete_job_response_data_relationships import PostCatalogCategoryDeleteJobResponseDataRelationships
    from openapi_client.models.post_catalog_category_delete_job_response_data_relationships_categories import PostCatalogCategoryDeleteJobResponseDataRelationshipsCategories
    from openapi_client.models.post_catalog_category_delete_job_response_data_relationships_categories_data_inner import PostCatalogCategoryDeleteJobResponseDataRelationshipsCategoriesDataInner
    from openapi_client.models.post_catalog_category_response import PostCatalogCategoryResponse
    from openapi_client.models.post_catalog_category_response_data import PostCatalogCategoryResponseData
    from openapi_client.models.post_catalog_category_response_data_relationships import PostCatalogCategoryResponseDataRelationships
    from openapi_client.models.post_catalog_category_response_data_relationships_items import PostCatalogCategoryResponseDataRelationshipsItems
    from openapi_client.models.post_catalog_category_update_job_response import PostCatalogCategoryUpdateJobResponse
    from openapi_client.models.post_catalog_category_update_job_response_data import PostCatalogCategoryUpdateJobResponseData
    from openapi_client.models.post_catalog_item_create_job_response import PostCatalogItemCreateJobResponse
    from openapi_client.models.post_catalog_item_create_job_response_data import PostCatalogItemCreateJobResponseData
    from openapi_client.models.post_catalog_item_delete_job_response import PostCatalogItemDeleteJobResponse
    from openapi_client.models.post_catalog_item_delete_job_response_data import PostCatalogItemDeleteJobResponseData
    from openapi_client.models.post_catalog_item_delete_job_response_data_relationships import PostCatalogItemDeleteJobResponseDataRelationships
    from openapi_client.models.post_catalog_item_delete_job_response_data_relationships_items import PostCatalogItemDeleteJobResponseDataRelationshipsItems
    from openapi_client.models.post_catalog_item_delete_job_response_data_relationships_items_data_inner import PostCatalogItemDeleteJobResponseDataRelationshipsItemsDataInner
    from openapi_client.models.post_catalog_item_response import PostCatalogItemResponse
    from openapi_client.models.post_catalog_item_response_data import PostCatalogItemResponseData
    from openapi_client.models.post_catalog_item_update_job_response import PostCatalogItemUpdateJobResponse
    from openapi_client.models.post_catalog_item_update_job_response_data import PostCatalogItemUpdateJobResponseData
    from openapi_client.models.post_catalog_variant_create_job_response import PostCatalogVariantCreateJobResponse
    from openapi_client.models.post_catalog_variant_create_job_response_data import PostCatalogVariantCreateJobResponseData
    from openapi_client.models.post_catalog_variant_delete_job_response import PostCatalogVariantDeleteJobResponse
    from openapi_client.models.post_catalog_variant_delete_job_response_data import PostCatalogVariantDeleteJobResponseData
    from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships import PostCatalogVariantDeleteJobResponseDataRelationships
    from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships_variants import PostCatalogVariantDeleteJobResponseDataRelationshipsVariants
    from openapi_client.models.post_catalog_variant_delete_job_response_data_relationships_variants_data_inner import PostCatalogVariantDeleteJobResponseDataRelationshipsVariantsDataInner
    from openapi_client.models.post_catalog_variant_response import PostCatalogVariantResponse
    from openapi_client.models.post_catalog_variant_response_data import PostCatalogVariantResponseData
    from openapi_client.models.post_catalog_variant_response_data_relationships import PostCatalogVariantResponseDataRelationships
    from openapi_client.models.post_catalog_variant_response_data_relationships_item import PostCatalogVariantResponseDataRelationshipsItem
    from openapi_client.models.post_catalog_variant_response_data_relationships_item_data import PostCatalogVariantResponseDataRelationshipsItemData
    from openapi_client.models.post_catalog_variant_update_job_response import PostCatalogVariantUpdateJobResponse
    from openapi_client.models.post_catalog_variant_update_job_response_data import PostCatalogVariantUpdateJobResponseData
    from openapi_client.models.post_coupon_code_create_job_response import PostCouponCodeCreateJobResponse
    from openapi_client.models.post_coupon_code_create_job_response_data import PostCouponCodeCreateJobResponseData
    from openapi_client.models.post_coupon_code_create_job_response_data_attributes import PostCouponCodeCreateJobResponseDataAttributes
    from openapi_client.models.post_coupon_code_response import PostCouponCodeResponse
    from openapi_client.models.post_coupon_code_response_data import PostCouponCodeResponseData
    from openapi_client.models.post_coupon_code_response_data_relationships import PostCouponCodeResponseDataRelationships
    from openapi_client.models.post_coupon_code_response_data_relationships_profile import PostCouponCodeResponseDataRelationshipsProfile
    from openapi_client.models.post_coupon_code_response_data_relationships_profile_data import PostCouponCodeResponseDataRelationshipsProfileData
    from openapi_client.models.post_coupon_response import PostCouponResponse
    from openapi_client.models.post_coupon_response_data import PostCouponResponseData
    from openapi_client.models.post_coupon_response_data_attributes import PostCouponResponseDataAttributes
    from openapi_client.models.post_custom_metric_response import PostCustomMetricResponse
    from openapi_client.models.post_custom_metric_response_data import PostCustomMetricResponseData
    from openapi_client.models.post_custom_metric_response_data_attributes import PostCustomMetricResponseDataAttributes
    from openapi_client.models.post_flow_series_response_dto import PostFlowSeriesResponseDTO
    from openapi_client.models.post_flow_series_response_dto_data import PostFlowSeriesResponseDTOData
    from openapi_client.models.post_flow_series_response_dto_data_attributes import PostFlowSeriesResponseDTODataAttributes
    from openapi_client.models.post_flow_v2_response import PostFlowV2Response
    from openapi_client.models.post_flow_v2_response_data import PostFlowV2ResponseData
    from openapi_client.models.post_flow_v2_response_data_attributes import PostFlowV2ResponseDataAttributes
    from openapi_client.models.post_flow_values_response_dto import PostFlowValuesResponseDTO
    from openapi_client.models.post_flow_values_response_dto_data import PostFlowValuesResponseDTOData
    from openapi_client.models.post_flow_values_response_dto_data_attributes import PostFlowValuesResponseDTODataAttributes
    from openapi_client.models.post_flow_values_response_dto_data_relationships import PostFlowValuesResponseDTODataRelationships
    from openapi_client.models.post_form_series_response_dto import PostFormSeriesResponseDTO
    from openapi_client.models.post_form_series_response_dto_data import PostFormSeriesResponseDTOData
    from openapi_client.models.post_form_series_response_dto_data_attributes import PostFormSeriesResponseDTODataAttributes
    from openapi_client.models.post_form_values_response_dto import PostFormValuesResponseDTO
    from openapi_client.models.post_form_values_response_dto_data import PostFormValuesResponseDTOData
    from openapi_client.models.post_form_values_response_dto_data_attributes import PostFormValuesResponseDTODataAttributes
    from openapi_client.models.post_image_response import PostImageResponse
    from openapi_client.models.post_image_response_data import PostImageResponseData
    from openapi_client.models.post_image_response_data_attributes import PostImageResponseDataAttributes
    from openapi_client.models.post_list_create_response import PostListCreateResponse
    from openapi_client.models.post_list_create_response_data import PostListCreateResponseData
    from openapi_client.models.post_list_create_response_data_relationships import PostListCreateResponseDataRelationships
    from openapi_client.models.post_list_create_response_data_relationships_profiles import PostListCreateResponseDataRelationshipsProfiles
    from openapi_client.models.post_list_create_response_data_relationships_profiles_data_inner import PostListCreateResponseDataRelationshipsProfilesDataInner
    from openapi_client.models.post_metric_aggregate_response import PostMetricAggregateResponse
    from openapi_client.models.post_metric_aggregate_response_data import PostMetricAggregateResponseData
    from openapi_client.models.post_metric_aggregate_response_data_attributes import PostMetricAggregateResponseDataAttributes
    from openapi_client.models.post_profile_import_job_response import PostProfileImportJobResponse
    from openapi_client.models.post_profile_import_job_response_data import PostProfileImportJobResponseData
    from openapi_client.models.post_profile_import_job_response_data_attributes import PostProfileImportJobResponseDataAttributes
    from openapi_client.models.post_profile_import_job_response_data_relationships import PostProfileImportJobResponseDataRelationships
    from openapi_client.models.post_profile_import_job_response_data_relationships_import_errors import PostProfileImportJobResponseDataRelationshipsImportErrors
    from openapi_client.models.post_profile_import_job_response_data_relationships_import_errors_data_inner import PostProfileImportJobResponseDataRelationshipsImportErrorsDataInner
    from openapi_client.models.post_profile_import_job_response_data_relationships_profiles import PostProfileImportJobResponseDataRelationshipsProfiles
    from openapi_client.models.post_profile_import_job_response_data_relationships_profiles_data_inner import PostProfileImportJobResponseDataRelationshipsProfilesDataInner
    from openapi_client.models.post_profile_merge_response import PostProfileMergeResponse
    from openapi_client.models.post_profile_merge_response_data import PostProfileMergeResponseData
    from openapi_client.models.post_profile_response import PostProfileResponse
    from openapi_client.models.post_profile_response_data import PostProfileResponseData
    from openapi_client.models.post_profile_response_data_attributes import PostProfileResponseDataAttributes
    from openapi_client.models.post_segment_create_response import PostSegmentCreateResponse
    from openapi_client.models.post_segment_create_response_data import PostSegmentCreateResponseData
    from openapi_client.models.post_segment_series_response_dto import PostSegmentSeriesResponseDTO
    from openapi_client.models.post_segment_series_response_dto_data import PostSegmentSeriesResponseDTOData
    from openapi_client.models.post_segment_series_response_dto_data_attributes import PostSegmentSeriesResponseDTODataAttributes
    from openapi_client.models.post_segment_values_response_dto import PostSegmentValuesResponseDTO
    from openapi_client.models.post_segment_values_response_dto_data import PostSegmentValuesResponseDTOData
    from openapi_client.models.post_segment_values_response_dto_data_attributes import PostSegmentValuesResponseDTODataAttributes
    from openapi_client.models.post_tag_group_response import PostTagGroupResponse
    from openapi_client.models.post_tag_group_response_data import PostTagGroupResponseData
    from openapi_client.models.post_tag_group_response_data_attributes import PostTagGroupResponseDataAttributes
    from openapi_client.models.post_tag_group_response_data_relationships import PostTagGroupResponseDataRelationships
    from openapi_client.models.post_tag_response import PostTagResponse
    from openapi_client.models.post_tag_response_data import PostTagResponseData
    from openapi_client.models.post_tag_response_data_attributes import PostTagResponseDataAttributes
    from openapi_client.models.post_tag_response_data_relationships import PostTagResponseDataRelationships
    from openapi_client.models.post_tag_response_data_relationships_campaigns import PostTagResponseDataRelationshipsCampaigns
    from openapi_client.models.post_tag_response_data_relationships_campaigns_data_inner import PostTagResponseDataRelationshipsCampaignsDataInner
    from openapi_client.models.post_template_response import PostTemplateResponse
    from openapi_client.models.post_template_response_data import PostTemplateResponseData
    from openapi_client.models.post_template_response_data_attributes import PostTemplateResponseDataAttributes
    from openapi_client.models.post_universal_content_response import PostUniversalContentResponse
    from openapi_client.models.post_universal_content_response_data import PostUniversalContentResponseData
    from openapi_client.models.post_universal_content_response_data_attributes import PostUniversalContentResponseDataAttributes
    from openapi_client.models.post_web_feed_response import PostWebFeedResponse
    from openapi_client.models.post_web_feed_response_data import PostWebFeedResponseData
    from openapi_client.models.post_web_feed_response_data_attributes import PostWebFeedResponseDataAttributes
    from openapi_client.models.post_webhook_response import PostWebhookResponse
    from openapi_client.models.post_webhook_response_data import PostWebhookResponseData
    from openapi_client.models.post_webhook_response_data_attributes import PostWebhookResponseDataAttributes
    from openapi_client.models.predictive_analytics import PredictiveAnalytics
    from openapi_client.models.profile_bulk_import_job_enum import ProfileBulkImportJobEnum
    from openapi_client.models.profile_create_query import ProfileCreateQuery
    from openapi_client.models.profile_create_query_resource_object import ProfileCreateQueryResourceObject
    from openapi_client.models.profile_create_query_resource_object_attributes import ProfileCreateQueryResourceObjectAttributes
    from openapi_client.models.profile_enum import ProfileEnum
    from openapi_client.models.profile_identifier_dto_resource_object import ProfileIdentifierDTOResourceObject
    from openapi_client.models.profile_identifier_dto_resource_object_attributes import ProfileIdentifierDTOResourceObjectAttributes
    from openapi_client.models.profile_import_job_create_query import ProfileImportJobCreateQuery
    from openapi_client.models.profile_import_job_create_query_resource_object import ProfileImportJobCreateQueryResourceObject
    from openapi_client.models.profile_import_job_create_query_resource_object_attributes import ProfileImportJobCreateQueryResourceObjectAttributes
    from openapi_client.models.profile_import_job_create_query_resource_object_attributes_profiles import ProfileImportJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.profile_import_job_create_query_resource_object_relationships import ProfileImportJobCreateQueryResourceObjectRelationships
    from openapi_client.models.profile_import_job_create_query_resource_object_relationships_lists import ProfileImportJobCreateQueryResourceObjectRelationshipsLists
    from openapi_client.models.profile_import_job_create_query_resource_object_relationships_lists_data_inner import ProfileImportJobCreateQueryResourceObjectRelationshipsListsDataInner
    from openapi_client.models.profile_import_job_response_object_resource import ProfileImportJobResponseObjectResource
    from openapi_client.models.profile_import_job_response_object_resource_attributes import ProfileImportJobResponseObjectResourceAttributes
    from openapi_client.models.profile_location import ProfileLocation
    from openapi_client.models.profile_merge_enum import ProfileMergeEnum
    from openapi_client.models.profile_merge_query import ProfileMergeQuery
    from openapi_client.models.profile_merge_query_resource_object import ProfileMergeQueryResourceObject
    from openapi_client.models.profile_merge_query_resource_object_relationships import ProfileMergeQueryResourceObjectRelationships
    from openapi_client.models.profile_merge_query_resource_object_relationships_profiles import ProfileMergeQueryResourceObjectRelationshipsProfiles
    from openapi_client.models.profile_merge_query_resource_object_relationships_profiles_data_inner import ProfileMergeQueryResourceObjectRelationshipsProfilesDataInner
    from openapi_client.models.profile_meta import ProfileMeta
    from openapi_client.models.profile_meta_patch_properties import ProfileMetaPatchProperties
    from openapi_client.models.profile_partial_update_query import ProfilePartialUpdateQuery
    from openapi_client.models.profile_partial_update_query_resource_object import ProfilePartialUpdateQueryResourceObject
    from openapi_client.models.profile_partial_update_query_resource_object_attributes import ProfilePartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.profile_response_object_resource import ProfileResponseObjectResource
    from openapi_client.models.profile_response_object_resource_attributes import ProfileResponseObjectResourceAttributes
    from openapi_client.models.profile_response_object_resource_extended import ProfileResponseObjectResourceExtended
    from openapi_client.models.profile_response_object_resource_extended_attributes import ProfileResponseObjectResourceExtendedAttributes
    from openapi_client.models.profile_subscription_bulk_create_job_enum import ProfileSubscriptionBulkCreateJobEnum
    from openapi_client.models.profile_subscription_bulk_delete_job_enum import ProfileSubscriptionBulkDeleteJobEnum
    from openapi_client.models.profile_subscription_create_query_resource_object import ProfileSubscriptionCreateQueryResourceObject
    from openapi_client.models.profile_subscription_create_query_resource_object_attributes import ProfileSubscriptionCreateQueryResourceObjectAttributes
    from openapi_client.models.profile_subscription_delete_query_resource_object import ProfileSubscriptionDeleteQueryResourceObject
    from openapi_client.models.profile_subscription_delete_query_resource_object_attributes import ProfileSubscriptionDeleteQueryResourceObjectAttributes
    from openapi_client.models.profile_suppression_bulk_create_job_enum import ProfileSuppressionBulkCreateJobEnum
    from openapi_client.models.profile_suppression_bulk_delete_job_enum import ProfileSuppressionBulkDeleteJobEnum
    from openapi_client.models.profile_suppression_create_query_resource_object import ProfileSuppressionCreateQueryResourceObject
    from openapi_client.models.profile_suppression_create_query_resource_object_attributes import ProfileSuppressionCreateQueryResourceObjectAttributes
    from openapi_client.models.profile_suppression_delete_query_resource_object import ProfileSuppressionDeleteQueryResourceObject
    from openapi_client.models.profile_suppression_delete_query_resource_object_attributes import ProfileSuppressionDeleteQueryResourceObjectAttributes
    from openapi_client.models.profile_upsert_query import ProfileUpsertQuery
    from openapi_client.models.profile_upsert_query_resource_object import ProfileUpsertQueryResourceObject
    from openapi_client.models.profile_upsert_query_resource_object_attributes import ProfileUpsertQueryResourceObjectAttributes
    from openapi_client.models.push_channel import PushChannel
    from openapi_client.models.push_marketing import PushMarketing
    from openapi_client.models.push_profile_upsert_query_resource_object import PushProfileUpsertQueryResourceObject
    from openapi_client.models.push_profile_upsert_query_resource_object_attributes import PushProfileUpsertQueryResourceObjectAttributes
    from openapi_client.models.push_token_create_query import PushTokenCreateQuery
    from openapi_client.models.push_token_create_query_resource_object import PushTokenCreateQueryResourceObject
    from openapi_client.models.push_token_create_query_resource_object_attributes import PushTokenCreateQueryResourceObjectAttributes
    from openapi_client.models.push_token_create_query_resource_object_attributes_profile import PushTokenCreateQueryResourceObjectAttributesProfile
    from openapi_client.models.push_token_enum import PushTokenEnum
    from openapi_client.models.push_token_response_object_resource import PushTokenResponseObjectResource
    from openapi_client.models.push_token_response_object_resource_attributes import PushTokenResponseObjectResourceAttributes
    from openapi_client.models.relationship_links import RelationshipLinks
    from openapi_client.models.render_options_sub_object import RenderOptionsSubObject
    from openapi_client.models.review_enum import ReviewEnum
    from openapi_client.models.review_patch_query import ReviewPatchQuery
    from openapi_client.models.review_patch_query_resource_object import ReviewPatchQueryResourceObject
    from openapi_client.models.review_patch_query_resource_object_attributes import ReviewPatchQueryResourceObjectAttributes
    from openapi_client.models.review_product_dto import ReviewProductDTO
    from openapi_client.models.review_public_reply import ReviewPublicReply
    from openapi_client.models.review_response_dto_object_resource import ReviewResponseDTOObjectResource
    from openapi_client.models.review_response_dto_object_resource_attributes import ReviewResponseDTOObjectResourceAttributes
    from openapi_client.models.sms_channel import SMSChannel
    from openapi_client.models.sms_marketing import SMSMarketing
    from openapi_client.models.sms_render_options import SMSRenderOptions
    from openapi_client.models.sms_subscription_parameters import SMSSubscriptionParameters
    from openapi_client.models.sms_transactional import SMSTransactional
    from openapi_client.models.sms_unsubscription_parameters import SMSUnsubscriptionParameters
    from openapi_client.models.segment_create_query import SegmentCreateQuery
    from openapi_client.models.segment_create_query_resource_object import SegmentCreateQueryResourceObject
    from openapi_client.models.segment_create_query_resource_object_attributes import SegmentCreateQueryResourceObjectAttributes
    from openapi_client.models.segment_definition import SegmentDefinition
    from openapi_client.models.segment_enum import SegmentEnum
    from openapi_client.models.segment_list_response_object_resource import SegmentListResponseObjectResource
    from openapi_client.models.segment_list_response_object_resource_attributes import SegmentListResponseObjectResourceAttributes
    from openapi_client.models.segment_member_response_object_resource_attributes import SegmentMemberResponseObjectResourceAttributes
    from openapi_client.models.segment_member_response_object_resource_extended import SegmentMemberResponseObjectResourceExtended
    from openapi_client.models.segment_member_response_object_resource_extended_attributes import SegmentMemberResponseObjectResourceExtendedAttributes
    from openapi_client.models.segment_partial_update_query import SegmentPartialUpdateQuery
    from openapi_client.models.segment_partial_update_query_resource_object import SegmentPartialUpdateQueryResourceObject
    from openapi_client.models.segment_partial_update_query_resource_object_attributes import SegmentPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.segment_response_object_resource import SegmentResponseObjectResource
    from openapi_client.models.segment_retrieve_response_object_resource_attributes import SegmentRetrieveResponseObjectResourceAttributes
    from openapi_client.models.segment_retrieve_response_object_resource_extended import SegmentRetrieveResponseObjectResourceExtended
    from openapi_client.models.segment_retrieve_response_object_resource_extended_attributes import SegmentRetrieveResponseObjectResourceExtendedAttributes
    from openapi_client.models.segment_series_report_enum import SegmentSeriesReportEnum
    from openapi_client.models.segment_series_request_dto import SegmentSeriesRequestDTO
    from openapi_client.models.segment_series_request_dto_resource_object import SegmentSeriesRequestDTOResourceObject
    from openapi_client.models.segment_series_request_dto_resource_object_attributes import SegmentSeriesRequestDTOResourceObjectAttributes
    from openapi_client.models.segment_values_report_enum import SegmentValuesReportEnum
    from openapi_client.models.segment_values_request_dto import SegmentValuesRequestDTO
    from openapi_client.models.segment_values_request_dto_resource_object import SegmentValuesRequestDTOResourceObject
    from openapi_client.models.segment_values_request_dto_resource_object_attributes import SegmentValuesRequestDTOResourceObjectAttributes
    from openapi_client.models.send_options import SendOptions
    from openapi_client.models.send_time import SendTime
    from openapi_client.models.send_time_sub_object import SendTimeSubObject
    from openapi_client.models.series_data import SeriesData
    from openapi_client.models.server_bis_subscription_create_query import ServerBISSubscriptionCreateQuery
    from openapi_client.models.server_bis_subscription_create_query_resource_object import ServerBISSubscriptionCreateQueryResourceObject
    from openapi_client.models.server_bis_subscription_create_query_resource_object_attributes import ServerBISSubscriptionCreateQueryResourceObjectAttributes
    from openapi_client.models.server_bis_subscription_create_query_resource_object_attributes_profile import ServerBISSubscriptionCreateQueryResourceObjectAttributesProfile
    from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships import ServerBISSubscriptionCreateQueryResourceObjectRelationships
    from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships_variant import ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariant
    from openapi_client.models.server_bis_subscription_create_query_resource_object_relationships_variant_data import ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData
    from openapi_client.models.street_address import StreetAddress
    from openapi_client.models.subscription_channels import SubscriptionChannels
    from openapi_client.models.subscription_create_job_create_query import SubscriptionCreateJobCreateQuery
    from openapi_client.models.subscription_create_job_create_query_resource_object import SubscriptionCreateJobCreateQueryResourceObject
    from openapi_client.models.subscription_create_job_create_query_resource_object_attributes import SubscriptionCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.subscription_create_job_create_query_resource_object_attributes_profiles import SubscriptionCreateJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.subscription_create_job_create_query_resource_object_relationships import SubscriptionCreateJobCreateQueryResourceObjectRelationships
    from openapi_client.models.subscription_create_job_create_query_resource_object_relationships_list import SubscriptionCreateJobCreateQueryResourceObjectRelationshipsList
    from openapi_client.models.subscription_create_job_create_query_resource_object_relationships_list_data import SubscriptionCreateJobCreateQueryResourceObjectRelationshipsListData
    from openapi_client.models.subscription_delete_job_create_query import SubscriptionDeleteJobCreateQuery
    from openapi_client.models.subscription_delete_job_create_query_resource_object import SubscriptionDeleteJobCreateQueryResourceObject
    from openapi_client.models.subscription_delete_job_create_query_resource_object_attributes import SubscriptionDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.subscription_delete_job_create_query_resource_object_attributes_profiles import SubscriptionDeleteJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships import SubscriptionDeleteJobCreateQueryResourceObjectRelationships
    from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships_list import SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsList
    from openapi_client.models.subscription_delete_job_create_query_resource_object_relationships_list_data import SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsListData
    from openapi_client.models.subscription_parameters import SubscriptionParameters
    from openapi_client.models.subscriptions import Subscriptions
    from openapi_client.models.suppression_create_job_create_query import SuppressionCreateJobCreateQuery
    from openapi_client.models.suppression_create_job_create_query_resource_object import SuppressionCreateJobCreateQueryResourceObject
    from openapi_client.models.suppression_create_job_create_query_resource_object_attributes import SuppressionCreateJobCreateQueryResourceObjectAttributes
    from openapi_client.models.suppression_create_job_create_query_resource_object_attributes_profiles import SuppressionCreateJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships import SuppressionCreateJobCreateQueryResourceObjectRelationships
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_list import SuppressionCreateJobCreateQueryResourceObjectRelationshipsList
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_list_data import SuppressionCreateJobCreateQueryResourceObjectRelationshipsListData
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_segment import SuppressionCreateJobCreateQueryResourceObjectRelationshipsSegment
    from openapi_client.models.suppression_create_job_create_query_resource_object_relationships_segment_data import SuppressionCreateJobCreateQueryResourceObjectRelationshipsSegmentData
    from openapi_client.models.suppression_delete_job_create_query import SuppressionDeleteJobCreateQuery
    from openapi_client.models.suppression_delete_job_create_query_resource_object import SuppressionDeleteJobCreateQueryResourceObject
    from openapi_client.models.suppression_delete_job_create_query_resource_object_attributes import SuppressionDeleteJobCreateQueryResourceObjectAttributes
    from openapi_client.models.suppression_delete_job_create_query_resource_object_attributes_profiles import SuppressionDeleteJobCreateQueryResourceObjectAttributesProfiles
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships import SuppressionDeleteJobCreateQueryResourceObjectRelationships
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_list import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsList
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_list_data import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsListData
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_segment import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsSegment
    from openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_segment_data import SuppressionDeleteJobCreateQueryResourceObjectRelationshipsSegmentData
    from openapi_client.models.tag_campaign_op import TagCampaignOp
    from openapi_client.models.tag_campaign_op_data_inner import TagCampaignOpDataInner
    from openapi_client.models.tag_create_query import TagCreateQuery
    from openapi_client.models.tag_create_query_resource_object import TagCreateQueryResourceObject
    from openapi_client.models.tag_create_query_resource_object_relationships import TagCreateQueryResourceObjectRelationships
    from openapi_client.models.tag_create_query_resource_object_relationships_tag_group import TagCreateQueryResourceObjectRelationshipsTagGroup
    from openapi_client.models.tag_create_query_resource_object_relationships_tag_group_data import TagCreateQueryResourceObjectRelationshipsTagGroupData
    from openapi_client.models.tag_enum import TagEnum
    from openapi_client.models.tag_flow_op import TagFlowOp
    from openapi_client.models.tag_flow_op_data_inner import TagFlowOpDataInner
    from openapi_client.models.tag_group_create_query import TagGroupCreateQuery
    from openapi_client.models.tag_group_create_query_resource_object import TagGroupCreateQueryResourceObject
    from openapi_client.models.tag_group_create_query_resource_object_attributes import TagGroupCreateQueryResourceObjectAttributes
    from openapi_client.models.tag_group_enum import TagGroupEnum
    from openapi_client.models.tag_group_response_object_resource import TagGroupResponseObjectResource
    from openapi_client.models.tag_group_response_object_resource_attributes import TagGroupResponseObjectResourceAttributes
    from openapi_client.models.tag_group_update_query import TagGroupUpdateQuery
    from openapi_client.models.tag_group_update_query_resource_object import TagGroupUpdateQueryResourceObject
    from openapi_client.models.tag_group_update_query_resource_object_attributes import TagGroupUpdateQueryResourceObjectAttributes
    from openapi_client.models.tag_list_op import TagListOp
    from openapi_client.models.tag_list_op_data_inner import TagListOpDataInner
    from openapi_client.models.tag_response_object_resource import TagResponseObjectResource
    from openapi_client.models.tag_response_object_resource_attributes import TagResponseObjectResourceAttributes
    from openapi_client.models.tag_segment_op import TagSegmentOp
    from openapi_client.models.tag_segment_op_data_inner import TagSegmentOpDataInner
    from openapi_client.models.tag_update_query import TagUpdateQuery
    from openapi_client.models.tag_update_query_resource_object import TagUpdateQueryResourceObject
    from openapi_client.models.template_clone_query import TemplateCloneQuery
    from openapi_client.models.template_clone_query_resource_object import TemplateCloneQueryResourceObject
    from openapi_client.models.template_clone_query_resource_object_attributes import TemplateCloneQueryResourceObjectAttributes
    from openapi_client.models.template_create_query import TemplateCreateQuery
    from openapi_client.models.template_create_query_resource_object import TemplateCreateQueryResourceObject
    from openapi_client.models.template_create_query_resource_object_attributes import TemplateCreateQueryResourceObjectAttributes
    from openapi_client.models.template_enum import TemplateEnum
    from openapi_client.models.template_render_query import TemplateRenderQuery
    from openapi_client.models.template_render_query_resource_object import TemplateRenderQueryResourceObject
    from openapi_client.models.template_render_query_resource_object_attributes import TemplateRenderQueryResourceObjectAttributes
    from openapi_client.models.template_response_object_resource import TemplateResponseObjectResource
    from openapi_client.models.template_response_object_resource_attributes import TemplateResponseObjectResourceAttributes
    from openapi_client.models.template_universal_content_enum import TemplateUniversalContentEnum
    from openapi_client.models.template_update_query import TemplateUpdateQuery
    from openapi_client.models.template_update_query_resource_object import TemplateUpdateQueryResourceObject
    from openapi_client.models.template_update_query_resource_object_attributes import TemplateUpdateQueryResourceObjectAttributes
    from openapi_client.models.tracking_param_dto import TrackingParamDTO
    from openapi_client.models.tracking_setting_enum import TrackingSettingEnum
    from openapi_client.models.tracking_setting_partial_update_query import TrackingSettingPartialUpdateQuery
    from openapi_client.models.tracking_setting_partial_update_query_resource_object import TrackingSettingPartialUpdateQueryResourceObject
    from openapi_client.models.tracking_setting_partial_update_query_resource_object_attributes import TrackingSettingPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.tracking_setting_response_object_resource import TrackingSettingResponseObjectResource
    from openapi_client.models.tracking_setting_response_object_resource_attributes import TrackingSettingResponseObjectResourceAttributes
    from openapi_client.models.universal_content_create_query import UniversalContentCreateQuery
    from openapi_client.models.universal_content_create_query_resource_object import UniversalContentCreateQueryResourceObject
    from openapi_client.models.universal_content_create_query_resource_object_attributes import UniversalContentCreateQueryResourceObjectAttributes
    from openapi_client.models.universal_content_partial_update_query import UniversalContentPartialUpdateQuery
    from openapi_client.models.universal_content_partial_update_query_resource_object import UniversalContentPartialUpdateQueryResourceObject
    from openapi_client.models.universal_content_partial_update_query_resource_object_attributes import UniversalContentPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.universal_content_response_object_resource import UniversalContentResponseObjectResource
    from openapi_client.models.universal_content_response_object_resource_attributes import UniversalContentResponseObjectResourceAttributes
    from openapi_client.models.unsubscription_channels import UnsubscriptionChannels
    from openapi_client.models.unsubscription_parameters import UnsubscriptionParameters
    from openapi_client.models.values_data import ValuesData
    from openapi_client.models.web_feed_create_query import WebFeedCreateQuery
    from openapi_client.models.web_feed_create_query_resource_object import WebFeedCreateQueryResourceObject
    from openapi_client.models.web_feed_create_query_resource_object_attributes import WebFeedCreateQueryResourceObjectAttributes
    from openapi_client.models.web_feed_enum import WebFeedEnum
    from openapi_client.models.web_feed_partial_update_query import WebFeedPartialUpdateQuery
    from openapi_client.models.web_feed_partial_update_query_resource_object import WebFeedPartialUpdateQueryResourceObject
    from openapi_client.models.web_feed_partial_update_query_resource_object_attributes import WebFeedPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.web_feed_response_object_resource import WebFeedResponseObjectResource
    from openapi_client.models.web_feed_response_object_resource_attributes import WebFeedResponseObjectResourceAttributes
    from openapi_client.models.webhook_create_query import WebhookCreateQuery
    from openapi_client.models.webhook_create_query_resource_object import WebhookCreateQueryResourceObject
    from openapi_client.models.webhook_create_query_resource_object_attributes import WebhookCreateQueryResourceObjectAttributes
    from openapi_client.models.webhook_create_query_resource_object_relationships import WebhookCreateQueryResourceObjectRelationships
    from openapi_client.models.webhook_create_query_resource_object_relationships_webhook_topics import WebhookCreateQueryResourceObjectRelationshipsWebhookTopics
    from openapi_client.models.webhook_create_query_resource_object_relationships_webhook_topics_data_inner import WebhookCreateQueryResourceObjectRelationshipsWebhookTopicsDataInner
    from openapi_client.models.webhook_enum import WebhookEnum
    from openapi_client.models.webhook_partial_update_query import WebhookPartialUpdateQuery
    from openapi_client.models.webhook_partial_update_query_resource_object import WebhookPartialUpdateQueryResourceObject
    from openapi_client.models.webhook_partial_update_query_resource_object_attributes import WebhookPartialUpdateQueryResourceObjectAttributes
    from openapi_client.models.webhook_partial_update_query_resource_object_relationships import WebhookPartialUpdateQueryResourceObjectRelationships
    from openapi_client.models.webhook_response_object_resource import WebhookResponseObjectResource
    from openapi_client.models.webhook_response_object_resource_attributes import WebhookResponseObjectResourceAttributes
    from openapi_client.models.webhook_topic_enum import WebhookTopicEnum
    from openapi_client.models.webhook_topic_response_object_resource import WebhookTopicResponseObjectResource

# lazy imports for performance (see https://docs.python.org/3/reference/datamodel.html#customizing-module-attribute-access)

object_origins = {
    # import apis into sdk package
    "AccountsApi": "openapi_client.api.accounts_api",
    "CampaignsApi": "openapi_client.api.campaigns_api",
    "CatalogsApi": "openapi_client.api.catalogs_api",
    "CouponsApi": "openapi_client.api.coupons_api",
    "DataPrivacyApi": "openapi_client.api.data_privacy_api",
    "EventsApi": "openapi_client.api.events_api",
    "FlowsApi": "openapi_client.api.flows_api",
    "FormsApi": "openapi_client.api.forms_api",
    "ImagesApi": "openapi_client.api.images_api",
    "ListsApi": "openapi_client.api.lists_api",
    "MetricsApi": "openapi_client.api.metrics_api",
    "ProfilesApi": "openapi_client.api.profiles_api",
    "ReportingApi": "openapi_client.api.reporting_api",
    "ReviewsApi": "openapi_client.api.reviews_api",
    "SegmentsApi": "openapi_client.api.segments_api",
    "TagsApi": "openapi_client.api.tags_api",
    "TemplatesApi": "openapi_client.api.templates_api",
    "TrackingSettingsApi": "openapi_client.api.tracking_settings_api",
    "WebFeedsApi": "openapi_client.api.web_feeds_api",
    "WebhooksApi": "openapi_client.api.webhooks_api",
    

    # import ApiClient
    "ApiResponse": "openapi_client.api_response",
    "ApiClient": "openapi_client.api_client",
    "Configuration": "openapi_client.configuration",
    "OpenApiException": "openapi_client.exceptions",
    "ApiTypeError": "openapi_client.exceptions",
    "ApiValueError": "openapi_client.exceptions",
    "ApiKeyError": "openapi_client.exceptions",
    "ApiAttributeError": "openapi_client.exceptions",
    "ApiException": "openapi_client.exceptions",

    
    # import models into sdk package
    "APIJobErrorPayload": "openapi_client.models.api_job_error_payload",
    "AccountEnum": "openapi_client.models.account_enum",
    "AccountResponseObjectResource": "openapi_client.models.account_response_object_resource",
    "AccountResponseObjectResourceAttributes": "openapi_client.models.account_response_object_resource_attributes",
    "AttributionEnum": "openapi_client.models.attribution_enum",
    "Audiences": "openapi_client.models.audiences",
    "AudiencesUpdate": "openapi_client.models.audiences_update",
    "BackInStockSubscriptionEnum": "openapi_client.models.back_in_stock_subscription_enum",
    "BaseEventCreateQueryBulkEntryResourceObject": "openapi_client.models.base_event_create_query_bulk_entry_resource_object",
    "BaseEventCreateQueryBulkEntryResourceObjectAttributes": "openapi_client.models.base_event_create_query_bulk_entry_resource_object_attributes",
    "BulkProfileSuppressionsCreateJobResponseObjectResource": "openapi_client.models.bulk_profile_suppressions_create_job_response_object_resource",
    "BulkProfileSuppressionsCreateJobResponseObjectResourceAttributes": "openapi_client.models.bulk_profile_suppressions_create_job_response_object_resource_attributes",
    "BulkProfileSuppressionsRemoveJobResponseObjectResource": "openapi_client.models.bulk_profile_suppressions_remove_job_response_object_resource",
    "CampaignCloneQuery": "openapi_client.models.campaign_clone_query",
    "CampaignCloneQueryResourceObject": "openapi_client.models.campaign_clone_query_resource_object",
    "CampaignCloneQueryResourceObjectAttributes": "openapi_client.models.campaign_clone_query_resource_object_attributes",
    "CampaignCreateQuery": "openapi_client.models.campaign_create_query",
    "CampaignCreateQueryResourceObject": "openapi_client.models.campaign_create_query_resource_object",
    "CampaignCreateQueryResourceObjectAttributes": "openapi_client.models.campaign_create_query_resource_object_attributes",
    "CampaignCreateQueryResourceObjectAttributesCampaignMessages": "openapi_client.models.campaign_create_query_resource_object_attributes_campaign_messages",
    "CampaignEnum": "openapi_client.models.campaign_enum",
    "CampaignMessageAssignTemplateQuery": "openapi_client.models.campaign_message_assign_template_query",
    "CampaignMessageAssignTemplateQueryResourceObject": "openapi_client.models.campaign_message_assign_template_query_resource_object",
    "CampaignMessageAssignTemplateQueryResourceObjectRelationships": "openapi_client.models.campaign_message_assign_template_query_resource_object_relationships",
    "CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplate": "openapi_client.models.campaign_message_assign_template_query_resource_object_relationships_template",
    "CampaignMessageAssignTemplateQueryResourceObjectRelationshipsTemplateData": "openapi_client.models.campaign_message_assign_template_query_resource_object_relationships_template_data",
    "CampaignMessageCreateQueryResourceObject": "openapi_client.models.campaign_message_create_query_resource_object",
    "CampaignMessageCreateQueryResourceObjectAttributes": "openapi_client.models.campaign_message_create_query_resource_object_attributes",
    "CampaignMessageCreateQueryResourceObjectRelationships": "openapi_client.models.campaign_message_create_query_resource_object_relationships",
    "CampaignMessageCreateQueryResourceObjectRelationshipsImage": "openapi_client.models.campaign_message_create_query_resource_object_relationships_image",
    "CampaignMessageCreateQueryResourceObjectRelationshipsImageData": "openapi_client.models.campaign_message_create_query_resource_object_relationships_image_data",
    "CampaignMessageEnum": "openapi_client.models.campaign_message_enum",
    "CampaignMessageImageUpdateQuery": "openapi_client.models.campaign_message_image_update_query",
    "CampaignMessageImageUpdateQueryData": "openapi_client.models.campaign_message_image_update_query_data",
    "CampaignMessagePartialUpdateQuery": "openapi_client.models.campaign_message_partial_update_query",
    "CampaignMessagePartialUpdateQueryResourceObject": "openapi_client.models.campaign_message_partial_update_query_resource_object",
    "CampaignMessagePartialUpdateQueryResourceObjectAttributes": "openapi_client.models.campaign_message_partial_update_query_resource_object_attributes",
    "CampaignMessageResponseObjectResource": "openapi_client.models.campaign_message_response_object_resource",
    "CampaignMessageResponseObjectResourceAttributes": "openapi_client.models.campaign_message_response_object_resource_attributes",
    "CampaignPartialUpdateQuery": "openapi_client.models.campaign_partial_update_query",
    "CampaignPartialUpdateQueryResourceObject": "openapi_client.models.campaign_partial_update_query_resource_object",
    "CampaignPartialUpdateQueryResourceObjectAttributes": "openapi_client.models.campaign_partial_update_query_resource_object_attributes",
    "CampaignRecipientEstimationEnum": "openapi_client.models.campaign_recipient_estimation_enum",
    "CampaignRecipientEstimationJobCreateQuery": "openapi_client.models.campaign_recipient_estimation_job_create_query",
    "CampaignRecipientEstimationJobCreateQueryResourceObject": "openapi_client.models.campaign_recipient_estimation_job_create_query_resource_object",
    "CampaignRecipientEstimationJobEnum": "openapi_client.models.campaign_recipient_estimation_job_enum",
    "CampaignRecipientEstimationJobResponseObjectResource": "openapi_client.models.campaign_recipient_estimation_job_response_object_resource",
    "CampaignRecipientEstimationJobResponseObjectResourceAttributes": "openapi_client.models.campaign_recipient_estimation_job_response_object_resource_attributes",
    "CampaignRecipientEstimationResponseObjectResource": "openapi_client.models.campaign_recipient_estimation_response_object_resource",
    "CampaignRecipientEstimationResponseObjectResourceAttributes": "openapi_client.models.campaign_recipient_estimation_response_object_resource_attributes",
    "CampaignResponseObjectResource": "openapi_client.models.campaign_response_object_resource",
    "CampaignResponseObjectResourceAttributes": "openapi_client.models.campaign_response_object_resource_attributes",
    "CampaignSendJobCreateQuery": "openapi_client.models.campaign_send_job_create_query",
    "CampaignSendJobCreateQueryResourceObject": "openapi_client.models.campaign_send_job_create_query_resource_object",
    "CampaignSendJobEnum": "openapi_client.models.campaign_send_job_enum",
    "CampaignSendJobPartialUpdateQuery": "openapi_client.models.campaign_send_job_partial_update_query",
    "CampaignSendJobPartialUpdateQueryResourceObject": "openapi_client.models.campaign_send_job_partial_update_query_resource_object",
    "CampaignSendJobPartialUpdateQueryResourceObjectAttributes": "openapi_client.models.campaign_send_job_partial_update_query_resource_object_attributes",
    "CampaignSendJobResponseObjectResource": "openapi_client.models.campaign_send_job_response_object_resource",
    "CampaignSendJobResponseObjectResourceAttributes": "openapi_client.models.campaign_send_job_response_object_resource_attributes",
    "CampaignValuesReportEnum": "openapi_client.models.campaign_values_report_enum",
    "CampaignValuesRequestDTO": "openapi_client.models.campaign_values_request_dto",
    "CampaignValuesRequestDTOResourceObject": "openapi_client.models.campaign_values_request_dto_resource_object",
    "CampaignValuesRequestDTOResourceObjectAttributes": "openapi_client.models.campaign_values_request_dto_resource_object_attributes",
    "CatalogCategoryBulkCreateJobEnum": "openapi_client.models.catalog_category_bulk_create_job_enum",
    "CatalogCategoryBulkDeleteJobEnum": "openapi_client.models.catalog_category_bulk_delete_job_enum",
    "CatalogCategoryBulkUpdateJobEnum": "openapi_client.models.catalog_category_bulk_update_job_enum",
    "CatalogCategoryCreateJobCreateQuery": "openapi_client.models.catalog_category_create_job_create_query",
    "CatalogCategoryCreateJobCreateQueryResourceObject": "openapi_client.models.catalog_category_create_job_create_query_resource_object",
    "CatalogCategoryCreateJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_category_create_job_create_query_resource_object_attributes",
    "CatalogCategoryCreateJobCreateQueryResourceObjectAttributesCategories": "openapi_client.models.catalog_category_create_job_create_query_resource_object_attributes_categories",
    "CatalogCategoryCreateJobResponseObjectResource": "openapi_client.models.catalog_category_create_job_response_object_resource",
    "CatalogCategoryCreateQuery": "openapi_client.models.catalog_category_create_query",
    "CatalogCategoryCreateQueryResourceObject": "openapi_client.models.catalog_category_create_query_resource_object",
    "CatalogCategoryCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_category_create_query_resource_object_attributes",
    "CatalogCategoryCreateQueryResourceObjectRelationships": "openapi_client.models.catalog_category_create_query_resource_object_relationships",
    "CatalogCategoryCreateQueryResourceObjectRelationshipsItems": "openapi_client.models.catalog_category_create_query_resource_object_relationships_items",
    "CatalogCategoryDeleteJobCreateQuery": "openapi_client.models.catalog_category_delete_job_create_query",
    "CatalogCategoryDeleteJobCreateQueryResourceObject": "openapi_client.models.catalog_category_delete_job_create_query_resource_object",
    "CatalogCategoryDeleteJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_category_delete_job_create_query_resource_object_attributes",
    "CatalogCategoryDeleteJobCreateQueryResourceObjectAttributesCategories": "openapi_client.models.catalog_category_delete_job_create_query_resource_object_attributes_categories",
    "CatalogCategoryDeleteJobResponseObjectResource": "openapi_client.models.catalog_category_delete_job_response_object_resource",
    "CatalogCategoryDeleteQueryResourceObject": "openapi_client.models.catalog_category_delete_query_resource_object",
    "CatalogCategoryEnum": "openapi_client.models.catalog_category_enum",
    "CatalogCategoryItemOp": "openapi_client.models.catalog_category_item_op",
    "CatalogCategoryItemOpDataInner": "openapi_client.models.catalog_category_item_op_data_inner",
    "CatalogCategoryResponseObjectResource": "openapi_client.models.catalog_category_response_object_resource",
    "CatalogCategoryResponseObjectResourceAttributes": "openapi_client.models.catalog_category_response_object_resource_attributes",
    "CatalogCategoryUpdateJobCreateQuery": "openapi_client.models.catalog_category_update_job_create_query",
    "CatalogCategoryUpdateJobCreateQueryResourceObject": "openapi_client.models.catalog_category_update_job_create_query_resource_object",
    "CatalogCategoryUpdateJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_category_update_job_create_query_resource_object_attributes",
    "CatalogCategoryUpdateJobCreateQueryResourceObjectAttributesCategories": "openapi_client.models.catalog_category_update_job_create_query_resource_object_attributes_categories",
    "CatalogCategoryUpdateJobResponseObjectResource": "openapi_client.models.catalog_category_update_job_response_object_resource",
    "CatalogCategoryUpdateQuery": "openapi_client.models.catalog_category_update_query",
    "CatalogCategoryUpdateQueryResourceObject": "openapi_client.models.catalog_category_update_query_resource_object",
    "CatalogCategoryUpdateQueryResourceObjectAttributes": "openapi_client.models.catalog_category_update_query_resource_object_attributes",
    "CatalogItemBulkCreateJobEnum": "openapi_client.models.catalog_item_bulk_create_job_enum",
    "CatalogItemBulkDeleteJobEnum": "openapi_client.models.catalog_item_bulk_delete_job_enum",
    "CatalogItemBulkUpdateJobEnum": "openapi_client.models.catalog_item_bulk_update_job_enum",
    "CatalogItemCategoryOp": "openapi_client.models.catalog_item_category_op",
    "CatalogItemCreateJobCreateQuery": "openapi_client.models.catalog_item_create_job_create_query",
    "CatalogItemCreateJobCreateQueryResourceObject": "openapi_client.models.catalog_item_create_job_create_query_resource_object",
    "CatalogItemCreateJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_item_create_job_create_query_resource_object_attributes",
    "CatalogItemCreateJobCreateQueryResourceObjectAttributesItems": "openapi_client.models.catalog_item_create_job_create_query_resource_object_attributes_items",
    "CatalogItemCreateJobResponseObjectResource": "openapi_client.models.catalog_item_create_job_response_object_resource",
    "CatalogItemCreateQuery": "openapi_client.models.catalog_item_create_query",
    "CatalogItemCreateQueryResourceObject": "openapi_client.models.catalog_item_create_query_resource_object",
    "CatalogItemCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_item_create_query_resource_object_attributes",
    "CatalogItemCreateQueryResourceObjectRelationships": "openapi_client.models.catalog_item_create_query_resource_object_relationships",
    "CatalogItemCreateQueryResourceObjectRelationshipsCategories": "openapi_client.models.catalog_item_create_query_resource_object_relationships_categories",
    "CatalogItemCreateQueryResourceObjectRelationshipsCategoriesDataInner": "openapi_client.models.catalog_item_create_query_resource_object_relationships_categories_data_inner",
    "CatalogItemDeleteJobCreateQuery": "openapi_client.models.catalog_item_delete_job_create_query",
    "CatalogItemDeleteJobCreateQueryResourceObject": "openapi_client.models.catalog_item_delete_job_create_query_resource_object",
    "CatalogItemDeleteJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_item_delete_job_create_query_resource_object_attributes",
    "CatalogItemDeleteJobCreateQueryResourceObjectAttributesItems": "openapi_client.models.catalog_item_delete_job_create_query_resource_object_attributes_items",
    "CatalogItemDeleteJobResponseObjectResource": "openapi_client.models.catalog_item_delete_job_response_object_resource",
    "CatalogItemDeleteQueryResourceObject": "openapi_client.models.catalog_item_delete_query_resource_object",
    "CatalogItemEnum": "openapi_client.models.catalog_item_enum",
    "CatalogItemResponseObjectResource": "openapi_client.models.catalog_item_response_object_resource",
    "CatalogItemResponseObjectResourceAttributes": "openapi_client.models.catalog_item_response_object_resource_attributes",
    "CatalogItemUpdateJobCreateQuery": "openapi_client.models.catalog_item_update_job_create_query",
    "CatalogItemUpdateJobCreateQueryResourceObject": "openapi_client.models.catalog_item_update_job_create_query_resource_object",
    "CatalogItemUpdateJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_item_update_job_create_query_resource_object_attributes",
    "CatalogItemUpdateJobCreateQueryResourceObjectAttributesItems": "openapi_client.models.catalog_item_update_job_create_query_resource_object_attributes_items",
    "CatalogItemUpdateJobResponseObjectResource": "openapi_client.models.catalog_item_update_job_response_object_resource",
    "CatalogItemUpdateQuery": "openapi_client.models.catalog_item_update_query",
    "CatalogItemUpdateQueryResourceObject": "openapi_client.models.catalog_item_update_query_resource_object",
    "CatalogItemUpdateQueryResourceObjectAttributes": "openapi_client.models.catalog_item_update_query_resource_object_attributes",
    "CatalogVariantBulkCreateJobEnum": "openapi_client.models.catalog_variant_bulk_create_job_enum",
    "CatalogVariantBulkDeleteJobEnum": "openapi_client.models.catalog_variant_bulk_delete_job_enum",
    "CatalogVariantBulkUpdateJobEnum": "openapi_client.models.catalog_variant_bulk_update_job_enum",
    "CatalogVariantCreateJobCreateQuery": "openapi_client.models.catalog_variant_create_job_create_query",
    "CatalogVariantCreateJobCreateQueryResourceObject": "openapi_client.models.catalog_variant_create_job_create_query_resource_object",
    "CatalogVariantCreateJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_variant_create_job_create_query_resource_object_attributes",
    "CatalogVariantCreateJobCreateQueryResourceObjectAttributesVariants": "openapi_client.models.catalog_variant_create_job_create_query_resource_object_attributes_variants",
    "CatalogVariantCreateJobResponseObjectResource": "openapi_client.models.catalog_variant_create_job_response_object_resource",
    "CatalogVariantCreateQuery": "openapi_client.models.catalog_variant_create_query",
    "CatalogVariantCreateQueryResourceObject": "openapi_client.models.catalog_variant_create_query_resource_object",
    "CatalogVariantCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_variant_create_query_resource_object_attributes",
    "CatalogVariantCreateQueryResourceObjectRelationships": "openapi_client.models.catalog_variant_create_query_resource_object_relationships",
    "CatalogVariantCreateQueryResourceObjectRelationshipsItem": "openapi_client.models.catalog_variant_create_query_resource_object_relationships_item",
    "CatalogVariantCreateQueryResourceObjectRelationshipsItemData": "openapi_client.models.catalog_variant_create_query_resource_object_relationships_item_data",
    "CatalogVariantDeleteJobCreateQuery": "openapi_client.models.catalog_variant_delete_job_create_query",
    "CatalogVariantDeleteJobCreateQueryResourceObject": "openapi_client.models.catalog_variant_delete_job_create_query_resource_object",
    "CatalogVariantDeleteJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_variant_delete_job_create_query_resource_object_attributes",
    "CatalogVariantDeleteJobCreateQueryResourceObjectAttributesVariants": "openapi_client.models.catalog_variant_delete_job_create_query_resource_object_attributes_variants",
    "CatalogVariantDeleteJobResponseObjectResource": "openapi_client.models.catalog_variant_delete_job_response_object_resource",
    "CatalogVariantDeleteQueryResourceObject": "openapi_client.models.catalog_variant_delete_query_resource_object",
    "CatalogVariantEnum": "openapi_client.models.catalog_variant_enum",
    "CatalogVariantResponseObjectResource": "openapi_client.models.catalog_variant_response_object_resource",
    "CatalogVariantResponseObjectResourceAttributes": "openapi_client.models.catalog_variant_response_object_resource_attributes",
    "CatalogVariantUpdateJobCreateQuery": "openapi_client.models.catalog_variant_update_job_create_query",
    "CatalogVariantUpdateJobCreateQueryResourceObject": "openapi_client.models.catalog_variant_update_job_create_query_resource_object",
    "CatalogVariantUpdateJobCreateQueryResourceObjectAttributes": "openapi_client.models.catalog_variant_update_job_create_query_resource_object_attributes",
    "CatalogVariantUpdateJobCreateQueryResourceObjectAttributesVariants": "openapi_client.models.catalog_variant_update_job_create_query_resource_object_attributes_variants",
    "CatalogVariantUpdateJobResponseObjectResource": "openapi_client.models.catalog_variant_update_job_response_object_resource",
    "CatalogVariantUpdateQuery": "openapi_client.models.catalog_variant_update_query",
    "CatalogVariantUpdateQueryResourceObject": "openapi_client.models.catalog_variant_update_query_resource_object",
    "CatalogVariantUpdateQueryResourceObjectAttributes": "openapi_client.models.catalog_variant_update_query_resource_object_attributes",
    "CollectionLinks": "openapi_client.models.collection_links",
    "ConditionGroup": "openapi_client.models.condition_group",
    "ContactInformation": "openapi_client.models.contact_information",
    "CouponCodeBulkCreateJobEnum": "openapi_client.models.coupon_code_bulk_create_job_enum",
    "CouponCodeCreateJobCreateQuery": "openapi_client.models.coupon_code_create_job_create_query",
    "CouponCodeCreateJobCreateQueryResourceObject": "openapi_client.models.coupon_code_create_job_create_query_resource_object",
    "CouponCodeCreateJobCreateQueryResourceObjectAttributes": "openapi_client.models.coupon_code_create_job_create_query_resource_object_attributes",
    "CouponCodeCreateJobCreateQueryResourceObjectAttributesCouponCodes": "openapi_client.models.coupon_code_create_job_create_query_resource_object_attributes_coupon_codes",
    "CouponCodeCreateJobResponseObjectResource": "openapi_client.models.coupon_code_create_job_response_object_resource",
    "CouponCodeCreateJobResponseObjectResourceAttributes": "openapi_client.models.coupon_code_create_job_response_object_resource_attributes",
    "CouponCodeCreateQuery": "openapi_client.models.coupon_code_create_query",
    "CouponCodeCreateQueryResourceObject": "openapi_client.models.coupon_code_create_query_resource_object",
    "CouponCodeCreateQueryResourceObjectAttributes": "openapi_client.models.coupon_code_create_query_resource_object_attributes",
    "CouponCodeCreateQueryResourceObjectRelationships": "openapi_client.models.coupon_code_create_query_resource_object_relationships",
    "CouponCodeCreateQueryResourceObjectRelationshipsCoupon": "openapi_client.models.coupon_code_create_query_resource_object_relationships_coupon",
    "CouponCodeEnum": "openapi_client.models.coupon_code_enum",
    "CouponCodeResponseObjectResource": "openapi_client.models.coupon_code_response_object_resource",
    "CouponCodeResponseObjectResourceAttributes": "openapi_client.models.coupon_code_response_object_resource_attributes",
    "CouponCodeUpdateQuery": "openapi_client.models.coupon_code_update_query",
    "CouponCodeUpdateQueryResourceObject": "openapi_client.models.coupon_code_update_query_resource_object",
    "CouponCodeUpdateQueryResourceObjectAttributes": "openapi_client.models.coupon_code_update_query_resource_object_attributes",
    "CouponCreateQuery": "openapi_client.models.coupon_create_query",
    "CouponCreateQueryResourceObject": "openapi_client.models.coupon_create_query_resource_object",
    "CouponEnum": "openapi_client.models.coupon_enum",
    "CouponResponseObjectResource": "openapi_client.models.coupon_response_object_resource",
    "CouponResponseObjectResourceAttributes": "openapi_client.models.coupon_response_object_resource_attributes",
    "CouponUpdateQuery": "openapi_client.models.coupon_update_query",
    "CouponUpdateQueryResourceObject": "openapi_client.models.coupon_update_query_resource_object",
    "CouponUpdateQueryResourceObjectAttributes": "openapi_client.models.coupon_update_query_resource_object_attributes",
    "CustomMetricCondition": "openapi_client.models.custom_metric_condition",
    "CustomMetricCreateQuery": "openapi_client.models.custom_metric_create_query",
    "CustomMetricCreateQueryResourceObject": "openapi_client.models.custom_metric_create_query_resource_object",
    "CustomMetricCreateQueryResourceObjectAttributes": "openapi_client.models.custom_metric_create_query_resource_object_attributes",
    "CustomMetricDefinition": "openapi_client.models.custom_metric_definition",
    "CustomMetricEnum": "openapi_client.models.custom_metric_enum",
    "CustomMetricGroup": "openapi_client.models.custom_metric_group",
    "CustomMetricPartialUpdateQuery": "openapi_client.models.custom_metric_partial_update_query",
    "CustomMetricPartialUpdateQueryResourceObject": "openapi_client.models.custom_metric_partial_update_query_resource_object",
    "CustomMetricPartialUpdateQueryResourceObjectAttributes": "openapi_client.models.custom_metric_partial_update_query_resource_object_attributes",
    "CustomMetricResponseObjectResource": "openapi_client.models.custom_metric_response_object_resource",
    "CustomMetricResponseObjectResourceAttributes": "openapi_client.models.custom_metric_response_object_resource_attributes",
    "CustomTrackingParamDTO": "openapi_client.models.custom_tracking_param_dto",
    "DataPrivacyCreateDeletionJobQuery": "openapi_client.models.data_privacy_create_deletion_job_query",
    "DataPrivacyCreateDeletionJobQueryResourceObject": "openapi_client.models.data_privacy_create_deletion_job_query_resource_object",
    "DataPrivacyCreateDeletionJobQueryResourceObjectAttributes": "openapi_client.models.data_privacy_create_deletion_job_query_resource_object_attributes",
    "DataPrivacyCreateDeletionJobQueryResourceObjectAttributesProfile": "openapi_client.models.data_privacy_create_deletion_job_query_resource_object_attributes_profile",
    "DataPrivacyDeletionJobEnum": "openapi_client.models.data_privacy_deletion_job_enum",
    "DataPrivacyProfileQueryResourceObject": "openapi_client.models.data_privacy_profile_query_resource_object",
    "DataPrivacyProfileQueryResourceObjectAttributes": "openapi_client.models.data_privacy_profile_query_resource_object_attributes",
    "DeleteTagGroupResponse": "openapi_client.models.delete_tag_group_response",
    "DeviceMetadata": "openapi_client.models.device_metadata",
    "EmailChannel": "openapi_client.models.email_channel",
    "EmailMarketing": "openapi_client.models.email_marketing",
    "EmailMarketingListSuppression": "openapi_client.models.email_marketing_list_suppression",
    "EmailMarketingSuppression": "openapi_client.models.email_marketing_suppression",
    "EmailSubscriptionParameters": "openapi_client.models.email_subscription_parameters",
    "EmailUnsubscriptionParameters": "openapi_client.models.email_unsubscription_parameters",
    "ErrorSource": "openapi_client.models.error_source",
    "EventBulkCreateEnum": "openapi_client.models.event_bulk_create_enum",
    "EventBulkCreateJobEnum": "openapi_client.models.event_bulk_create_job_enum",
    "EventCreateQueryV2": "openapi_client.models.event_create_query_v2",
    "EventCreateQueryV2ResourceObject": "openapi_client.models.event_create_query_v2_resource_object",
    "EventCreateQueryV2ResourceObjectAttributes": "openapi_client.models.event_create_query_v2_resource_object_attributes",
    "EventCreateQueryV2ResourceObjectAttributesMetric": "openapi_client.models.event_create_query_v2_resource_object_attributes_metric",
    "EventCreateQueryV2ResourceObjectAttributesProfile": "openapi_client.models.event_create_query_v2_resource_object_attributes_profile",
    "EventEnum": "openapi_client.models.event_enum",
    "EventProfileCreateQueryResourceObject": "openapi_client.models.event_profile_create_query_resource_object",
    "EventProfileCreateQueryResourceObjectAttributes": "openapi_client.models.event_profile_create_query_resource_object_attributes",
    "EventResponseObjectResource": "openapi_client.models.event_response_object_resource",
    "EventResponseObjectResourceAttributes": "openapi_client.models.event_response_object_resource_attributes",
    "EventsBulkCreateJob": "openapi_client.models.events_bulk_create_job",
    "EventsBulkCreateJobResourceObject": "openapi_client.models.events_bulk_create_job_resource_object",
    "EventsBulkCreateJobResourceObjectAttributes": "openapi_client.models.events_bulk_create_job_resource_object_attributes",
    "EventsBulkCreateJobResourceObjectAttributesEventsBulkCreate": "openapi_client.models.events_bulk_create_job_resource_object_attributes_events_bulk_create",
    "EventsBulkCreateQueryResourceObject": "openapi_client.models.events_bulk_create_query_resource_object",
    "EventsBulkCreateQueryResourceObjectAttributes": "openapi_client.models.events_bulk_create_query_resource_object_attributes",
    "EventsBulkCreateQueryResourceObjectAttributesEvents": "openapi_client.models.events_bulk_create_query_resource_object_attributes_events",
    "EventsBulkCreateQueryResourceObjectAttributesProfile": "openapi_client.models.events_bulk_create_query_resource_object_attributes_profile",
    "FlowActionEnum": "openapi_client.models.flow_action_enum",
    "FlowActionResponseObjectResource": "openapi_client.models.flow_action_response_object_resource",
    "FlowActionResponseObjectResourceAttributes": "openapi_client.models.flow_action_response_object_resource_attributes",
    "FlowCreateQuery": "openapi_client.models.flow_create_query",
    "FlowCreateQueryResourceObject": "openapi_client.models.flow_create_query_resource_object",
    "FlowCreateQueryResourceObjectAttributes": "openapi_client.models.flow_create_query_resource_object_attributes",
    "FlowDefinition": "openapi_client.models.flow_definition",
    "FlowDefinitionProfileFilter": "openapi_client.models.flow_definition_profile_filter",
    "FlowDefinitionProfileFilterConditionGroupsInner": "openapi_client.models.flow_definition_profile_filter_condition_groups_inner",
    "FlowEnum": "openapi_client.models.flow_enum",
    "FlowMessageEnum": "openapi_client.models.flow_message_enum",
    "FlowMessageResponseObjectResource": "openapi_client.models.flow_message_response_object_resource",
    "FlowMessageResponseObjectResourceAttributes": "openapi_client.models.flow_message_response_object_resource_attributes",
    "FlowResponseObjectResource": "openapi_client.models.flow_response_object_resource",
    "FlowResponseObjectResourceAttributes": "openapi_client.models.flow_response_object_resource_attributes",
    "FlowSeriesReportEnum": "openapi_client.models.flow_series_report_enum",
    "FlowSeriesRequestDTO": "openapi_client.models.flow_series_request_dto",
    "FlowSeriesRequestDTOResourceObject": "openapi_client.models.flow_series_request_dto_resource_object",
    "FlowSeriesRequestDTOResourceObjectAttributes": "openapi_client.models.flow_series_request_dto_resource_object_attributes",
    "FlowUpdateQuery": "openapi_client.models.flow_update_query",
    "FlowUpdateQueryResourceObject": "openapi_client.models.flow_update_query_resource_object",
    "FlowUpdateQueryResourceObjectAttributes": "openapi_client.models.flow_update_query_resource_object_attributes",
    "FlowV2ResponseObjectResourceAttributes": "openapi_client.models.flow_v2_response_object_resource_attributes",
    "FlowV2ResponseObjectResourceExtended": "openapi_client.models.flow_v2_response_object_resource_extended",
    "FlowV2ResponseObjectResourceExtendedAttributes": "openapi_client.models.flow_v2_response_object_resource_extended_attributes",
    "FlowValuesReportEnum": "openapi_client.models.flow_values_report_enum",
    "FlowValuesRequestDTO": "openapi_client.models.flow_values_request_dto",
    "FlowValuesRequestDTOResourceObject": "openapi_client.models.flow_values_request_dto_resource_object",
    "FlowValuesRequestDTOResourceObjectAttributes": "openapi_client.models.flow_values_request_dto_resource_object_attributes",
    "FormEnum": "openapi_client.models.form_enum",
    "FormResponseObjectResource": "openapi_client.models.form_response_object_resource",
    "FormResponseObjectResourceAttributes": "openapi_client.models.form_response_object_resource_attributes",
    "FormSeriesReportEnum": "openapi_client.models.form_series_report_enum",
    "FormSeriesRequestDTO": "openapi_client.models.form_series_request_dto",
    "FormSeriesRequestDTOResourceObject": "openapi_client.models.form_series_request_dto_resource_object",
    "FormSeriesRequestDTOResourceObjectAttributes": "openapi_client.models.form_series_request_dto_resource_object_attributes",
    "FormValuesReportEnum": "openapi_client.models.form_values_report_enum",
    "FormValuesRequestDTO": "openapi_client.models.form_values_request_dto",
    "FormValuesRequestDTOResourceObject": "openapi_client.models.form_values_request_dto_resource_object",
    "FormValuesRequestDTOResourceObjectAttributes": "openapi_client.models.form_values_request_dto_resource_object_attributes",
    "FormVersionABTest": "openapi_client.models.form_version_ab_test",
    "FormVersionEnum": "openapi_client.models.form_version_enum",
    "FormVersionResponseObjectResource": "openapi_client.models.form_version_response_object_resource",
    "FormVersionResponseObjectResourceAttributes": "openapi_client.models.form_version_response_object_resource_attributes",
    "GetAccountResponse": "openapi_client.models.get_account_response",
    "GetAccountResponseCollection": "openapi_client.models.get_account_response_collection",
    "GetAccounts4XXResponse": "openapi_client.models.get_accounts4_xx_response",
    "GetAccounts4XXResponseErrorsInner": "openapi_client.models.get_accounts4_xx_response_errors_inner",
    "GetAccounts4XXResponseErrorsInnerSource": "openapi_client.models.get_accounts4_xx_response_errors_inner_source",
    "GetBulkProfileSuppressionsCreateJobResponse": "openapi_client.models.get_bulk_profile_suppressions_create_job_response",
    "GetBulkProfileSuppressionsCreateJobResponseCollection": "openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection",
    "GetBulkProfileSuppressionsCreateJobResponseCollectionDataInner": "openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection_data_inner",
    "GetBulkProfileSuppressionsCreateJobResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_bulk_profile_suppressions_create_job_response_collection_data_inner_all_of_relationships",
    "GetBulkProfileSuppressionsRemoveJobResponse": "openapi_client.models.get_bulk_profile_suppressions_remove_job_response",
    "GetBulkProfileSuppressionsRemoveJobResponseCollection": "openapi_client.models.get_bulk_profile_suppressions_remove_job_response_collection",
    "GetBulkProfileSuppressionsRemoveJobResponseCollectionDataInner": "openapi_client.models.get_bulk_profile_suppressions_remove_job_response_collection_data_inner",
    "GetCampaignMessageCampaignRelationshipResponse": "openapi_client.models.get_campaign_message_campaign_relationship_response",
    "GetCampaignMessageCampaignRelationshipResponseData": "openapi_client.models.get_campaign_message_campaign_relationship_response_data",
    "GetCampaignMessageImageRelationshipResponse": "openapi_client.models.get_campaign_message_image_relationship_response",
    "GetCampaignMessageImageRelationshipResponseData": "openapi_client.models.get_campaign_message_image_relationship_response_data",
    "GetCampaignMessageResponseCollectionCompoundDocument": "openapi_client.models.get_campaign_message_response_collection_compound_document",
    "GetCampaignMessageResponseCompoundDocument": "openapi_client.models.get_campaign_message_response_compound_document",
    "GetCampaignMessageResponseCompoundDocumentData": "openapi_client.models.get_campaign_message_response_compound_document_data",
    "GetCampaignMessageResponseCompoundDocumentDataAllOfRelationships": "openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships",
    "GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsCampaign": "openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_campaign",
    "GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsCampaignData": "openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_campaign_data",
    "GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsImage": "openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_image",
    "GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsImageData": "openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_image_data",
    "GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsTemplate": "openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_template",
    "GetCampaignMessageResponseCompoundDocumentDataAllOfRelationshipsTemplateData": "openapi_client.models.get_campaign_message_response_compound_document_data_all_of_relationships_template_data",
    "GetCampaignMessageTemplateRelationshipResponse": "openapi_client.models.get_campaign_message_template_relationship_response",
    "GetCampaignMessagesRelationshipsResponseCollection": "openapi_client.models.get_campaign_messages_relationships_response_collection",
    "GetCampaignMessagesRelationshipsResponseCollectionDataInner": "openapi_client.models.get_campaign_messages_relationships_response_collection_data_inner",
    "GetCampaignRecipientEstimationJobResponse": "openapi_client.models.get_campaign_recipient_estimation_job_response",
    "GetCampaignRecipientEstimationResponse": "openapi_client.models.get_campaign_recipient_estimation_response",
    "GetCampaignResponse": "openapi_client.models.get_campaign_response",
    "GetCampaignResponseCollectionCompoundDocument": "openapi_client.models.get_campaign_response_collection_compound_document",
    "GetCampaignResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_campaign_response_collection_compound_document_data_inner",
    "GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCampaignMessages": "openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships_campaign_messages",
    "GetCampaignResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCampaignMessagesDataInner": "openapi_client.models.get_campaign_response_collection_compound_document_data_inner_all_of_relationships_campaign_messages_data_inner",
    "GetCampaignResponseCompoundDocument": "openapi_client.models.get_campaign_response_compound_document",
    "GetCampaignResponseData": "openapi_client.models.get_campaign_response_data",
    "GetCampaignResponseDataAllOfRelationships": "openapi_client.models.get_campaign_response_data_all_of_relationships",
    "GetCampaignSendJobResponse": "openapi_client.models.get_campaign_send_job_response",
    "GetCampaignTagsRelationshipsResponseCollection": "openapi_client.models.get_campaign_tags_relationships_response_collection",
    "GetCatalogCategoryCreateJobResponseCollectionCompoundDocument": "openapi_client.models.get_catalog_category_create_job_response_collection_compound_document",
    "GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner",
    "GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategories": "openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships_categories",
    "GetCatalogCategoryCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategoriesDataInner": "openapi_client.models.get_catalog_category_create_job_response_collection_compound_document_data_inner_all_of_relationships_categories_data_inner",
    "GetCatalogCategoryCreateJobResponseCompoundDocument": "openapi_client.models.get_catalog_category_create_job_response_compound_document",
    "GetCatalogCategoryDeleteJobResponse": "openapi_client.models.get_catalog_category_delete_job_response",
    "GetCatalogCategoryDeleteJobResponseCollection": "openapi_client.models.get_catalog_category_delete_job_response_collection",
    "GetCatalogCategoryDeleteJobResponseCollectionDataInner": "openapi_client.models.get_catalog_category_delete_job_response_collection_data_inner",
    "GetCatalogCategoryDeleteJobResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_catalog_category_delete_job_response_collection_data_inner_all_of_relationships",
    "GetCatalogCategoryItemsRelationshipsResponseCollection": "openapi_client.models.get_catalog_category_items_relationships_response_collection",
    "GetCatalogCategoryItemsRelationshipsResponseCollectionDataInner": "openapi_client.models.get_catalog_category_items_relationships_response_collection_data_inner",
    "GetCatalogCategoryResponse": "openapi_client.models.get_catalog_category_response",
    "GetCatalogCategoryResponseCollection": "openapi_client.models.get_catalog_category_response_collection",
    "GetCatalogCategoryResponseCollectionDataInner": "openapi_client.models.get_catalog_category_response_collection_data_inner",
    "GetCatalogCategoryResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_catalog_category_response_collection_data_inner_all_of_relationships",
    "GetCatalogCategoryUpdateJobResponseCollectionCompoundDocument": "openapi_client.models.get_catalog_category_update_job_response_collection_compound_document",
    "GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner",
    "GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategories": "openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships_categories",
    "GetCatalogCategoryUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCategoriesDataInner": "openapi_client.models.get_catalog_category_update_job_response_collection_compound_document_data_inner_all_of_relationships_categories_data_inner",
    "GetCatalogCategoryUpdateJobResponseCompoundDocument": "openapi_client.models.get_catalog_category_update_job_response_compound_document",
    "GetCatalogItemCategoriesRelationshipsResponseCollection": "openapi_client.models.get_catalog_item_categories_relationships_response_collection",
    "GetCatalogItemCategoriesRelationshipsResponseCollectionDataInner": "openapi_client.models.get_catalog_item_categories_relationships_response_collection_data_inner",
    "GetCatalogItemCreateJobResponseCollectionCompoundDocument": "openapi_client.models.get_catalog_item_create_job_response_collection_compound_document",
    "GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner",
    "GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItems": "openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships_items",
    "GetCatalogItemCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItemsDataInner": "openapi_client.models.get_catalog_item_create_job_response_collection_compound_document_data_inner_all_of_relationships_items_data_inner",
    "GetCatalogItemCreateJobResponseCompoundDocument": "openapi_client.models.get_catalog_item_create_job_response_compound_document",
    "GetCatalogItemDeleteJobResponse": "openapi_client.models.get_catalog_item_delete_job_response",
    "GetCatalogItemDeleteJobResponseCollection": "openapi_client.models.get_catalog_item_delete_job_response_collection",
    "GetCatalogItemDeleteJobResponseCollectionDataInner": "openapi_client.models.get_catalog_item_delete_job_response_collection_data_inner",
    "GetCatalogItemResponseCollectionCompoundDocument": "openapi_client.models.get_catalog_item_response_collection_compound_document",
    "GetCatalogItemResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner",
    "GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants": "openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships_variants",
    "GetCatalogItemResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner": "openapi_client.models.get_catalog_item_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner",
    "GetCatalogItemResponseCompoundDocument": "openapi_client.models.get_catalog_item_response_compound_document",
    "GetCatalogItemUpdateJobResponseCollectionCompoundDocument": "openapi_client.models.get_catalog_item_update_job_response_collection_compound_document",
    "GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner",
    "GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItems": "openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships_items",
    "GetCatalogItemUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsItemsDataInner": "openapi_client.models.get_catalog_item_update_job_response_collection_compound_document_data_inner_all_of_relationships_items_data_inner",
    "GetCatalogItemUpdateJobResponseCompoundDocument": "openapi_client.models.get_catalog_item_update_job_response_compound_document",
    "GetCatalogItemVariantsRelationshipsResponseCollection": "openapi_client.models.get_catalog_item_variants_relationships_response_collection",
    "GetCatalogItemVariantsRelationshipsResponseCollectionDataInner": "openapi_client.models.get_catalog_item_variants_relationships_response_collection_data_inner",
    "GetCatalogVariantCreateJobResponseCollectionCompoundDocument": "openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document",
    "GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner",
    "GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants": "openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships_variants",
    "GetCatalogVariantCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner": "openapi_client.models.get_catalog_variant_create_job_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner",
    "GetCatalogVariantCreateJobResponseCompoundDocument": "openapi_client.models.get_catalog_variant_create_job_response_compound_document",
    "GetCatalogVariantDeleteJobResponse": "openapi_client.models.get_catalog_variant_delete_job_response",
    "GetCatalogVariantDeleteJobResponseCollection": "openapi_client.models.get_catalog_variant_delete_job_response_collection",
    "GetCatalogVariantDeleteJobResponseCollectionDataInner": "openapi_client.models.get_catalog_variant_delete_job_response_collection_data_inner",
    "GetCatalogVariantDeleteJobResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_catalog_variant_delete_job_response_collection_data_inner_all_of_relationships",
    "GetCatalogVariantResponse": "openapi_client.models.get_catalog_variant_response",
    "GetCatalogVariantResponseCollection": "openapi_client.models.get_catalog_variant_response_collection",
    "GetCatalogVariantResponseCollectionDataInner": "openapi_client.models.get_catalog_variant_response_collection_data_inner",
    "GetCatalogVariantResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_catalog_variant_response_collection_data_inner_all_of_relationships",
    "GetCatalogVariantUpdateJobResponseCollectionCompoundDocument": "openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document",
    "GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner",
    "GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariants": "openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships_variants",
    "GetCatalogVariantUpdateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsVariantsDataInner": "openapi_client.models.get_catalog_variant_update_job_response_collection_compound_document_data_inner_all_of_relationships_variants_data_inner",
    "GetCatalogVariantUpdateJobResponseCompoundDocument": "openapi_client.models.get_catalog_variant_update_job_response_compound_document",
    "GetCouponCodeCouponRelationshipResponse": "openapi_client.models.get_coupon_code_coupon_relationship_response",
    "GetCouponCodeCouponRelationshipResponseData": "openapi_client.models.get_coupon_code_coupon_relationship_response_data",
    "GetCouponCodeCreateJobResponseCollectionCompoundDocument": "openapi_client.models.get_coupon_code_create_job_response_collection_compound_document",
    "GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner",
    "GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponCodes": "openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships_coupon_codes",
    "GetCouponCodeCreateJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponCodesDataInner": "openapi_client.models.get_coupon_code_create_job_response_collection_compound_document_data_inner_all_of_relationships_coupon_codes_data_inner",
    "GetCouponCodeCreateJobResponseCompoundDocument": "openapi_client.models.get_coupon_code_create_job_response_compound_document",
    "GetCouponCodeResponseCollection": "openapi_client.models.get_coupon_code_response_collection",
    "GetCouponCodeResponseCollectionCompoundDocument": "openapi_client.models.get_coupon_code_response_collection_compound_document",
    "GetCouponCodeResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner",
    "GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCoupon": "openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_coupon",
    "GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsCouponData": "openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_coupon_data",
    "GetCouponCodeResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile": "openapi_client.models.get_coupon_code_response_collection_compound_document_data_inner_all_of_relationships_profile",
    "GetCouponCodeResponseCollectionDataInner": "openapi_client.models.get_coupon_code_response_collection_data_inner",
    "GetCouponCodeResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_coupon_code_response_collection_data_inner_all_of_relationships",
    "GetCouponCodeResponseCompoundDocument": "openapi_client.models.get_coupon_code_response_compound_document",
    "GetCouponCodesRelationshipsResponseCollection": "openapi_client.models.get_coupon_codes_relationships_response_collection",
    "GetCouponCodesRelationshipsResponseCollectionDataInner": "openapi_client.models.get_coupon_codes_relationships_response_collection_data_inner",
    "GetCouponResponse": "openapi_client.models.get_coupon_response",
    "GetCouponResponseCollection": "openapi_client.models.get_coupon_response_collection",
    "GetCustomMetricMetricsRelationshipsResponseCollection": "openapi_client.models.get_custom_metric_metrics_relationships_response_collection",
    "GetCustomMetricResponseCollectionCompoundDocument": "openapi_client.models.get_custom_metric_response_collection_compound_document",
    "GetCustomMetricResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_custom_metric_response_collection_compound_document_data_inner",
    "GetCustomMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_custom_metric_response_collection_compound_document_data_inner_all_of_relationships",
    "GetCustomMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetrics": "openapi_client.models.get_custom_metric_response_collection_compound_document_data_inner_all_of_relationships_metrics",
    "GetCustomMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetricsDataInner": "openapi_client.models.get_custom_metric_response_collection_compound_document_data_inner_all_of_relationships_metrics_data_inner",
    "GetCustomMetricResponseCompoundDocument": "openapi_client.models.get_custom_metric_response_compound_document",
    "GetEventMetricRelationshipResponse": "openapi_client.models.get_event_metric_relationship_response",
    "GetEventProfileRelationshipResponse": "openapi_client.models.get_event_profile_relationship_response",
    "GetEventProfileRelationshipResponseData": "openapi_client.models.get_event_profile_relationship_response_data",
    "GetEventResponseCollectionCompoundDocument": "openapi_client.models.get_event_response_collection_compound_document",
    "GetEventResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_event_response_collection_compound_document_data_inner",
    "GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships",
    "GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsAttributions": "openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_attributions",
    "GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsAttributionsDataInner": "openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_attributions_data_inner",
    "GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetric": "openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_metric",
    "GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsMetricData": "openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_metric_data",
    "GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile": "openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_profile",
    "GetEventResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfileData": "openapi_client.models.get_event_response_collection_compound_document_data_inner_all_of_relationships_profile_data",
    "GetEventResponseCompoundDocument": "openapi_client.models.get_event_response_compound_document",
    "GetFlowActionFlowMessageRelationshipResponseCollection": "openapi_client.models.get_flow_action_flow_message_relationship_response_collection",
    "GetFlowActionFlowRelationshipResponse": "openapi_client.models.get_flow_action_flow_relationship_response",
    "GetFlowActionResponse": "openapi_client.models.get_flow_action_response",
    "GetFlowActionResponseCollection": "openapi_client.models.get_flow_action_response_collection",
    "GetFlowActionResponseCollectionDataInner": "openapi_client.models.get_flow_action_response_collection_data_inner",
    "GetFlowActionResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_flow_action_response_collection_data_inner_all_of_relationships",
    "GetFlowActionResponseCompoundDocument": "openapi_client.models.get_flow_action_response_compound_document",
    "GetFlowActionResponseCompoundDocumentData": "openapi_client.models.get_flow_action_response_compound_document_data",
    "GetFlowActionResponseCompoundDocumentDataAllOfRelationships": "openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships",
    "GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlow": "openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow",
    "GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlowMessages": "openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow_messages",
    "GetFlowActionResponseCompoundDocumentDataAllOfRelationshipsFlowMessagesDataInner": "openapi_client.models.get_flow_action_response_compound_document_data_all_of_relationships_flow_messages_data_inner",
    "GetFlowFlowActionRelationshipListResponseCollection": "openapi_client.models.get_flow_flow_action_relationship_list_response_collection",
    "GetFlowMessageActionRelationshipResponse": "openapi_client.models.get_flow_message_action_relationship_response",
    "GetFlowMessageResponseCollection": "openapi_client.models.get_flow_message_response_collection",
    "GetFlowMessageResponseCollectionDataInner": "openapi_client.models.get_flow_message_response_collection_data_inner",
    "GetFlowMessageResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_flow_message_response_collection_data_inner_all_of_relationships",
    "GetFlowMessageResponseCompoundDocument": "openapi_client.models.get_flow_message_response_compound_document",
    "GetFlowMessageResponseCompoundDocumentData": "openapi_client.models.get_flow_message_response_compound_document_data",
    "GetFlowMessageResponseCompoundDocumentDataAllOfRelationships": "openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships",
    "GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsFlowAction": "openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_flow_action",
    "GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsTemplate": "openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_template",
    "GetFlowMessageResponseCompoundDocumentDataAllOfRelationshipsTemplateData": "openapi_client.models.get_flow_message_response_compound_document_data_all_of_relationships_template_data",
    "GetFlowMessageTemplateRelationshipResponse": "openapi_client.models.get_flow_message_template_relationship_response",
    "GetFlowMessageTemplateRelationshipResponseData": "openapi_client.models.get_flow_message_template_relationship_response_data",
    "GetFlowResponse": "openapi_client.models.get_flow_response",
    "GetFlowResponseCollection": "openapi_client.models.get_flow_response_collection",
    "GetFlowResponseCollectionCompoundDocument": "openapi_client.models.get_flow_response_collection_compound_document",
    "GetFlowResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_flow_response_collection_compound_document_data_inner",
    "GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships",
    "GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowActions": "openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships_flow_actions",
    "GetFlowResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowActionsDataInner": "openapi_client.models.get_flow_response_collection_compound_document_data_inner_all_of_relationships_flow_actions_data_inner",
    "GetFlowResponseCollectionDataInner": "openapi_client.models.get_flow_response_collection_data_inner",
    "GetFlowResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_flow_response_collection_data_inner_all_of_relationships",
    "GetFlowTagsRelationshipsResponseCollection": "openapi_client.models.get_flow_tags_relationships_response_collection",
    "GetFlowV2ResponseCompoundDocument": "openapi_client.models.get_flow_v2_response_compound_document",
    "GetFlowV2ResponseCompoundDocumentData": "openapi_client.models.get_flow_v2_response_compound_document_data",
    "GetFormResponse": "openapi_client.models.get_form_response",
    "GetFormResponseCollectionCompoundDocument": "openapi_client.models.get_form_response_collection_compound_document",
    "GetFormResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_form_response_collection_compound_document_data_inner",
    "GetFormResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_form_response_collection_compound_document_data_inner_all_of_relationships",
    "GetFormResponseCompoundDocument": "openapi_client.models.get_form_response_compound_document",
    "GetFormResponseCompoundDocumentData": "openapi_client.models.get_form_response_compound_document_data",
    "GetFormResponseCompoundDocumentDataAllOfRelationships": "openapi_client.models.get_form_response_compound_document_data_all_of_relationships",
    "GetFormResponseCompoundDocumentDataAllOfRelationshipsFormVersions": "openapi_client.models.get_form_response_compound_document_data_all_of_relationships_form_versions",
    "GetFormResponseCompoundDocumentDataAllOfRelationshipsFormVersionsDataInner": "openapi_client.models.get_form_response_compound_document_data_all_of_relationships_form_versions_data_inner",
    "GetFormVersionFormRelationshipResponse": "openapi_client.models.get_form_version_form_relationship_response",
    "GetFormVersionFormRelationshipResponseData": "openapi_client.models.get_form_version_form_relationship_response_data",
    "GetFormVersionResponse": "openapi_client.models.get_form_version_response",
    "GetFormVersionResponseCollection": "openapi_client.models.get_form_version_response_collection",
    "GetFormVersionsRelationshipsResponseCollection": "openapi_client.models.get_form_versions_relationships_response_collection",
    "GetFormVersionsRelationshipsResponseCollectionDataInner": "openapi_client.models.get_form_versions_relationships_response_collection_data_inner",
    "GetImageResponse": "openapi_client.models.get_image_response",
    "GetImageResponseCollection": "openapi_client.models.get_image_response_collection",
    "GetImportErrorResponseCollection": "openapi_client.models.get_import_error_response_collection",
    "GetListFlowTriggersRelationshipsResponseCollection": "openapi_client.models.get_list_flow_triggers_relationships_response_collection",
    "GetListListResponseCollectionCompoundDocument": "openapi_client.models.get_list_list_response_collection_compound_document",
    "GetListListResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_list_list_response_collection_compound_document_data_inner",
    "GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships",
    "GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTags": "openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships_tags",
    "GetListListResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagsDataInner": "openapi_client.models.get_list_list_response_collection_compound_document_data_inner_all_of_relationships_tags_data_inner",
    "GetListMemberResponseCollection": "openapi_client.models.get_list_member_response_collection",
    "GetListMemberResponseCollectionDataInner": "openapi_client.models.get_list_member_response_collection_data_inner",
    "GetListProfilesRelationshipsResponseCollection": "openapi_client.models.get_list_profiles_relationships_response_collection",
    "GetListResponseCollection": "openapi_client.models.get_list_response_collection",
    "GetListResponseCollectionDataInner": "openapi_client.models.get_list_response_collection_data_inner",
    "GetListResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_list_response_collection_data_inner_all_of_relationships",
    "GetListRetrieveResponseCompoundDocument": "openapi_client.models.get_list_retrieve_response_compound_document",
    "GetListRetrieveResponseCompoundDocumentData": "openapi_client.models.get_list_retrieve_response_compound_document_data",
    "GetListTagsRelationshipsResponseCollection": "openapi_client.models.get_list_tags_relationships_response_collection",
    "GetListTagsRelationshipsResponseCollectionDataInner": "openapi_client.models.get_list_tags_relationships_response_collection_data_inner",
    "GetMetricFlowTriggersRelationshipsResponseCollection": "openapi_client.models.get_metric_flow_triggers_relationships_response_collection",
    "GetMetricPropertiesRelationshipsResponseCollection": "openapi_client.models.get_metric_properties_relationships_response_collection",
    "GetMetricPropertiesRelationshipsResponseCollectionDataInner": "openapi_client.models.get_metric_properties_relationships_response_collection_data_inner",
    "GetMetricPropertyMetricRelationshipResponse": "openapi_client.models.get_metric_property_metric_relationship_response",
    "GetMetricPropertyResponseCollection": "openapi_client.models.get_metric_property_response_collection",
    "GetMetricPropertyResponseCollectionDataInner": "openapi_client.models.get_metric_property_response_collection_data_inner",
    "GetMetricPropertyResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_metric_property_response_collection_data_inner_all_of_relationships",
    "GetMetricPropertyResponseCompoundDocument": "openapi_client.models.get_metric_property_response_compound_document",
    "GetMetricPropertyResponseCompoundDocumentData": "openapi_client.models.get_metric_property_response_compound_document_data",
    "GetMetricPropertyResponseCompoundDocumentDataAllOfRelationships": "openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships",
    "GetMetricPropertyResponseCompoundDocumentDataAllOfRelationshipsMetric": "openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships_metric",
    "GetMetricPropertyResponseCompoundDocumentDataAllOfRelationshipsMetricData": "openapi_client.models.get_metric_property_response_compound_document_data_all_of_relationships_metric_data",
    "GetMetricResponse": "openapi_client.models.get_metric_response",
    "GetMetricResponseCollection": "openapi_client.models.get_metric_response_collection",
    "GetMetricResponseCollectionCompoundDocument": "openapi_client.models.get_metric_response_collection_compound_document",
    "GetMetricResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_metric_response_collection_compound_document_data_inner",
    "GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships",
    "GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowTriggers": "openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships_flow_triggers",
    "GetMetricResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsFlowTriggersDataInner": "openapi_client.models.get_metric_response_collection_compound_document_data_inner_all_of_relationships_flow_triggers_data_inner",
    "GetMetricResponseCompoundDocument": "openapi_client.models.get_metric_response_compound_document",
    "GetMetricResponseData": "openapi_client.models.get_metric_response_data",
    "GetMetricResponseDataAllOfRelationships": "openapi_client.models.get_metric_response_data_all_of_relationships",
    "GetProfileBulkImportJobListsRelationshipsResponseCollection": "openapi_client.models.get_profile_bulk_import_job_lists_relationships_response_collection",
    "GetProfileBulkImportJobProfilesRelationshipsResponseCollection": "openapi_client.models.get_profile_bulk_import_job_profiles_relationships_response_collection",
    "GetProfileImportJobResponseCollectionCompoundDocument": "openapi_client.models.get_profile_import_job_response_collection_compound_document",
    "GetProfileImportJobResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner",
    "GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships",
    "GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsImportErrors": "openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_import_errors",
    "GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsLists": "openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_lists",
    "GetProfileImportJobResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsListsDataInner": "openapi_client.models.get_profile_import_job_response_collection_compound_document_data_inner_all_of_relationships_lists_data_inner",
    "GetProfileImportJobResponseCompoundDocument": "openapi_client.models.get_profile_import_job_response_compound_document",
    "GetProfileListsRelationshipsResponseCollection": "openapi_client.models.get_profile_lists_relationships_response_collection",
    "GetProfileListsRelationshipsResponseCollectionDataInner": "openapi_client.models.get_profile_lists_relationships_response_collection_data_inner",
    "GetProfilePushTokensRelationshipsResponseCollection": "openapi_client.models.get_profile_push_tokens_relationships_response_collection",
    "GetProfilePushTokensRelationshipsResponseCollectionDataInner": "openapi_client.models.get_profile_push_tokens_relationships_response_collection_data_inner",
    "GetProfileResponse": "openapi_client.models.get_profile_response",
    "GetProfileResponseCollection": "openapi_client.models.get_profile_response_collection",
    "GetProfileResponseCollectionCompoundDocument": "openapi_client.models.get_profile_response_collection_compound_document",
    "GetProfileResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_profile_response_collection_compound_document_data_inner",
    "GetProfileResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_profile_response_collection_compound_document_data_inner_all_of_relationships",
    "GetProfileResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsPushTokens": "openapi_client.models.get_profile_response_collection_compound_document_data_inner_all_of_relationships_push_tokens",
    "GetProfileResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsPushTokensDataInner": "openapi_client.models.get_profile_response_collection_compound_document_data_inner_all_of_relationships_push_tokens_data_inner",
    "GetProfileResponseCompoundDocument": "openapi_client.models.get_profile_response_compound_document",
    "GetProfileResponseCompoundDocumentData": "openapi_client.models.get_profile_response_compound_document_data",
    "GetProfileResponseCompoundDocumentDataAllOfRelationships": "openapi_client.models.get_profile_response_compound_document_data_all_of_relationships",
    "GetProfileResponseCompoundDocumentDataAllOfRelationshipsLists": "openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_lists",
    "GetProfileResponseCompoundDocumentDataAllOfRelationshipsListsDataInner": "openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_lists_data_inner",
    "GetProfileResponseCompoundDocumentDataAllOfRelationshipsSegments": "openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_segments",
    "GetProfileResponseCompoundDocumentDataAllOfRelationshipsSegmentsDataInner": "openapi_client.models.get_profile_response_compound_document_data_all_of_relationships_segments_data_inner",
    "GetProfileResponseData": "openapi_client.models.get_profile_response_data",
    "GetProfileResponseDataAllOfRelationships": "openapi_client.models.get_profile_response_data_all_of_relationships",
    "GetProfileSegmentsRelationshipsResponseCollection": "openapi_client.models.get_profile_segments_relationships_response_collection",
    "GetPushTokenProfileRelationshipResponse": "openapi_client.models.get_push_token_profile_relationship_response",
    "GetPushTokenResponseCollection": "openapi_client.models.get_push_token_response_collection",
    "GetPushTokenResponseCollectionCompoundDocument": "openapi_client.models.get_push_token_response_collection_compound_document",
    "GetPushTokenResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_push_token_response_collection_compound_document_data_inner",
    "GetPushTokenResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_push_token_response_collection_compound_document_data_inner_all_of_relationships",
    "GetPushTokenResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfile": "openapi_client.models.get_push_token_response_collection_compound_document_data_inner_all_of_relationships_profile",
    "GetPushTokenResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsProfileData": "openapi_client.models.get_push_token_response_collection_compound_document_data_inner_all_of_relationships_profile_data",
    "GetPushTokenResponseCollectionDataInner": "openapi_client.models.get_push_token_response_collection_data_inner",
    "GetPushTokenResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_push_token_response_collection_data_inner_all_of_relationships",
    "GetPushTokenResponseCompoundDocument": "openapi_client.models.get_push_token_response_compound_document",
    "GetReviewResponseDTOCollectionCompoundDocument": "openapi_client.models.get_review_response_dto_collection_compound_document",
    "GetReviewResponseDTOCollectionCompoundDocumentDataInner": "openapi_client.models.get_review_response_dto_collection_compound_document_data_inner",
    "GetReviewResponseDTOCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_review_response_dto_collection_compound_document_data_inner_all_of_relationships",
    "GetReviewResponseDTOCollectionCompoundDocumentDataInnerAllOfRelationshipsEvents": "openapi_client.models.get_review_response_dto_collection_compound_document_data_inner_all_of_relationships_events",
    "GetReviewResponseDTOCollectionCompoundDocumentDataInnerAllOfRelationshipsEventsDataInner": "openapi_client.models.get_review_response_dto_collection_compound_document_data_inner_all_of_relationships_events_data_inner",
    "GetReviewResponseDTOCompoundDocument": "openapi_client.models.get_review_response_dto_compound_document",
    "GetSegmentFlowTriggersRelationshipsResponseCollection": "openapi_client.models.get_segment_flow_triggers_relationships_response_collection",
    "GetSegmentListResponseCollectionCompoundDocument": "openapi_client.models.get_segment_list_response_collection_compound_document",
    "GetSegmentListResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_segment_list_response_collection_compound_document_data_inner",
    "GetSegmentMemberResponseCollection": "openapi_client.models.get_segment_member_response_collection",
    "GetSegmentMemberResponseCollectionDataInner": "openapi_client.models.get_segment_member_response_collection_data_inner",
    "GetSegmentProfilesRelationshipsResponseCollection": "openapi_client.models.get_segment_profiles_relationships_response_collection",
    "GetSegmentResponseCollection": "openapi_client.models.get_segment_response_collection",
    "GetSegmentResponseCollectionDataInner": "openapi_client.models.get_segment_response_collection_data_inner",
    "GetSegmentRetrieveResponseCompoundDocument": "openapi_client.models.get_segment_retrieve_response_compound_document",
    "GetSegmentRetrieveResponseCompoundDocumentData": "openapi_client.models.get_segment_retrieve_response_compound_document_data",
    "GetSegmentTagsRelationshipsResponseCollection": "openapi_client.models.get_segment_tags_relationships_response_collection",
    "GetTagCampaignRelationshipsResponseCollection": "openapi_client.models.get_tag_campaign_relationships_response_collection",
    "GetTagCampaignRelationshipsResponseCollectionDataInner": "openapi_client.models.get_tag_campaign_relationships_response_collection_data_inner",
    "GetTagFlowRelationshipsResponseCollection": "openapi_client.models.get_tag_flow_relationships_response_collection",
    "GetTagFlowRelationshipsResponseCollectionDataInner": "openapi_client.models.get_tag_flow_relationships_response_collection_data_inner",
    "GetTagGroupRelationshipResponse": "openapi_client.models.get_tag_group_relationship_response",
    "GetTagGroupRelationshipResponseData": "openapi_client.models.get_tag_group_relationship_response_data",
    "GetTagGroupResponse": "openapi_client.models.get_tag_group_response",
    "GetTagGroupResponseCollection": "openapi_client.models.get_tag_group_response_collection",
    "GetTagGroupResponseCollectionDataInner": "openapi_client.models.get_tag_group_response_collection_data_inner",
    "GetTagGroupResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_tag_group_response_collection_data_inner_all_of_relationships",
    "GetTagGroupTagsRelationshipsResponseCollection": "openapi_client.models.get_tag_group_tags_relationships_response_collection",
    "GetTagListRelationshipsResponseCollection": "openapi_client.models.get_tag_list_relationships_response_collection",
    "GetTagListRelationshipsResponseCollectionDataInner": "openapi_client.models.get_tag_list_relationships_response_collection_data_inner",
    "GetTagResponseCollection": "openapi_client.models.get_tag_response_collection",
    "GetTagResponseCollectionCompoundDocument": "openapi_client.models.get_tag_response_collection_compound_document",
    "GetTagResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_tag_response_collection_compound_document_data_inner",
    "GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships",
    "GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagGroup": "openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships_tag_group",
    "GetTagResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsTagGroupData": "openapi_client.models.get_tag_response_collection_compound_document_data_inner_all_of_relationships_tag_group_data",
    "GetTagResponseCollectionDataInner": "openapi_client.models.get_tag_response_collection_data_inner",
    "GetTagResponseCollectionDataInnerAllOfRelationships": "openapi_client.models.get_tag_response_collection_data_inner_all_of_relationships",
    "GetTagResponseCompoundDocument": "openapi_client.models.get_tag_response_compound_document",
    "GetTagSegmentRelationshipsResponseCollection": "openapi_client.models.get_tag_segment_relationships_response_collection",
    "GetTagSegmentRelationshipsResponseCollectionDataInner": "openapi_client.models.get_tag_segment_relationships_response_collection_data_inner",
    "GetTemplateResponse": "openapi_client.models.get_template_response",
    "GetTemplateResponseCollection": "openapi_client.models.get_template_response_collection",
    "GetTrackingSettingResponse": "openapi_client.models.get_tracking_setting_response",
    "GetTrackingSettingResponseCollection": "openapi_client.models.get_tracking_setting_response_collection",
    "GetUniversalContentResponse": "openapi_client.models.get_universal_content_response",
    "GetUniversalContentResponseCollection": "openapi_client.models.get_universal_content_response_collection",
    "GetWebFeedResponse": "openapi_client.models.get_web_feed_response",
    "GetWebFeedResponseCollection": "openapi_client.models.get_web_feed_response_collection",
    "GetWebhookResponseCollectionCompoundDocument": "openapi_client.models.get_webhook_response_collection_compound_document",
    "GetWebhookResponseCollectionCompoundDocumentDataInner": "openapi_client.models.get_webhook_response_collection_compound_document_data_inner",
    "GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationships": "openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships",
    "GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsWebhookTopics": "openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships_webhook_topics",
    "GetWebhookResponseCollectionCompoundDocumentDataInnerAllOfRelationshipsWebhookTopicsDataInner": "openapi_client.models.get_webhook_response_collection_compound_document_data_inner_all_of_relationships_webhook_topics_data_inner",
    "GetWebhookResponseCompoundDocument": "openapi_client.models.get_webhook_response_compound_document",
    "GetWebhookTopicResponse": "openapi_client.models.get_webhook_topic_response",
    "GetWebhookTopicResponseCollection": "openapi_client.models.get_webhook_topic_response_collection",
    "ImageCreateQuery": "openapi_client.models.image_create_query",
    "ImageCreateQueryResourceObject": "openapi_client.models.image_create_query_resource_object",
    "ImageCreateQueryResourceObjectAttributes": "openapi_client.models.image_create_query_resource_object_attributes",
    "ImageEnum": "openapi_client.models.image_enum",
    "ImagePartialUpdateQuery": "openapi_client.models.image_partial_update_query",
    "ImagePartialUpdateQueryResourceObject": "openapi_client.models.image_partial_update_query_resource_object",
    "ImagePartialUpdateQueryResourceObjectAttributes": "openapi_client.models.image_partial_update_query_resource_object_attributes",
    "ImageResponseObjectResource": "openapi_client.models.image_response_object_resource",
    "ImageResponseObjectResourceAttributes": "openapi_client.models.image_response_object_resource_attributes",
    "ImportErrorEnum": "openapi_client.models.import_error_enum",
    "ImportErrorResponseObjectResource": "openapi_client.models.import_error_response_object_resource",
    "ImportErrorResponseObjectResourceAttributes": "openapi_client.models.import_error_response_object_resource_attributes",
    "ListCreateQuery": "openapi_client.models.list_create_query",
    "ListCreateQueryResourceObject": "openapi_client.models.list_create_query_resource_object",
    "ListCreateQueryResourceObjectAttributes": "openapi_client.models.list_create_query_resource_object_attributes",
    "ListEnum": "openapi_client.models.list_enum",
    "ListListResponseObjectResource": "openapi_client.models.list_list_response_object_resource",
    "ListListResponseObjectResourceAttributes": "openapi_client.models.list_list_response_object_resource_attributes",
    "ListMemberResponseObjectResourceAttributes": "openapi_client.models.list_member_response_object_resource_attributes",
    "ListMemberResponseObjectResourceExtended": "openapi_client.models.list_member_response_object_resource_extended",
    "ListMemberResponseObjectResourceExtendedAttributes": "openapi_client.models.list_member_response_object_resource_extended_attributes",
    "ListMembersAddQuery": "openapi_client.models.list_members_add_query",
    "ListMembersDeleteQuery": "openapi_client.models.list_members_delete_query",
    "ListPartialUpdateQuery": "openapi_client.models.list_partial_update_query",
    "ListPartialUpdateQueryResourceObject": "openapi_client.models.list_partial_update_query_resource_object",
    "ListResponseObjectResource": "openapi_client.models.list_response_object_resource",
    "ListRetrieveResponseObjectResourceAttributes": "openapi_client.models.list_retrieve_response_object_resource_attributes",
    "ListRetrieveResponseObjectResourceExtended": "openapi_client.models.list_retrieve_response_object_resource_extended",
    "ListRetrieveResponseObjectResourceExtendedAttributes": "openapi_client.models.list_retrieve_response_object_resource_extended_attributes",
    "MetricAggregateEnum": "openapi_client.models.metric_aggregate_enum",
    "MetricAggregateQuery": "openapi_client.models.metric_aggregate_query",
    "MetricAggregateQueryResourceObject": "openapi_client.models.metric_aggregate_query_resource_object",
    "MetricAggregateQueryResourceObjectAttributes": "openapi_client.models.metric_aggregate_query_resource_object_attributes",
    "MetricAggregateRowDTO": "openapi_client.models.metric_aggregate_row_dto",
    "MetricCreateQueryResourceObject": "openapi_client.models.metric_create_query_resource_object",
    "MetricCreateQueryResourceObjectAttributes": "openapi_client.models.metric_create_query_resource_object_attributes",
    "MetricEnum": "openapi_client.models.metric_enum",
    "MetricPropertyEnum": "openapi_client.models.metric_property_enum",
    "MetricPropertyResponseObjectResourceAttributes": "openapi_client.models.metric_property_response_object_resource_attributes",
    "MetricPropertyResponseObjectResourceExtended": "openapi_client.models.metric_property_response_object_resource_extended",
    "MetricPropertyResponseObjectResourceExtendedAttributes": "openapi_client.models.metric_property_response_object_resource_extended_attributes",
    "MetricResponseObjectResource": "openapi_client.models.metric_response_object_resource",
    "MetricResponseObjectResourceAttributes": "openapi_client.models.metric_response_object_resource_attributes",
    "ObjectLinks": "openapi_client.models.object_links",
    "OnlyRelatedLinks": "openapi_client.models.only_related_links",
    "OnsiteProfileCreateQueryResourceObject": "openapi_client.models.onsite_profile_create_query_resource_object",
    "OnsiteProfileCreateQueryResourceObjectAttributes": "openapi_client.models.onsite_profile_create_query_resource_object_attributes",
    "OnsiteProfileMeta": "openapi_client.models.onsite_profile_meta",
    "PatchCampaignMessageResponse": "openapi_client.models.patch_campaign_message_response",
    "PatchCampaignMessageResponseData": "openapi_client.models.patch_campaign_message_response_data",
    "PatchCampaignResponse": "openapi_client.models.patch_campaign_response",
    "PatchCatalogCategoryResponse": "openapi_client.models.patch_catalog_category_response",
    "PatchCatalogItemResponse": "openapi_client.models.patch_catalog_item_response",
    "PatchCatalogVariantResponse": "openapi_client.models.patch_catalog_variant_response",
    "PatchCouponCodeResponse": "openapi_client.models.patch_coupon_code_response",
    "PatchCouponResponse": "openapi_client.models.patch_coupon_response",
    "PatchCustomMetricResponse": "openapi_client.models.patch_custom_metric_response",
    "PatchFlowResponse": "openapi_client.models.patch_flow_response",
    "PatchFlowResponseData": "openapi_client.models.patch_flow_response_data",
    "PatchImageResponse": "openapi_client.models.patch_image_response",
    "PatchListPartialUpdateResponse": "openapi_client.models.patch_list_partial_update_response",
    "PatchProfileResponse": "openapi_client.models.patch_profile_response",
    "PatchReviewResponseDTO": "openapi_client.models.patch_review_response_dto",
    "PatchReviewResponseDTOData": "openapi_client.models.patch_review_response_dto_data",
    "PatchReviewResponseDTODataAttributes": "openapi_client.models.patch_review_response_dto_data_attributes",
    "PatchReviewResponseDTODataRelationships": "openapi_client.models.patch_review_response_dto_data_relationships",
    "PatchReviewResponseDTODataRelationshipsItem": "openapi_client.models.patch_review_response_dto_data_relationships_item",
    "PatchReviewResponseDTODataRelationshipsItemData": "openapi_client.models.patch_review_response_dto_data_relationships_item_data",
    "PatchSegmentPartialUpdateResponse": "openapi_client.models.patch_segment_partial_update_response",
    "PatchTagGroupResponse": "openapi_client.models.patch_tag_group_response",
    "PatchTemplateResponse": "openapi_client.models.patch_template_response",
    "PatchTrackingSettingResponse": "openapi_client.models.patch_tracking_setting_response",
    "PatchTrackingSettingResponseData": "openapi_client.models.patch_tracking_setting_response_data",
    "PatchUniversalContentResponse": "openapi_client.models.patch_universal_content_response",
    "PatchWebFeedResponse": "openapi_client.models.patch_web_feed_response",
    "PatchWebhookResponse": "openapi_client.models.patch_webhook_response",
    "PostBulkProfileSuppressionsCreateJobResponse": "openapi_client.models.post_bulk_profile_suppressions_create_job_response",
    "PostBulkProfileSuppressionsCreateJobResponseData": "openapi_client.models.post_bulk_profile_suppressions_create_job_response_data",
    "PostBulkProfileSuppressionsCreateJobResponseDataAttributes": "openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_attributes",
    "PostBulkProfileSuppressionsCreateJobResponseDataRelationships": "openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships",
    "PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsLists": "openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_lists",
    "PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsListsDataInner": "openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_lists_data_inner",
    "PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsSegments": "openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_segments",
    "PostBulkProfileSuppressionsCreateJobResponseDataRelationshipsSegmentsDataInner": "openapi_client.models.post_bulk_profile_suppressions_create_job_response_data_relationships_segments_data_inner",
    "PostBulkProfileSuppressionsRemoveJobResponse": "openapi_client.models.post_bulk_profile_suppressions_remove_job_response",
    "PostBulkProfileSuppressionsRemoveJobResponseData": "openapi_client.models.post_bulk_profile_suppressions_remove_job_response_data",
    "PostCampaignMessageResponse": "openapi_client.models.post_campaign_message_response",
    "PostCampaignMessageResponseData": "openapi_client.models.post_campaign_message_response_data",
    "PostCampaignMessageResponseDataAttributes": "openapi_client.models.post_campaign_message_response_data_attributes",
    "PostCampaignMessageResponseDataRelationships": "openapi_client.models.post_campaign_message_response_data_relationships",
    "PostCampaignRecipientEstimationJobResponse": "openapi_client.models.post_campaign_recipient_estimation_job_response",
    "PostCampaignRecipientEstimationJobResponseData": "openapi_client.models.post_campaign_recipient_estimation_job_response_data",
    "PostCampaignRecipientEstimationJobResponseDataAttributes": "openapi_client.models.post_campaign_recipient_estimation_job_response_data_attributes",
    "PostCampaignResponse": "openapi_client.models.post_campaign_response",
    "PostCampaignResponseData": "openapi_client.models.post_campaign_response_data",
    "PostCampaignResponseDataAttributes": "openapi_client.models.post_campaign_response_data_attributes",
    "PostCampaignSendJobResponse": "openapi_client.models.post_campaign_send_job_response",
    "PostCampaignSendJobResponseData": "openapi_client.models.post_campaign_send_job_response_data",
    "PostCampaignSendJobResponseDataAttributes": "openapi_client.models.post_campaign_send_job_response_data_attributes",
    "PostCampaignValuesResponseDTO": "openapi_client.models.post_campaign_values_response_dto",
    "PostCampaignValuesResponseDTOData": "openapi_client.models.post_campaign_values_response_dto_data",
    "PostCampaignValuesResponseDTODataAttributes": "openapi_client.models.post_campaign_values_response_dto_data_attributes",
    "PostCampaignValuesResponseDTODataRelationships": "openapi_client.models.post_campaign_values_response_dto_data_relationships",
    "PostCatalogCategoryCreateJobResponse": "openapi_client.models.post_catalog_category_create_job_response",
    "PostCatalogCategoryCreateJobResponseData": "openapi_client.models.post_catalog_category_create_job_response_data",
    "PostCatalogCategoryDeleteJobResponse": "openapi_client.models.post_catalog_category_delete_job_response",
    "PostCatalogCategoryDeleteJobResponseData": "openapi_client.models.post_catalog_category_delete_job_response_data",
    "PostCatalogCategoryDeleteJobResponseDataRelationships": "openapi_client.models.post_catalog_category_delete_job_response_data_relationships",
    "PostCatalogCategoryDeleteJobResponseDataRelationshipsCategories": "openapi_client.models.post_catalog_category_delete_job_response_data_relationships_categories",
    "PostCatalogCategoryDeleteJobResponseDataRelationshipsCategoriesDataInner": "openapi_client.models.post_catalog_category_delete_job_response_data_relationships_categories_data_inner",
    "PostCatalogCategoryResponse": "openapi_client.models.post_catalog_category_response",
    "PostCatalogCategoryResponseData": "openapi_client.models.post_catalog_category_response_data",
    "PostCatalogCategoryResponseDataRelationships": "openapi_client.models.post_catalog_category_response_data_relationships",
    "PostCatalogCategoryResponseDataRelationshipsItems": "openapi_client.models.post_catalog_category_response_data_relationships_items",
    "PostCatalogCategoryUpdateJobResponse": "openapi_client.models.post_catalog_category_update_job_response",
    "PostCatalogCategoryUpdateJobResponseData": "openapi_client.models.post_catalog_category_update_job_response_data",
    "PostCatalogItemCreateJobResponse": "openapi_client.models.post_catalog_item_create_job_response",
    "PostCatalogItemCreateJobResponseData": "openapi_client.models.post_catalog_item_create_job_response_data",
    "PostCatalogItemDeleteJobResponse": "openapi_client.models.post_catalog_item_delete_job_response",
    "PostCatalogItemDeleteJobResponseData": "openapi_client.models.post_catalog_item_delete_job_response_data",
    "PostCatalogItemDeleteJobResponseDataRelationships": "openapi_client.models.post_catalog_item_delete_job_response_data_relationships",
    "PostCatalogItemDeleteJobResponseDataRelationshipsItems": "openapi_client.models.post_catalog_item_delete_job_response_data_relationships_items",
    "PostCatalogItemDeleteJobResponseDataRelationshipsItemsDataInner": "openapi_client.models.post_catalog_item_delete_job_response_data_relationships_items_data_inner",
    "PostCatalogItemResponse": "openapi_client.models.post_catalog_item_response",
    "PostCatalogItemResponseData": "openapi_client.models.post_catalog_item_response_data",
    "PostCatalogItemUpdateJobResponse": "openapi_client.models.post_catalog_item_update_job_response",
    "PostCatalogItemUpdateJobResponseData": "openapi_client.models.post_catalog_item_update_job_response_data",
    "PostCatalogVariantCreateJobResponse": "openapi_client.models.post_catalog_variant_create_job_response",
    "PostCatalogVariantCreateJobResponseData": "openapi_client.models.post_catalog_variant_create_job_response_data",
    "PostCatalogVariantDeleteJobResponse": "openapi_client.models.post_catalog_variant_delete_job_response",
    "PostCatalogVariantDeleteJobResponseData": "openapi_client.models.post_catalog_variant_delete_job_response_data",
    "PostCatalogVariantDeleteJobResponseDataRelationships": "openapi_client.models.post_catalog_variant_delete_job_response_data_relationships",
    "PostCatalogVariantDeleteJobResponseDataRelationshipsVariants": "openapi_client.models.post_catalog_variant_delete_job_response_data_relationships_variants",
    "PostCatalogVariantDeleteJobResponseDataRelationshipsVariantsDataInner": "openapi_client.models.post_catalog_variant_delete_job_response_data_relationships_variants_data_inner",
    "PostCatalogVariantResponse": "openapi_client.models.post_catalog_variant_response",
    "PostCatalogVariantResponseData": "openapi_client.models.post_catalog_variant_response_data",
    "PostCatalogVariantResponseDataRelationships": "openapi_client.models.post_catalog_variant_response_data_relationships",
    "PostCatalogVariantResponseDataRelationshipsItem": "openapi_client.models.post_catalog_variant_response_data_relationships_item",
    "PostCatalogVariantResponseDataRelationshipsItemData": "openapi_client.models.post_catalog_variant_response_data_relationships_item_data",
    "PostCatalogVariantUpdateJobResponse": "openapi_client.models.post_catalog_variant_update_job_response",
    "PostCatalogVariantUpdateJobResponseData": "openapi_client.models.post_catalog_variant_update_job_response_data",
    "PostCouponCodeCreateJobResponse": "openapi_client.models.post_coupon_code_create_job_response",
    "PostCouponCodeCreateJobResponseData": "openapi_client.models.post_coupon_code_create_job_response_data",
    "PostCouponCodeCreateJobResponseDataAttributes": "openapi_client.models.post_coupon_code_create_job_response_data_attributes",
    "PostCouponCodeResponse": "openapi_client.models.post_coupon_code_response",
    "PostCouponCodeResponseData": "openapi_client.models.post_coupon_code_response_data",
    "PostCouponCodeResponseDataRelationships": "openapi_client.models.post_coupon_code_response_data_relationships",
    "PostCouponCodeResponseDataRelationshipsProfile": "openapi_client.models.post_coupon_code_response_data_relationships_profile",
    "PostCouponCodeResponseDataRelationshipsProfileData": "openapi_client.models.post_coupon_code_response_data_relationships_profile_data",
    "PostCouponResponse": "openapi_client.models.post_coupon_response",
    "PostCouponResponseData": "openapi_client.models.post_coupon_response_data",
    "PostCouponResponseDataAttributes": "openapi_client.models.post_coupon_response_data_attributes",
    "PostCustomMetricResponse": "openapi_client.models.post_custom_metric_response",
    "PostCustomMetricResponseData": "openapi_client.models.post_custom_metric_response_data",
    "PostCustomMetricResponseDataAttributes": "openapi_client.models.post_custom_metric_response_data_attributes",
    "PostFlowSeriesResponseDTO": "openapi_client.models.post_flow_series_response_dto",
    "PostFlowSeriesResponseDTOData": "openapi_client.models.post_flow_series_response_dto_data",
    "PostFlowSeriesResponseDTODataAttributes": "openapi_client.models.post_flow_series_response_dto_data_attributes",
    "PostFlowV2Response": "openapi_client.models.post_flow_v2_response",
    "PostFlowV2ResponseData": "openapi_client.models.post_flow_v2_response_data",
    "PostFlowV2ResponseDataAttributes": "openapi_client.models.post_flow_v2_response_data_attributes",
    "PostFlowValuesResponseDTO": "openapi_client.models.post_flow_values_response_dto",
    "PostFlowValuesResponseDTOData": "openapi_client.models.post_flow_values_response_dto_data",
    "PostFlowValuesResponseDTODataAttributes": "openapi_client.models.post_flow_values_response_dto_data_attributes",
    "PostFlowValuesResponseDTODataRelationships": "openapi_client.models.post_flow_values_response_dto_data_relationships",
    "PostFormSeriesResponseDTO": "openapi_client.models.post_form_series_response_dto",
    "PostFormSeriesResponseDTOData": "openapi_client.models.post_form_series_response_dto_data",
    "PostFormSeriesResponseDTODataAttributes": "openapi_client.models.post_form_series_response_dto_data_attributes",
    "PostFormValuesResponseDTO": "openapi_client.models.post_form_values_response_dto",
    "PostFormValuesResponseDTOData": "openapi_client.models.post_form_values_response_dto_data",
    "PostFormValuesResponseDTODataAttributes": "openapi_client.models.post_form_values_response_dto_data_attributes",
    "PostImageResponse": "openapi_client.models.post_image_response",
    "PostImageResponseData": "openapi_client.models.post_image_response_data",
    "PostImageResponseDataAttributes": "openapi_client.models.post_image_response_data_attributes",
    "PostListCreateResponse": "openapi_client.models.post_list_create_response",
    "PostListCreateResponseData": "openapi_client.models.post_list_create_response_data",
    "PostListCreateResponseDataRelationships": "openapi_client.models.post_list_create_response_data_relationships",
    "PostListCreateResponseDataRelationshipsProfiles": "openapi_client.models.post_list_create_response_data_relationships_profiles",
    "PostListCreateResponseDataRelationshipsProfilesDataInner": "openapi_client.models.post_list_create_response_data_relationships_profiles_data_inner",
    "PostMetricAggregateResponse": "openapi_client.models.post_metric_aggregate_response",
    "PostMetricAggregateResponseData": "openapi_client.models.post_metric_aggregate_response_data",
    "PostMetricAggregateResponseDataAttributes": "openapi_client.models.post_metric_aggregate_response_data_attributes",
    "PostProfileImportJobResponse": "openapi_client.models.post_profile_import_job_response",
    "PostProfileImportJobResponseData": "openapi_client.models.post_profile_import_job_response_data",
    "PostProfileImportJobResponseDataAttributes": "openapi_client.models.post_profile_import_job_response_data_attributes",
    "PostProfileImportJobResponseDataRelationships": "openapi_client.models.post_profile_import_job_response_data_relationships",
    "PostProfileImportJobResponseDataRelationshipsImportErrors": "openapi_client.models.post_profile_import_job_response_data_relationships_import_errors",
    "PostProfileImportJobResponseDataRelationshipsImportErrorsDataInner": "openapi_client.models.post_profile_import_job_response_data_relationships_import_errors_data_inner",
    "PostProfileImportJobResponseDataRelationshipsProfiles": "openapi_client.models.post_profile_import_job_response_data_relationships_profiles",
    "PostProfileImportJobResponseDataRelationshipsProfilesDataInner": "openapi_client.models.post_profile_import_job_response_data_relationships_profiles_data_inner",
    "PostProfileMergeResponse": "openapi_client.models.post_profile_merge_response",
    "PostProfileMergeResponseData": "openapi_client.models.post_profile_merge_response_data",
    "PostProfileResponse": "openapi_client.models.post_profile_response",
    "PostProfileResponseData": "openapi_client.models.post_profile_response_data",
    "PostProfileResponseDataAttributes": "openapi_client.models.post_profile_response_data_attributes",
    "PostSegmentCreateResponse": "openapi_client.models.post_segment_create_response",
    "PostSegmentCreateResponseData": "openapi_client.models.post_segment_create_response_data",
    "PostSegmentSeriesResponseDTO": "openapi_client.models.post_segment_series_response_dto",
    "PostSegmentSeriesResponseDTOData": "openapi_client.models.post_segment_series_response_dto_data",
    "PostSegmentSeriesResponseDTODataAttributes": "openapi_client.models.post_segment_series_response_dto_data_attributes",
    "PostSegmentValuesResponseDTO": "openapi_client.models.post_segment_values_response_dto",
    "PostSegmentValuesResponseDTOData": "openapi_client.models.post_segment_values_response_dto_data",
    "PostSegmentValuesResponseDTODataAttributes": "openapi_client.models.post_segment_values_response_dto_data_attributes",
    "PostTagGroupResponse": "openapi_client.models.post_tag_group_response",
    "PostTagGroupResponseData": "openapi_client.models.post_tag_group_response_data",
    "PostTagGroupResponseDataAttributes": "openapi_client.models.post_tag_group_response_data_attributes",
    "PostTagGroupResponseDataRelationships": "openapi_client.models.post_tag_group_response_data_relationships",
    "PostTagResponse": "openapi_client.models.post_tag_response",
    "PostTagResponseData": "openapi_client.models.post_tag_response_data",
    "PostTagResponseDataAttributes": "openapi_client.models.post_tag_response_data_attributes",
    "PostTagResponseDataRelationships": "openapi_client.models.post_tag_response_data_relationships",
    "PostTagResponseDataRelationshipsCampaigns": "openapi_client.models.post_tag_response_data_relationships_campaigns",
    "PostTagResponseDataRelationshipsCampaignsDataInner": "openapi_client.models.post_tag_response_data_relationships_campaigns_data_inner",
    "PostTemplateResponse": "openapi_client.models.post_template_response",
    "PostTemplateResponseData": "openapi_client.models.post_template_response_data",
    "PostTemplateResponseDataAttributes": "openapi_client.models.post_template_response_data_attributes",
    "PostUniversalContentResponse": "openapi_client.models.post_universal_content_response",
    "PostUniversalContentResponseData": "openapi_client.models.post_universal_content_response_data",
    "PostUniversalContentResponseDataAttributes": "openapi_client.models.post_universal_content_response_data_attributes",
    "PostWebFeedResponse": "openapi_client.models.post_web_feed_response",
    "PostWebFeedResponseData": "openapi_client.models.post_web_feed_response_data",
    "PostWebFeedResponseDataAttributes": "openapi_client.models.post_web_feed_response_data_attributes",
    "PostWebhookResponse": "openapi_client.models.post_webhook_response",
    "PostWebhookResponseData": "openapi_client.models.post_webhook_response_data",
    "PostWebhookResponseDataAttributes": "openapi_client.models.post_webhook_response_data_attributes",
    "PredictiveAnalytics": "openapi_client.models.predictive_analytics",
    "ProfileBulkImportJobEnum": "openapi_client.models.profile_bulk_import_job_enum",
    "ProfileCreateQuery": "openapi_client.models.profile_create_query",
    "ProfileCreateQueryResourceObject": "openapi_client.models.profile_create_query_resource_object",
    "ProfileCreateQueryResourceObjectAttributes": "openapi_client.models.profile_create_query_resource_object_attributes",
    "ProfileEnum": "openapi_client.models.profile_enum",
    "ProfileIdentifierDTOResourceObject": "openapi_client.models.profile_identifier_dto_resource_object",
    "ProfileIdentifierDTOResourceObjectAttributes": "openapi_client.models.profile_identifier_dto_resource_object_attributes",
    "ProfileImportJobCreateQuery": "openapi_client.models.profile_import_job_create_query",
    "ProfileImportJobCreateQueryResourceObject": "openapi_client.models.profile_import_job_create_query_resource_object",
    "ProfileImportJobCreateQueryResourceObjectAttributes": "openapi_client.models.profile_import_job_create_query_resource_object_attributes",
    "ProfileImportJobCreateQueryResourceObjectAttributesProfiles": "openapi_client.models.profile_import_job_create_query_resource_object_attributes_profiles",
    "ProfileImportJobCreateQueryResourceObjectRelationships": "openapi_client.models.profile_import_job_create_query_resource_object_relationships",
    "ProfileImportJobCreateQueryResourceObjectRelationshipsLists": "openapi_client.models.profile_import_job_create_query_resource_object_relationships_lists",
    "ProfileImportJobCreateQueryResourceObjectRelationshipsListsDataInner": "openapi_client.models.profile_import_job_create_query_resource_object_relationships_lists_data_inner",
    "ProfileImportJobResponseObjectResource": "openapi_client.models.profile_import_job_response_object_resource",
    "ProfileImportJobResponseObjectResourceAttributes": "openapi_client.models.profile_import_job_response_object_resource_attributes",
    "ProfileLocation": "openapi_client.models.profile_location",
    "ProfileMergeEnum": "openapi_client.models.profile_merge_enum",
    "ProfileMergeQuery": "openapi_client.models.profile_merge_query",
    "ProfileMergeQueryResourceObject": "openapi_client.models.profile_merge_query_resource_object",
    "ProfileMergeQueryResourceObjectRelationships": "openapi_client.models.profile_merge_query_resource_object_relationships",
    "ProfileMergeQueryResourceObjectRelationshipsProfiles": "openapi_client.models.profile_merge_query_resource_object_relationships_profiles",
    "ProfileMergeQueryResourceObjectRelationshipsProfilesDataInner": "openapi_client.models.profile_merge_query_resource_object_relationships_profiles_data_inner",
    "ProfileMeta": "openapi_client.models.profile_meta",
    "ProfileMetaPatchProperties": "openapi_client.models.profile_meta_patch_properties",
    "ProfilePartialUpdateQuery": "openapi_client.models.profile_partial_update_query",
    "ProfilePartialUpdateQueryResourceObject": "openapi_client.models.profile_partial_update_query_resource_object",
    "ProfilePartialUpdateQueryResourceObjectAttributes": "openapi_client.models.profile_partial_update_query_resource_object_attributes",
    "ProfileResponseObjectResource": "openapi_client.models.profile_response_object_resource",
    "ProfileResponseObjectResourceAttributes": "openapi_client.models.profile_response_object_resource_attributes",
    "ProfileResponseObjectResourceExtended": "openapi_client.models.profile_response_object_resource_extended",
    "ProfileResponseObjectResourceExtendedAttributes": "openapi_client.models.profile_response_object_resource_extended_attributes",
    "ProfileSubscriptionBulkCreateJobEnum": "openapi_client.models.profile_subscription_bulk_create_job_enum",
    "ProfileSubscriptionBulkDeleteJobEnum": "openapi_client.models.profile_subscription_bulk_delete_job_enum",
    "ProfileSubscriptionCreateQueryResourceObject": "openapi_client.models.profile_subscription_create_query_resource_object",
    "ProfileSubscriptionCreateQueryResourceObjectAttributes": "openapi_client.models.profile_subscription_create_query_resource_object_attributes",
    "ProfileSubscriptionDeleteQueryResourceObject": "openapi_client.models.profile_subscription_delete_query_resource_object",
    "ProfileSubscriptionDeleteQueryResourceObjectAttributes": "openapi_client.models.profile_subscription_delete_query_resource_object_attributes",
    "ProfileSuppressionBulkCreateJobEnum": "openapi_client.models.profile_suppression_bulk_create_job_enum",
    "ProfileSuppressionBulkDeleteJobEnum": "openapi_client.models.profile_suppression_bulk_delete_job_enum",
    "ProfileSuppressionCreateQueryResourceObject": "openapi_client.models.profile_suppression_create_query_resource_object",
    "ProfileSuppressionCreateQueryResourceObjectAttributes": "openapi_client.models.profile_suppression_create_query_resource_object_attributes",
    "ProfileSuppressionDeleteQueryResourceObject": "openapi_client.models.profile_suppression_delete_query_resource_object",
    "ProfileSuppressionDeleteQueryResourceObjectAttributes": "openapi_client.models.profile_suppression_delete_query_resource_object_attributes",
    "ProfileUpsertQuery": "openapi_client.models.profile_upsert_query",
    "ProfileUpsertQueryResourceObject": "openapi_client.models.profile_upsert_query_resource_object",
    "ProfileUpsertQueryResourceObjectAttributes": "openapi_client.models.profile_upsert_query_resource_object_attributes",
    "PushChannel": "openapi_client.models.push_channel",
    "PushMarketing": "openapi_client.models.push_marketing",
    "PushProfileUpsertQueryResourceObject": "openapi_client.models.push_profile_upsert_query_resource_object",
    "PushProfileUpsertQueryResourceObjectAttributes": "openapi_client.models.push_profile_upsert_query_resource_object_attributes",
    "PushTokenCreateQuery": "openapi_client.models.push_token_create_query",
    "PushTokenCreateQueryResourceObject": "openapi_client.models.push_token_create_query_resource_object",
    "PushTokenCreateQueryResourceObjectAttributes": "openapi_client.models.push_token_create_query_resource_object_attributes",
    "PushTokenCreateQueryResourceObjectAttributesProfile": "openapi_client.models.push_token_create_query_resource_object_attributes_profile",
    "PushTokenEnum": "openapi_client.models.push_token_enum",
    "PushTokenResponseObjectResource": "openapi_client.models.push_token_response_object_resource",
    "PushTokenResponseObjectResourceAttributes": "openapi_client.models.push_token_response_object_resource_attributes",
    "RelationshipLinks": "openapi_client.models.relationship_links",
    "RenderOptionsSubObject": "openapi_client.models.render_options_sub_object",
    "ReviewEnum": "openapi_client.models.review_enum",
    "ReviewPatchQuery": "openapi_client.models.review_patch_query",
    "ReviewPatchQueryResourceObject": "openapi_client.models.review_patch_query_resource_object",
    "ReviewPatchQueryResourceObjectAttributes": "openapi_client.models.review_patch_query_resource_object_attributes",
    "ReviewProductDTO": "openapi_client.models.review_product_dto",
    "ReviewPublicReply": "openapi_client.models.review_public_reply",
    "ReviewResponseDTOObjectResource": "openapi_client.models.review_response_dto_object_resource",
    "ReviewResponseDTOObjectResourceAttributes": "openapi_client.models.review_response_dto_object_resource_attributes",
    "SMSChannel": "openapi_client.models.sms_channel",
    "SMSMarketing": "openapi_client.models.sms_marketing",
    "SMSRenderOptions": "openapi_client.models.sms_render_options",
    "SMSSubscriptionParameters": "openapi_client.models.sms_subscription_parameters",
    "SMSTransactional": "openapi_client.models.sms_transactional",
    "SMSUnsubscriptionParameters": "openapi_client.models.sms_unsubscription_parameters",
    "SegmentCreateQuery": "openapi_client.models.segment_create_query",
    "SegmentCreateQueryResourceObject": "openapi_client.models.segment_create_query_resource_object",
    "SegmentCreateQueryResourceObjectAttributes": "openapi_client.models.segment_create_query_resource_object_attributes",
    "SegmentDefinition": "openapi_client.models.segment_definition",
    "SegmentEnum": "openapi_client.models.segment_enum",
    "SegmentListResponseObjectResource": "openapi_client.models.segment_list_response_object_resource",
    "SegmentListResponseObjectResourceAttributes": "openapi_client.models.segment_list_response_object_resource_attributes",
    "SegmentMemberResponseObjectResourceAttributes": "openapi_client.models.segment_member_response_object_resource_attributes",
    "SegmentMemberResponseObjectResourceExtended": "openapi_client.models.segment_member_response_object_resource_extended",
    "SegmentMemberResponseObjectResourceExtendedAttributes": "openapi_client.models.segment_member_response_object_resource_extended_attributes",
    "SegmentPartialUpdateQuery": "openapi_client.models.segment_partial_update_query",
    "SegmentPartialUpdateQueryResourceObject": "openapi_client.models.segment_partial_update_query_resource_object",
    "SegmentPartialUpdateQueryResourceObjectAttributes": "openapi_client.models.segment_partial_update_query_resource_object_attributes",
    "SegmentResponseObjectResource": "openapi_client.models.segment_response_object_resource",
    "SegmentRetrieveResponseObjectResourceAttributes": "openapi_client.models.segment_retrieve_response_object_resource_attributes",
    "SegmentRetrieveResponseObjectResourceExtended": "openapi_client.models.segment_retrieve_response_object_resource_extended",
    "SegmentRetrieveResponseObjectResourceExtendedAttributes": "openapi_client.models.segment_retrieve_response_object_resource_extended_attributes",
    "SegmentSeriesReportEnum": "openapi_client.models.segment_series_report_enum",
    "SegmentSeriesRequestDTO": "openapi_client.models.segment_series_request_dto",
    "SegmentSeriesRequestDTOResourceObject": "openapi_client.models.segment_series_request_dto_resource_object",
    "SegmentSeriesRequestDTOResourceObjectAttributes": "openapi_client.models.segment_series_request_dto_resource_object_attributes",
    "SegmentValuesReportEnum": "openapi_client.models.segment_values_report_enum",
    "SegmentValuesRequestDTO": "openapi_client.models.segment_values_request_dto",
    "SegmentValuesRequestDTOResourceObject": "openapi_client.models.segment_values_request_dto_resource_object",
    "SegmentValuesRequestDTOResourceObjectAttributes": "openapi_client.models.segment_values_request_dto_resource_object_attributes",
    "SendOptions": "openapi_client.models.send_options",
    "SendTime": "openapi_client.models.send_time",
    "SendTimeSubObject": "openapi_client.models.send_time_sub_object",
    "SeriesData": "openapi_client.models.series_data",
    "ServerBISSubscriptionCreateQuery": "openapi_client.models.server_bis_subscription_create_query",
    "ServerBISSubscriptionCreateQueryResourceObject": "openapi_client.models.server_bis_subscription_create_query_resource_object",
    "ServerBISSubscriptionCreateQueryResourceObjectAttributes": "openapi_client.models.server_bis_subscription_create_query_resource_object_attributes",
    "ServerBISSubscriptionCreateQueryResourceObjectAttributesProfile": "openapi_client.models.server_bis_subscription_create_query_resource_object_attributes_profile",
    "ServerBISSubscriptionCreateQueryResourceObjectRelationships": "openapi_client.models.server_bis_subscription_create_query_resource_object_relationships",
    "ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariant": "openapi_client.models.server_bis_subscription_create_query_resource_object_relationships_variant",
    "ServerBISSubscriptionCreateQueryResourceObjectRelationshipsVariantData": "openapi_client.models.server_bis_subscription_create_query_resource_object_relationships_variant_data",
    "StreetAddress": "openapi_client.models.street_address",
    "SubscriptionChannels": "openapi_client.models.subscription_channels",
    "SubscriptionCreateJobCreateQuery": "openapi_client.models.subscription_create_job_create_query",
    "SubscriptionCreateJobCreateQueryResourceObject": "openapi_client.models.subscription_create_job_create_query_resource_object",
    "SubscriptionCreateJobCreateQueryResourceObjectAttributes": "openapi_client.models.subscription_create_job_create_query_resource_object_attributes",
    "SubscriptionCreateJobCreateQueryResourceObjectAttributesProfiles": "openapi_client.models.subscription_create_job_create_query_resource_object_attributes_profiles",
    "SubscriptionCreateJobCreateQueryResourceObjectRelationships": "openapi_client.models.subscription_create_job_create_query_resource_object_relationships",
    "SubscriptionCreateJobCreateQueryResourceObjectRelationshipsList": "openapi_client.models.subscription_create_job_create_query_resource_object_relationships_list",
    "SubscriptionCreateJobCreateQueryResourceObjectRelationshipsListData": "openapi_client.models.subscription_create_job_create_query_resource_object_relationships_list_data",
    "SubscriptionDeleteJobCreateQuery": "openapi_client.models.subscription_delete_job_create_query",
    "SubscriptionDeleteJobCreateQueryResourceObject": "openapi_client.models.subscription_delete_job_create_query_resource_object",
    "SubscriptionDeleteJobCreateQueryResourceObjectAttributes": "openapi_client.models.subscription_delete_job_create_query_resource_object_attributes",
    "SubscriptionDeleteJobCreateQueryResourceObjectAttributesProfiles": "openapi_client.models.subscription_delete_job_create_query_resource_object_attributes_profiles",
    "SubscriptionDeleteJobCreateQueryResourceObjectRelationships": "openapi_client.models.subscription_delete_job_create_query_resource_object_relationships",
    "SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsList": "openapi_client.models.subscription_delete_job_create_query_resource_object_relationships_list",
    "SubscriptionDeleteJobCreateQueryResourceObjectRelationshipsListData": "openapi_client.models.subscription_delete_job_create_query_resource_object_relationships_list_data",
    "SubscriptionParameters": "openapi_client.models.subscription_parameters",
    "Subscriptions": "openapi_client.models.subscriptions",
    "SuppressionCreateJobCreateQuery": "openapi_client.models.suppression_create_job_create_query",
    "SuppressionCreateJobCreateQueryResourceObject": "openapi_client.models.suppression_create_job_create_query_resource_object",
    "SuppressionCreateJobCreateQueryResourceObjectAttributes": "openapi_client.models.suppression_create_job_create_query_resource_object_attributes",
    "SuppressionCreateJobCreateQueryResourceObjectAttributesProfiles": "openapi_client.models.suppression_create_job_create_query_resource_object_attributes_profiles",
    "SuppressionCreateJobCreateQueryResourceObjectRelationships": "openapi_client.models.suppression_create_job_create_query_resource_object_relationships",
    "SuppressionCreateJobCreateQueryResourceObjectRelationshipsList": "openapi_client.models.suppression_create_job_create_query_resource_object_relationships_list",
    "SuppressionCreateJobCreateQueryResourceObjectRelationshipsListData": "openapi_client.models.suppression_create_job_create_query_resource_object_relationships_list_data",
    "SuppressionCreateJobCreateQueryResourceObjectRelationshipsSegment": "openapi_client.models.suppression_create_job_create_query_resource_object_relationships_segment",
    "SuppressionCreateJobCreateQueryResourceObjectRelationshipsSegmentData": "openapi_client.models.suppression_create_job_create_query_resource_object_relationships_segment_data",
    "SuppressionDeleteJobCreateQuery": "openapi_client.models.suppression_delete_job_create_query",
    "SuppressionDeleteJobCreateQueryResourceObject": "openapi_client.models.suppression_delete_job_create_query_resource_object",
    "SuppressionDeleteJobCreateQueryResourceObjectAttributes": "openapi_client.models.suppression_delete_job_create_query_resource_object_attributes",
    "SuppressionDeleteJobCreateQueryResourceObjectAttributesProfiles": "openapi_client.models.suppression_delete_job_create_query_resource_object_attributes_profiles",
    "SuppressionDeleteJobCreateQueryResourceObjectRelationships": "openapi_client.models.suppression_delete_job_create_query_resource_object_relationships",
    "SuppressionDeleteJobCreateQueryResourceObjectRelationshipsList": "openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_list",
    "SuppressionDeleteJobCreateQueryResourceObjectRelationshipsListData": "openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_list_data",
    "SuppressionDeleteJobCreateQueryResourceObjectRelationshipsSegment": "openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_segment",
    "SuppressionDeleteJobCreateQueryResourceObjectRelationshipsSegmentData": "openapi_client.models.suppression_delete_job_create_query_resource_object_relationships_segment_data",
    "TagCampaignOp": "openapi_client.models.tag_campaign_op",
    "TagCampaignOpDataInner": "openapi_client.models.tag_campaign_op_data_inner",
    "TagCreateQuery": "openapi_client.models.tag_create_query",
    "TagCreateQueryResourceObject": "openapi_client.models.tag_create_query_resource_object",
    "TagCreateQueryResourceObjectRelationships": "openapi_client.models.tag_create_query_resource_object_relationships",
    "TagCreateQueryResourceObjectRelationshipsTagGroup": "openapi_client.models.tag_create_query_resource_object_relationships_tag_group",
    "TagCreateQueryResourceObjectRelationshipsTagGroupData": "openapi_client.models.tag_create_query_resource_object_relationships_tag_group_data",
    "TagEnum": "openapi_client.models.tag_enum",
    "TagFlowOp": "openapi_client.models.tag_flow_op",
    "TagFlowOpDataInner": "openapi_client.models.tag_flow_op_data_inner",
    "TagGroupCreateQuery": "openapi_client.models.tag_group_create_query",
    "TagGroupCreateQueryResourceObject": "openapi_client.models.tag_group_create_query_resource_object",
    "TagGroupCreateQueryResourceObjectAttributes": "openapi_client.models.tag_group_create_query_resource_object_attributes",
    "TagGroupEnum": "openapi_client.models.tag_group_enum",
    "TagGroupResponseObjectResource": "openapi_client.models.tag_group_response_object_resource",
    "TagGroupResponseObjectResourceAttributes": "openapi_client.models.tag_group_response_object_resource_attributes",
    "TagGroupUpdateQuery": "openapi_client.models.tag_group_update_query",
    "TagGroupUpdateQueryResourceObject": "openapi_client.models.tag_group_update_query_resource_object",
    "TagGroupUpdateQueryResourceObjectAttributes": "openapi_client.models.tag_group_update_query_resource_object_attributes",
    "TagListOp": "openapi_client.models.tag_list_op",
    "TagListOpDataInner": "openapi_client.models.tag_list_op_data_inner",
    "TagResponseObjectResource": "openapi_client.models.tag_response_object_resource",
    "TagResponseObjectResourceAttributes": "openapi_client.models.tag_response_object_resource_attributes",
    "TagSegmentOp": "openapi_client.models.tag_segment_op",
    "TagSegmentOpDataInner": "openapi_client.models.tag_segment_op_data_inner",
    "TagUpdateQuery": "openapi_client.models.tag_update_query",
    "TagUpdateQueryResourceObject": "openapi_client.models.tag_update_query_resource_object",
    "TemplateCloneQuery": "openapi_client.models.template_clone_query",
    "TemplateCloneQueryResourceObject": "openapi_client.models.template_clone_query_resource_object",
    "TemplateCloneQueryResourceObjectAttributes": "openapi_client.models.template_clone_query_resource_object_attributes",
    "TemplateCreateQuery": "openapi_client.models.template_create_query",
    "TemplateCreateQueryResourceObject": "openapi_client.models.template_create_query_resource_object",
    "TemplateCreateQueryResourceObjectAttributes": "openapi_client.models.template_create_query_resource_object_attributes",
    "TemplateEnum": "openapi_client.models.template_enum",
    "TemplateRenderQuery": "openapi_client.models.template_render_query",
    "TemplateRenderQueryResourceObject": "openapi_client.models.template_render_query_resource_object",
    "TemplateRenderQueryResourceObjectAttributes": "openapi_client.models.template_render_query_resource_object_attributes",
    "TemplateResponseObjectResource": "openapi_client.models.template_response_object_resource",
    "TemplateResponseObjectResourceAttributes": "openapi_client.models.template_response_object_resource_attributes",
    "TemplateUniversalContentEnum": "openapi_client.models.template_universal_content_enum",
    "TemplateUpdateQuery": "openapi_client.models.template_update_query",
    "TemplateUpdateQueryResourceObject": "openapi_client.models.template_update_query_resource_object",
    "TemplateUpdateQueryResourceObjectAttributes": "openapi_client.models.template_update_query_resource_object_attributes",
    "TrackingParamDTO": "openapi_client.models.tracking_param_dto",
    "TrackingSettingEnum": "openapi_client.models.tracking_setting_enum",
    "TrackingSettingPartialUpdateQuery": "openapi_client.models.tracking_setting_partial_update_query",
    "TrackingSettingPartialUpdateQueryResourceObject": "openapi_client.models.tracking_setting_partial_update_query_resource_object",
    "TrackingSettingPartialUpdateQueryResourceObjectAttributes": "openapi_client.models.tracking_setting_partial_update_query_resource_object_attributes",
    "TrackingSettingResponseObjectResource": "openapi_client.models.tracking_setting_response_object_resource",
    "TrackingSettingResponseObjectResourceAttributes": "openapi_client.models.tracking_setting_response_object_resource_attributes",
    "UniversalContentCreateQuery": "openapi_client.models.universal_content_create_query",
    "UniversalContentCreateQueryResourceObject": "openapi_client.models.universal_content_create_query_resource_object",
    "UniversalContentCreateQueryResourceObjectAttributes": "openapi_client.models.universal_content_create_query_resource_object_attributes",
    "UniversalContentPartialUpdateQuery": "openapi_client.models.universal_content_partial_update_query",
    "UniversalContentPartialUpdateQueryResourceObject": "openapi_client.models.universal_content_partial_update_query_resource_object",
    "UniversalContentPartialUpdateQueryResourceObjectAttributes": "openapi_client.models.universal_content_partial_update_query_resource_object_attributes",
    "UniversalContentResponseObjectResource": "openapi_client.models.universal_content_response_object_resource",
    "UniversalContentResponseObjectResourceAttributes": "openapi_client.models.universal_content_response_object_resource_attributes",
    "UnsubscriptionChannels": "openapi_client.models.unsubscription_channels",
    "UnsubscriptionParameters": "openapi_client.models.unsubscription_parameters",
    "ValuesData": "openapi_client.models.values_data",
    "WebFeedCreateQuery": "openapi_client.models.web_feed_create_query",
    "WebFeedCreateQueryResourceObject": "openapi_client.models.web_feed_create_query_resource_object",
    "WebFeedCreateQueryResourceObjectAttributes": "openapi_client.models.web_feed_create_query_resource_object_attributes",
    "WebFeedEnum": "openapi_client.models.web_feed_enum",
    "WebFeedPartialUpdateQuery": "openapi_client.models.web_feed_partial_update_query",
    "WebFeedPartialUpdateQueryResourceObject": "openapi_client.models.web_feed_partial_update_query_resource_object",
    "WebFeedPartialUpdateQueryResourceObjectAttributes": "openapi_client.models.web_feed_partial_update_query_resource_object_attributes",
    "WebFeedResponseObjectResource": "openapi_client.models.web_feed_response_object_resource",
    "WebFeedResponseObjectResourceAttributes": "openapi_client.models.web_feed_response_object_resource_attributes",
    "WebhookCreateQuery": "openapi_client.models.webhook_create_query",
    "WebhookCreateQueryResourceObject": "openapi_client.models.webhook_create_query_resource_object",
    "WebhookCreateQueryResourceObjectAttributes": "openapi_client.models.webhook_create_query_resource_object_attributes",
    "WebhookCreateQueryResourceObjectRelationships": "openapi_client.models.webhook_create_query_resource_object_relationships",
    "WebhookCreateQueryResourceObjectRelationshipsWebhookTopics": "openapi_client.models.webhook_create_query_resource_object_relationships_webhook_topics",
    "WebhookCreateQueryResourceObjectRelationshipsWebhookTopicsDataInner": "openapi_client.models.webhook_create_query_resource_object_relationships_webhook_topics_data_inner",
    "WebhookEnum": "openapi_client.models.webhook_enum",
    "WebhookPartialUpdateQuery": "openapi_client.models.webhook_partial_update_query",
    "WebhookPartialUpdateQueryResourceObject": "openapi_client.models.webhook_partial_update_query_resource_object",
    "WebhookPartialUpdateQueryResourceObjectAttributes": "openapi_client.models.webhook_partial_update_query_resource_object_attributes",
    "WebhookPartialUpdateQueryResourceObjectRelationships": "openapi_client.models.webhook_partial_update_query_resource_object_relationships",
    "WebhookResponseObjectResource": "openapi_client.models.webhook_response_object_resource",
    "WebhookResponseObjectResourceAttributes": "openapi_client.models.webhook_response_object_resource_attributes",
    "WebhookTopicEnum": "openapi_client.models.webhook_topic_enum",
    "WebhookTopicResponseObjectResource": "openapi_client.models.webhook_topic_response_object_resource",
    
}


def __getattr__(name):
    if name in object_origins:
        module = __import__(object_origins[name], None, None, [name])
        return getattr(module, name)
    return __import__(f"openapi_client.{name}")

